/*
** 2000-05-29
**
** The author disclaims copyright to this source code.  In place of
** a legal notice, here is a blessing:
**
**    May you do good and not evil.
**    May you find forgiveness for yourself and forgive others.
**    May you share freely, never taking more than you give.
**
*************************************************************************
** Driver template for the LEMON parser generator.
**
** The "lemon" program processes an LALR(1) input grammar file, then uses
** this template to construct a parser.  The "lemon" program inserts text
** at each "%%" line.  Also, any "P-a-r-s-e" identifer prefix (without the
** interstitial "-" characters) contained in this template is changed into
** the value of the %name directive from the grammar.  Otherwise, the content
** of this template is copied straight through into the generate parser
** source file.
**
** The following is the concatenation of all %include directives from the
** input grammar file:
*/
#include <stdio.h>
#include <string.h>
#include <assert.h>

#ifdef _MSC_VER
#define CDECL __cdecl
#else
#define CDECL
#endif

/************ Begin %include sections from the grammar ************************/
#line 40 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"

// Allocates a new AST node off the parse state's arena.
#define NEW_AST_NODE(type,name,tok) \
	ZCC_##type *name = static_cast<ZCC_##type *>(stat->InitNode(sizeof(ZCC_##type), AST_##type)); \
	SetNodeLine(name, tok)

static void SetNodeLine(ZCC_TreeNode *name, ZCCToken &tok)
{
	name->SourceLoc = tok.SourceLoc;
}

static void SetNodeLine(ZCC_TreeNode *name, ZCC_TreeNode *node)
{
	if (name == nullptr || node == nullptr)
	{
		I_Error("Fatal parse error");
	}
	name->SourceLoc = node->SourceLoc;
}

static void SetNodeLine(ZCC_TreeNode *name, int line)
{
	name->SourceLoc = line;
}

// If a is non-null, appends b to a. Otherwise, sets a to b.
#define SAFE_APPEND(a,b) \
	if (a == NULL) a = b; else AppendTreeNodeSibling(a, b);

#define UNARY_EXPR(X,T) NEW_AST_NODE(ExprUnary, expr1, X); expr1->Operation = T; expr1->Operand = X; expr1->Type = NULL
#define BINARY_EXPR(X,Y,T) NEW_AST_NODE(ExprBinary, expr2, X); expr2->Operation = T; expr2->Type = NULL; expr2->Left = X; expr2->Right = Y

#define NEW_INTCONST_NODE(name,type,val,tok) \
	NEW_AST_NODE(ExprConstant, name, tok); \
	name->Operation = PEX_ConstValue; \
	name->Type = type; \
	name->IntVal = val

	struct ClassFlagsBlock {
		VM_UWORD Flags;
		ZCC_Identifier *Replaces;
		VersionInfo Version;
	};

	struct StateOpts {
		ZCC_Expression *Offset;
		ZCC_ExprConstant *Lights;
		bool Bright;
		bool Fast;
		bool Slow;
		bool NoDelay;
		bool CanRaise;

		void Zero() {
			Offset = nullptr;
			Lights = nullptr;
			Bright = false;
			Fast = false;
			Slow = false;
			NoDelay = false;
			CanRaise = false;
		}
	};

	struct VarOrFun
	{
		ZCC_VarName *VarNames;
		ZCC_FuncParamDecl *FuncParams;
		ZCC_CompoundStmt *FuncBody;
		ENamedName FuncName;
		int FuncFlags;
		int SourceLoc;
	};
#line 111 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
/**************** End of %include directives **********************************/
/* These constants specify the various numeric values for terminal symbols
** in a format understandable to "makeheaders".  This section is blank unless
** "lemon" is run with the "-m" command-line option.
***************** Begin makeheaders token definitions *************************/
/**************** End makeheaders token definitions ***************************/

/* The next section is a series of control #defines.
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used to store the integer codes
**                       that represent terminal and non-terminal symbols.
**                       "unsigned char" is used if there are fewer than
**                       256 symbols.  Larger types otherwise.
**    YYNOCODE           is a number of type YYCODETYPE that is not used for
**                       any terminal or nonterminal symbol.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       (also known as: "terminal symbols") have fall-back
**                       values which should be used if the original symbol
**                       would not parse.  This permits keywords to sometimes
**                       be used as identifiers, for example.
**    YYACTIONTYPE       is the data type used for "action codes" - numbers
**                       that indicate what to do in response to the next
**                       token.
**    ZCCParseTOKENTYPE     is the data type used for minor type for terminal
**                       symbols.  Background: A "minor type" is a semantic
**                       value associated with a terminal or non-terminal
**                       symbols.  For example, for an "ID" terminal symbol,
**                       the minor type might be the name of the identifier.
**                       Each non-terminal can have a different minor type.
**                       Terminal symbols all have the same minor type, though.
**                       This macros defines the minor type for terminal 
**                       symbols.
**    YYMINORTYPE        is the data type used for all minor types.
**                       This is typically a union of many types, one of
**                       which is ZCCParseTOKENTYPE.  The entry in the union
**                       for terminal symbols is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    ZCCParseARG_SDECL     A static variable declaration for the %extra_argument
**    ZCCParseARG_PDECL     A parameter declaration for the %extra_argument
**    ZCCParseARG_STORE     Code to store %extra_argument into yypParser
**    ZCCParseARG_FETCH     Code to extract %extra_argument from yypParser
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YY_MAX_SHIFT       Maximum value for shift actions
**    YY_MIN_SHIFTREDUCE Minimum value for shift-reduce actions
**    YY_MAX_SHIFTREDUCE Maximum value for shift-reduce actions
**    YY_MIN_REDUCE      Maximum value for reduce actions
**    YY_ERROR_ACTION    The yy_action[] code for syntax error
**    YY_ACCEPT_ACTION   The yy_action[] code for accept
**    YY_NO_ACTION       The yy_action[] code for no-op
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/************* Begin control #defines *****************************************/
#define YYCODETYPE unsigned char
#define YYNOCODE 255
#define YYACTIONTYPE unsigned short int
#define ZCCParseTOKENTYPE  ZCCToken 
typedef union {
  int yyinit;
  ZCCParseTOKENTYPE yy0;
  ZCC_FlagStmt * yy8;
  ZCC_Identifier * yy17;
  ZCC_PropertyStmt * yy31;
  ZCC_Class * yy32;
  ZCC_CompoundStmt * yy35;
  ZCC_TreeNode * yy40;
  ZCC_IfStmt * yy101;
  ZCC_ExprConstant * yy135;
  ZCC_LocalVarStmt * yy150;
  ZCC_Enum * yy151;
  ZCC_Struct * yy179;
  ZCC_AssignStmt * yy195;
  ZCC_StaticArrayStatement * yy202;
  ZCC_States * yy258;
  ZCC_ExpressionStmt * yy262;
  ZCC_VarName * yy320;
  ZCC_DeclFlags * yy331;
  ClassFlagsBlock yy335;
  ZCC_Property * yy336;
  ZCC_Type * yy344;
  ZCC_VarInit * yy363;
  ZCC_FuncParm * yy366;
  ZCC_ConstantDef * yy375;
  ZCC_StatePart * yy386;
  ZCC_Declarator * yy411;
  ZCC_CaseStmt * yy422;
  ZCC_ExprFuncCall * yy465;
  ZCC_BasicType * yy474;
  ZCC_Statement * yy475;
  VarOrFun yy476;
  ZCC_Default * yy479;
  ZCC_FuncParamDecl * yy480;
  ZCC_Expression * yy494;
  StateOpts yy504;
  int yy509;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 0
#endif
#define ZCCParseARG_SDECL  ZCCParseState *stat ;
#define ZCCParseARG_PDECL , ZCCParseState *stat 
#define ZCCParseARG_FETCH  ZCCParseState *stat  = yypParser->stat 
#define ZCCParseARG_STORE yypParser->stat  = stat 
#define YYERRORSYMBOL 154
#define YYERRSYMDT yy509
#define YYFALLBACK 1
#define YYNSTATE             362
#define YYNRULE              344
#define YY_MAX_SHIFT         361
#define YY_MIN_SHIFTREDUCE   603
#define YY_MAX_SHIFTREDUCE   946
#define YY_MIN_REDUCE        947
#define YY_MAX_REDUCE        1290
#define YY_ERROR_ACTION      1291
#define YY_ACCEPT_ACTION     1292
#define YY_NO_ACTION         1293
/************* End control #defines *******************************************/

/* Define the yytestcase() macro to be a no-op if is not already defined
** otherwise.
**
** Applications can choose to define yytestcase() in the %include section
** to a macro that can assist in verifying code coverage.  For production
** code the yytestcase() macro should be turned off.  But it is useful
** for testing.
*/
#ifndef yytestcase
# define yytestcase(X)
#endif


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N <= YY_MAX_SHIFT             Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   N between YY_MIN_SHIFTREDUCE       Shift to an arbitrary state then
**     and YY_MAX_SHIFTREDUCE           reduce by rule N-YY_MIN_SHIFTREDUCE.
**
**   N between YY_MIN_REDUCE            Reduce by rule N-YY_MIN_REDUCE
**     and YY_MAX_REDUCE
**
**   N == YY_ERROR_ACTION               A syntax error has occurred.
**
**   N == YY_ACCEPT_ACTION              The parser accepts its input.
**
**   N == YY_NO_ACTION                  No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as either:
**
**    (A)   N = yy_action[ yy_shift_ofst[S] + X ]
**    (B)   N = yy_default[S]
**
** The (A) formula is preferred.  The B formula is used instead if:
**    (1)  The yy_shift_ofst[S]+X value is out of range, or
**    (2)  yy_lookahead[yy_shift_ofst[S]+X] is not equal to X, or
**    (3)  yy_shift_ofst[S] equal YY_SHIFT_USE_DFLT.
** (Implementation note: YY_SHIFT_USE_DFLT is chosen so that
** YY_SHIFT_USE_DFLT+X will be out of range for all possible lookaheads X.
** Hence only tests (1) and (2) need to be evaluated.)
**
** The formulas above are for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
**
*********** Begin parsing tables **********************************************/
#define YY_ACTTAB_COUNT (2601)
static const YYACTIONTYPE yy_action[] = {
 /*     0 */   109,  108,   36,  605,  607,  608,  609,  610,  611,  106,
 /*    10 */   107,  153,   29,   32,  132,   90,  870,  688,  163,   41,
 /*    20 */   152,  320,   57,  299,  187,  348,  634,  713,  861,  227,
 /*    30 */   295,  734,    2,  884,  636,  635,  639,   93,   92,   91,
 /*    40 */    89,   88,   90,  996,  709,  633,  797,  351,  339,   57,
 /*    50 */   640,  637,  638,  641,  720,  721,  722,  723,  724,  725,
 /*    60 */   726,  727,  728,  729,  730,  731,  732,  733,  735,  335,
 /*    70 */   328,  117,  329,  325,   72,   73,   74,   87,   86,   85,
 /*    80 */    95,   98,   93,   92,   91,   89,   88,   90,  226,  187,
 /*    90 */   798,  189,  348,  336,   57,  678,   14,  788,  105,  104,
 /*   100 */   103,  102,  863,  864,  865,  866,  867,  868,  869,   39,
 /*   110 */   306,  305,   28,    9,  301,  893,  894,  297,  785,  296,
 /*   120 */    47,   95,   98,   93,   92,   91,   89,   88,   90,  230,
 /*   130 */   130,  130,  109,  108,    2,   57,  675,  676,  677,  162,
 /*   140 */   662,  106,  107,  153,   29,   32,  736,  116,  870,  111,
 /*   150 */    36,  357,  152,  320,   44,  226,  189,  798,  230,  230,
 /*   160 */   861,  115,  295,  734,    2,  885,  661,  747,  736,  748,
 /*   170 */   121,  322,  112,  322,  321,  155,  337,  155,  797,  289,
 /*   180 */   289,   38, 1130,  762,  755,  755,  720,  721,  722,  723,
 /*   190 */   724,  725,  726,  727,  728,  729,  730,  731,  732,  733,
 /*   200 */   735,  335,  328,  685,  329,  325,  348,   73,   74,   87,
 /*   210 */    86,   85,   95,   98,   93,   92,   91,   89,   88,   90,
 /*   220 */   720,  721,  722,  723,  724,  725,   57,  787,  149,  149,
 /*   230 */   105,  104,  103,  102,  863,  864,  865,  866,  867,  868,
 /*   240 */   869,   39,  306,  305,   28,    9,  301,  893,  894,  297,
 /*   250 */   667,  296,   47,  789,   38,  263,  266,  232,  679,  680,
 /*   260 */   681,  682,  129,   40,  109,  108,  755,  630,  127,  226,
 /*   270 */   815,  798,  140,  106,  107,  153,   29,   32,  683,   27,
 /*   280 */   870,  265,  264,    1,  152,  320,  360,  353,  684,  351,
 /*   290 */   339,  143,  861,  166,  295,  734,    2,  153,  690,  691,
 /*   300 */   692,  693,  694,  274,  273,  627,  152,  737,   36,  161,
 /*   310 */   797,  711,  714,  715,  628,  629,  302,  734,  720,  721,
 /*   320 */   722,  723,  724,  725,  726,  727,  728,  729,  730,  731,
 /*   330 */   732,  733,  735,  335,  328,  753,  329,  325,  293,  293,
 /*   340 */   720,  721,  722,  723,  724,  725,  726,  727,  728,  729,
 /*   350 */   730,  731,  732,  733,  735,  335,  328,  674,  329,  325,
 /*   360 */   614,   39,  105,  104,  103,  102,  863,  864,  865,  866,
 /*   370 */   867,  868,  869,   39,  306,  305,   28,    9,  301,  893,
 /*   380 */   894,  297,  153,  296,   47,  348,  876,  736,  150,  150,
 /*   390 */    52,  152,  737,  626,  766,  779,  780,  110,  281,  606,
 /*   400 */   253,  292,  734,  886, 1292,   22,  911,  781,  747,  736,
 /*   410 */   748,  121,  358,  356,  750,  620,  621,  622,  623,  134,
 /*   420 */   256,  893,  894,  718,   52,  720,  721,  722,  723,  724,
 /*   430 */   725,  726,  727,  728,  729,  730,  731,  732,  733,  735,
 /*   440 */   335,  334,  286,  329,  325,  751,   36,  257,  226,  814,
 /*   450 */   798,  145,  284,  767,  768,  769,  770,  771,  772,  773,
 /*   460 */   775,  776,  777,  778,  782,   69,   66,   65,   64,   68,
 /*   470 */    67,   63,   62,   60,   59,   58,   61,   56,  160,   70,
 /*   480 */    71,   77,   76,   75,   83,   82,   81,   80,   79,   78,
 /*   490 */    84,   72,   73,   74,   87,   86,   85,   95,   98,   93,
 /*   500 */    92,   91,   89,   88,   90,  806,  807,  346,   17,   54,
 /*   510 */   133,   57,  754,  261,   96,  264,  234,  234,  631,  360,
 /*   520 */   353,  348,  351,  339,  143,   52,  800,  262,   69,   66,
 /*   530 */    65,   64,   68,   67,   63,   62,   60,   59,   58,   61,
 /*   540 */    56,  912,   70,   71,   77,   76,   75,   83,   82,   81,
 /*   550 */    80,   79,   78,   84,   72,   73,   74,   87,   86,   85,
 /*   560 */    95,   98,   93,   92,   91,   89,   88,   90, 1265,  126,
 /*   570 */   109,  108,  351,  339,   57,   21,   30,   97,  704,  106,
 /*   580 */   107,  153,   29,  272,  226,  813,  798,  706,    8,  801,
 /*   590 */   152,  320,  756,  146,   39,  696,  736,   52,  861,  189,
 /*   600 */   348,  734,  883,   52,   74,   87,   86,   85,   95,   98,
 /*   610 */    93,   92,   91,   89,   88,   90,  797,  747,  736,  748,
 /*   620 */   121,  128,   57,  324,  720,  721,  722,  723,  724,  725,
 /*   630 */   726,  727,  728,  729,  730,  731,  732,  733,  735,  335,
 /*   640 */   328,  345,  329,  325,   87,   86,   85,   95,   98,   93,
 /*   650 */    92,   91,   89,   88,   90,   15,  876,  168,  348,  294,
 /*   660 */   269,   57,  697,  226,  189,  798,  857,  857,  105,  104,
 /*   670 */   103,  102,  863,  864,  865,  866,  867,  868,  869,   69,
 /*   680 */    66,   65,   64,   68,   67,   63,   62,   60,   59,   58,
 /*   690 */    61,   56,  231,   70,   71,   77,   76,   75,   83,   82,
 /*   700 */    81,   80,   79,   78,   84,   72,   73,   74,   87,   86,
 /*   710 */    85,   95,   98,   93,   92,   91,   89,   88,   90,  333,
 /*   720 */   144,  226,  168,  798,  164,   57,  670,   69,   66,   65,
 /*   730 */    64,   68,   67,   63,   62,   60,   59,   58,   61,   56,
 /*   740 */   695,   70,   71,   77,   76,   75,   83,   82,   81,   80,
 /*   750 */    79,   78,   84,   72,   73,   74,   87,   86,   85,   95,
 /*   760 */    98,   93,   92,   91,   89,   88,   90,  332,  233,  311,
 /*   770 */   763,  118,  914,   57,  760,  784,   42,  316,   69,   66,
 /*   780 */    65,   64,   68,   67,   63,   62,   60,   59,   58,   61,
 /*   790 */    56,  904,   70,   71,   77,   76,   75,   83,   82,   81,
 /*   800 */    80,   79,   78,   84,   72,   73,   74,   87,   86,   85,
 /*   810 */    95,   98,   93,   92,   91,   89,   88,   90,  114,  244,
 /*   820 */   151,  744,  330,  663,   57,  154,   69,   66,   65,   64,
 /*   830 */    68,   67,   63,   62,   60,   59,   58,   61,   56,  924,
 /*   840 */    70,   71,   77,   76,   75,   83,   82,   81,   80,   79,
 /*   850 */    78,   84,   72,   73,   74,   87,   86,   85,   95,   98,
 /*   860 */    93,   92,   91,   89,   88,   90,  917,  659,  125,  338,
 /*   870 */   645,  861,   57,  361,   69,   66,   65,   64,   68,   67,
 /*   880 */    63,   62,   60,   59,   58,   61,   56,    5,   70,   71,
 /*   890 */    77,   76,   75,   83,   82,   81,   80,   79,   78,   84,
 /*   900 */    72,   73,   74,   87,   86,   85,   95,   98,   93,   92,
 /*   910 */    91,   89,   88,   90,  224,   12,  267,  268,  275,  225,
 /*   920 */    57,   13,   69,   66,   65,   64,   68,   67,   63,   62,
 /*   930 */    60,   59,   58,   61,   56,    6,   70,   71,   77,   76,
 /*   940 */    75,   83,   82,   81,   80,   79,   78,   84,   72,   73,
 /*   950 */    74,   87,   86,   85,   95,   98,   93,   92,   91,   89,
 /*   960 */    88,   90,  227,  625,  254,  255,  135,  615,   57,  259,
 /*   970 */    69,   66,   65,   64,   68,   67,   63,   62,   60,   59,
 /*   980 */    58,   61,   56,  891,   70,   71,   77,   76,   75,   83,
 /*   990 */    82,   81,   80,   79,   78,   84,   72,   73,   74,   87,
 /*  1000 */    86,   85,   95,   98,   93,   92,   91,   89,   88,   90,
 /*  1010 */   713,   37,  138,  139,  701,  700,   57,  925,   69,   66,
 /*  1020 */    65,   64,   68,   67,   63,   62,   60,   59,   58,   61,
 /*  1030 */    56,   10,   70,   71,   77,   76,   75,   83,   82,   81,
 /*  1040 */    80,   79,   78,   84,   72,   73,   74,   87,   86,   85,
 /*  1050 */    95,   98,   93,   92,   91,   89,   88,   90,  186,  348,
 /*  1060 */   323,  187,  348,  702,   57,  699,   69,   66,   65,   64,
 /*  1070 */    68,   67,   63,   62,   60,   59,   58,   61,   56,   55,
 /*  1080 */    70,   71,   77,   76,   75,   83,   82,   81,   80,   79,
 /*  1090 */    78,   84,   72,   73,   74,   87,   86,   85,   95,   98,
 /*  1100 */    93,   92,   91,   89,   88,   90,  650,  647,  648,  348,
 /*  1110 */   278,  142,   57,  698,   43,   18,  123,  651,  276,  649,
 /*  1120 */   277,  765,  226,  186,  798,  226,  187,  798,   52,  804,
 /*  1130 */   899,   69,   66,   65,   64,   68,   67,   63,   62,   60,
 /*  1140 */    59,   58,   61,   56,  307,   70,   71,   77,   76,   75,
 /*  1150 */    83,   82,   81,   80,   79,   78,   84,   72,   73,   74,
 /*  1160 */    87,   86,   85,   95,   98,   93,   92,   91,   89,   88,
 /*  1170 */    90,  279,  226,  812,  798,  764,  280,   57,  282,   69,
 /*  1180 */    66,   65,   64,   68,   67,   63,   62,   60,   59,   58,
 /*  1190 */    61,   56,  799,   70,   71,   77,   76,   75,   83,   82,
 /*  1200 */    81,   80,   79,   78,   84,   72,   73,   74,   87,   86,
 /*  1210 */    85,   95,   98,   93,   92,   91,   89,   88,   90,  283,
 /*  1220 */   671,  757,   45,  287,  913,   57,  119,  658,   31,   69,
 /*  1230 */    66,   65,   64,   68,   67,   63,   62,   60,   59,   58,
 /*  1240 */    61,   56,  348,   70,   71,   77,   76,   75,   83,   82,
 /*  1250 */    81,   80,   79,   78,   84,   72,   73,   74,   87,   86,
 /*  1260 */    85,   95,   98,   93,   92,   91,   89,   88,   90,   30,
 /*  1270 */   147,   46,   48,    7,   56,   57,   70,   71,   77,   76,
 /*  1280 */    75,   83,   82,   81,   80,   79,   78,   84,   72,   73,
 /*  1290 */    74,   87,   86,   85,   95,   98,   93,   92,   91,   89,
 /*  1300 */    88,   90,  153,  189,  348,  226,  811,  798,   57,  653,
 /*  1310 */   655,  152,  737,  186,  348,  905,   49,  182,  348,  656,
 /*  1320 */   657,   20,  734,   84,   72,   73,   74,   87,   86,   85,
 /*  1330 */    95,   98,   93,   92,   91,   89,   88,   90,  352,  101,
 /*  1340 */   101,  246,  746,   33,   57,  720,  721,  722,  723,  724,
 /*  1350 */   725,  726,  727,  728,  729,  730,  731,  732,  733,  735,
 /*  1360 */   335,  328,  285,  329,  325,  227,  881,  226,  189,  798,
 /*  1370 */   246,  246,   11,   52,  669,  736,   50,  226,  186,  798,
 /*  1380 */    14,  226,  182,  798,  291,  898,  793,  794,  795,  312,
 /*  1390 */    51,   34,  880,  238,  308,  879,  747,  736,  748,  121,
 /*  1400 */   185,  348,  326,   71,   77,   76,   75,   83,   82,   81,
 /*  1410 */    80,   79,   78,   84,   72,   73,   74,   87,   86,   85,
 /*  1420 */    95,   98,   93,   92,   91,   89,   88,   90,  736,  141,
 /*  1430 */   348,  309,  189,  348,   57,  947,   21,  310,  136,  137,
 /*  1440 */   136,  137,  313,  235,  878,  186,  348,   35,  803,  747,
 /*  1450 */   736,  748,  121,  736,  712,  327,  712,  877,  315,  626,
 /*  1460 */    21,  626,  314,  875,  226,  185,  798, 1081,  736,  874,
 /*  1470 */   247,  707,  802,  708,  747,  736,  748,  288,  873,  148,
 /*  1480 */   270,   23,    3,  915,  752,  743,  159,  260,  258,  747,
 /*  1490 */   736,  748,  120,  226,  810,  798,  226,  189,  798,  247,
 /*  1500 */   247,  348,   24,  353,   25,  351,  339,  742,  245,  226,
 /*  1510 */   186,  798,  185,  348,  872,  887,  871,  319,  887,  887,
 /*  1520 */   887,  318,  317,  303,   26,  331,  298,   77,   76,   75,
 /*  1530 */    83,   82,   81,   80,   79,   78,   84,   72,   73,   74,
 /*  1540 */    87,   86,   85,   95,   98,   93,   92,   91,   89,   88,
 /*  1550 */    90,  185,  348,  740,  739,  229,  738,   57,  243,  348,
 /*  1560 */    53,  736,  156,  113,  226,  809,  798,  185,  348,  157,
 /*  1570 */   185,  348,  228,   16,  186,  348,  226,  185,  798,  109,
 /*  1580 */   108,  340,  747,  736,  748,  242,  877,  341,  106,  107,
 /*  1590 */   227,   29,  180,  348,  239,  719,   27,  736,  185,  348,
 /*  1600 */   796,  342,  343,  169,  348,  935,  805,  861,   57,  862,
 /*  1610 */   236,    4,   94,  237,   99,  226,  185,  798,  747,  736,
 /*  1620 */   748,  120,  226,  808,  798,  797,  350,  100,  710,  714,
 /*  1630 */   715,  226,  185,  798,  226,  185,  798,  304,  226,  186,
 /*  1640 */   798,  240,  158,  872,  887,  871,  319,  887,  887,  887,
 /*  1650 */   318,  317,  303,  186,  348,  298,  226,  180,  798,  165,
 /*  1660 */  1015,  354,  226,  185,  798,  877,  355,  226,  169,  798,
 /*  1670 */  1014,  642,  122,  949,  949,  304,  736,  105,  104,  103,
 /*  1680 */   102,  863,  864,  865,  866,  867,  868,  869,  271,  359,
 /*  1690 */   949,  186,  348,  949,  949,  949,  949,  747,  736,  748,
 /*  1700 */   120,  949,  949,  877,  949,  949,  949,  949,  949,  949,
 /*  1710 */   185,  348,  949,  949,  736,  170,  348,  226,  186,  798,
 /*  1720 */   124,  348,  872,  888,  871,  319,  888,  888,  888,  318,
 /*  1730 */   317,  303,  181,  348,  298,  747,  736,  748,  120,  949,
 /*  1740 */   949,  655,  949,  183,  348,  949,  949,  949,  949,  949,
 /*  1750 */   656,  657,  949,  241,  949,  226,  186,  798,  949,  949,
 /*  1760 */   872,  888,  871,  319,  888,  888,  888,  318,  317,  303,
 /*  1770 */   949,  654,  298,  304,  226,  185,  798,  949,  949,  226,
 /*  1780 */   170,  798,  171,  348,  226,  124,  798,  949,  949,  186,
 /*  1790 */   348,  949,  949,  949,  109,  108,  226,  181,  798,  949,
 /*  1800 */   949,  877,  949,  106,  107,  949,   29,  226,  183,  798,
 /*  1810 */   882,   14,  736,  949,  949,  796,  949,  172,  348,  949,
 /*  1820 */   173,  348,  861,  174,  348,  949,  949,  949,  949,  949,
 /*  1830 */   949,  949,  949,  747,  736,  748,  120,  949,  949,  949,
 /*  1840 */   797,  949,  949,  949,  949,  949,  226,  171,  798,  949,
 /*  1850 */   949,  949,  304,  226,  186,  798,  175,  348,  872,  903,
 /*  1860 */   871,  319,  903,  903,  903,  318,  317,  303,  186,  348,
 /*  1870 */   298,  949,  949,  949,  949,  949,  949,  949,  949,  949,
 /*  1880 */   877,  226,  172,  798,  226,  173,  798,  226,  174,  798,
 /*  1890 */   304,  736,  105,  104,  103,  102,  863,  864,  865,  866,
 /*  1900 */   867,  868,  869,  184,  348,  949,  186,  348,  949,  949,
 /*  1910 */   949,  949,  747,  736,  748,  120,  949,  949,  877,  949,
 /*  1920 */   226,  175,  798,  949,  949,  949,  188,  348,  949,  736,
 /*  1930 */   949,  949,  226,  186,  798,  176,  348,  872,  902,  871,
 /*  1940 */   319,  902,  902,  902,  318,  317,  303,  203,  348,  298,
 /*  1950 */   747,  736,  748,  120,  949,  949,  949,  949,  949,  949,
 /*  1960 */   177,  348,  949,  949,  949,  949,  949,  226,  184,  798,
 /*  1970 */   226,  186,  798,  949,  949,  872,  901,  871,  319,  901,
 /*  1980 */   901,  901,  318,  317,  303,  949,  949,  298,  304,  949,
 /*  1990 */   226,  188,  798,  854,  348,  949,  949,  949,  949,  226,
 /*  2000 */   176,  798,  949,  949,  186,  348,  949,  949,  949,  109,
 /*  2010 */   108,  226,  203,  798,  949,  949,  877,  949,  106,  107,
 /*  2020 */   949,   29,  949,  949,  226,  177,  798,  736,  949,  344,
 /*  2030 */   796,  949,  190,  348,  949,  191,  348,  861,  192,  348,
 /*  2040 */   949,  949,  949,  949,  949,  949,  949,  949,  747,  736,
 /*  2050 */   748,  120,  949,  949,  949,  797,  949,  226,  854,  798,
 /*  2060 */   193,  348,  949,  949,  949,  949,  949,  304,  226,  186,
 /*  2070 */   798,  194,  348,  872,  892,  871,  319,  892,  892,  892,
 /*  2080 */   318,  317,  303,  186,  348,  298,  949,  949,  949,  949,
 /*  2090 */   949,  949,  949,  949,  949,  877,  226,  190,  798,  226,
 /*  2100 */   191,  798,  226,  192,  798,  304,  736,  105,  104,  103,
 /*  2110 */   102,  863,  864,  865,  866,  867,  868,  869,  195,  348,
 /*  2120 */   949,  186,  348,  949,  226,  193,  798,  747,  736,  748,
 /*  2130 */   120,  949,  949,  877,  949,  226,  194,  798,  949,  196,
 /*  2140 */   348,  949,  949,  949,  736,  949,  949,  226,  186,  798,
 /*  2150 */   949,  949,  872,  131,  871,  319,  131,  131,  131,  318,
 /*  2160 */   317,  303,  949,  949,  298,  747,  736,  748,  120,  949,
 /*  2170 */   949,  949,  949,  949,  949,  949,  949,  949,  949,  949,
 /*  2180 */   949,  949,  226,  195,  798,  226,  186,  798,  949,  949,
 /*  2190 */   872,  890,  871,  319,  890,  890,  890,  318,  317,  303,
 /*  2200 */   949,  949,  298,  226,  196,  798,   83,   82,   81,   80,
 /*  2210 */    79,   78,   84,   72,   73,   74,   87,   86,   85,   95,
 /*  2220 */    98,   93,   92,   91,   89,   88,   90,  109,  108,  197,
 /*  2230 */   348,  949,  949,   57,  949,  949,  106,  107,  949,   29,
 /*  2240 */   109,  108,  949,  949,  186,  348,  949,  949,  796,  106,
 /*  2250 */   107,  949,   29,  109,  108,  861,  949,  949,  949,   19,
 /*  2260 */   949,  349,  106,  107,  949,   29,  949,  736,  861,  949,
 /*  2270 */   949,  949,  949,  797,  796,  949,  949,  949,  949,  949,
 /*  2280 */   949,  861,  949,  949,  949,  949,  797,  949,  747,  736,
 /*  2290 */   748,  120,  949,  226,  197,  798,  949,  949,  949,  797,
 /*  2300 */   198,  348,  949,  949,  199,  348,  949,  949,  226,  186,
 /*  2310 */   798,  200,  348,  949,  949,  949,  898,  949,  201,  348,
 /*  2320 */   949,  895,  949,  300,  290,  105,  104,  103,  102,  863,
 /*  2330 */   864,  865,  866,  867,  868,  869,  204,  348,  105,  104,
 /*  2340 */   103,  102,  863,  864,  865,  866,  867,  868,  869,  949,
 /*  2350 */   949,  105,  104,  103,  102,  863,  864,  865,  866,  867,
 /*  2360 */   868,  869,  205,  348,  226,  198,  798,  949,  226,  199,
 /*  2370 */   798,  949,  949,  216,  348,  226,  200,  798,  217,  348,
 /*  2380 */   949,  949,  226,  201,  798,  218,  348,  949,  206,  348,
 /*  2390 */   949,  207,  348,  949,  208,  348,  949,  209,  348,  949,
 /*  2400 */   226,  204,  798,  949,  210,  348,  949,  211,  348,  949,
 /*  2410 */   212,  348,  949,  949,  949,  213,  348,  949,  949,  214,
 /*  2420 */   348,  949,  949,  215,  348,  949,  226,  205,  798,  949,
 /*  2430 */   219,  348,  949,  220,  348,  949,  949,  226,  216,  798,
 /*  2440 */   949,  949,  226,  217,  798,  221,  348,  949,  949,  226,
 /*  2450 */   218,  798,  226,  206,  798,  226,  207,  798,  226,  208,
 /*  2460 */   798,  226,  209,  798,  248,  348,  949,  949,  226,  210,
 /*  2470 */   798,  226,  211,  798,  226,  212,  798,  949,  949,  226,
 /*  2480 */   213,  798,  949,  226,  214,  798,  949,  226,  215,  798,
 /*  2490 */   249,  348,  949,  949,  226,  219,  798,  226,  220,  798,
 /*  2500 */   347,  348,  949,  250,  348,  949,  251,  348,  949,  226,
 /*  2510 */   221,  798,  252,  348,  949,  202,  348,  949,  223,  348,
 /*  2520 */   949,  949,  178,  348,  949,  167,  348,  949,  226,  248,
 /*  2530 */   798,  222,  348,  949,  179,  348,  949,  949,  949,  949,
 /*  2540 */   949,  949,  949,  949,  949,  949,  949,  949,  949,  949,
 /*  2550 */   949,  949,  949,  949,  226,  249,  798,  949,  949,  949,
 /*  2560 */   949,  949,  949,  949,  226,  347,  798,  226,  250,  798,
 /*  2570 */   226,  251,  798,  949,  949,  949,  226,  252,  798,  226,
 /*  2580 */   202,  798,  226,  223,  798,  949,  226,  178,  798,  226,
 /*  2590 */   167,  798,  949,  949,  949,  226,  222,  798,  226,  179,
 /*  2600 */   798,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */    33,   34,   46,  161,  162,  163,  164,  165,  166,   42,
 /*    10 */    43,   44,   45,   46,  172,   40,   49,  200,  201,   34,
 /*    20 */    53,   54,   47,  169,  170,  171,  155,   49,   61,   44,
 /*    30 */    63,   64,   65,   66,  163,  164,  165,   35,   36,   37,
 /*    40 */    38,   39,   40,   66,   66,  174,   79,   70,   71,   47,
 /*    50 */   179,  180,  181,  182,   87,   88,   89,   90,   91,   92,
 /*    60 */    93,   94,   95,   96,   97,   98,   99,  100,  101,  102,
 /*    70 */   103,   54,  105,  106,   27,   28,   29,   30,   31,   32,
 /*    80 */    33,   34,   35,   36,   37,   38,   39,   40,  234,  235,
 /*    90 */   236,  170,  171,   54,   47,   14,  225,  127,  131,  132,
 /*   100 */   133,  134,  135,  136,  137,  138,  139,  140,  141,  142,
 /*   110 */   143,  144,  145,  146,  147,  148,  149,  150,   49,  152,
 /*   120 */   153,   33,   34,   35,   36,   37,   38,   39,   40,  208,
 /*   130 */   222,  223,   33,   34,   65,   47,  195,  196,  197,  198,
 /*   140 */   154,   42,   43,   44,   45,   46,  193,   54,   49,   45,
 /*   150 */    46,   54,   53,   54,   73,  234,  235,  236,  237,  238,
 /*   160 */    61,  203,   63,   64,   65,   66,  193,  214,  215,  216,
 /*   170 */   217,  218,  219,  220,  226,  189,  190,  191,   79,  231,
 /*   180 */   232,  233,   62,  230,  157,  158,   87,   88,   89,   90,
 /*   190 */    91,   92,   93,   94,   95,   96,   97,   98,   99,  100,
 /*   200 */   101,  102,  103,  199,  105,  106,  171,   28,   29,   30,
 /*   210 */    31,   32,   33,   34,   35,   36,   37,   38,   39,   40,
 /*   220 */    87,   88,   89,   90,   91,   92,   47,  107,  222,  223,
 /*   230 */   131,  132,  133,  134,  135,  136,  137,  138,  139,  140,
 /*   240 */   141,  142,  143,  144,  145,  146,  147,  148,  149,  150,
 /*   250 */    66,  152,  153,  232,  233,  154,   54,   73,   74,   75,
 /*   260 */    76,   77,   78,    1,   33,   34,  239,   48,  178,  234,
 /*   270 */   235,  236,   54,   42,   43,   44,   45,   46,  199,  178,
 /*   280 */    49,   79,   63,   65,   53,   54,   67,   68,  199,   70,
 /*   290 */    71,   72,   61,   49,   63,   64,   65,   44,   80,   81,
 /*   300 */    82,   83,   84,   85,   86,   54,   53,   54,   46,   65,
 /*   310 */    79,  210,  211,  212,   63,   64,  248,   64,   87,   88,
 /*   320 */    89,   90,   91,   92,   93,   94,   95,   96,   97,   98,
 /*   330 */    99,  100,  101,  102,  103,  223,  105,  106,  252,  253,
 /*   340 */    87,   88,   89,   90,   91,   92,   93,   94,   95,   96,
 /*   350 */    97,   98,   99,  100,  101,  102,  103,  154,  105,  106,
 /*   360 */   175,  142,  131,  132,  133,  134,  135,  136,  137,  138,
 /*   370 */   139,  140,  141,  142,  143,  144,  145,  146,  147,  148,
 /*   380 */   149,  150,   44,  152,  153,  171,   49,  193,  222,  223,
 /*   390 */    50,   53,   54,   54,   56,   57,   58,  194,   60,  154,
 /*   400 */   178,    1,   64,   66,  159,  160,   66,   69,  214,  215,
 /*   410 */   216,  217,  186,  187,  220,   55,   56,   57,   58,   59,
 /*   420 */    60,  148,  149,   49,   50,   87,   88,   89,   90,   91,
 /*   430 */    92,   93,   94,   95,   96,   97,   98,   99,  100,  101,
 /*   440 */   102,  103,  154,  105,  106,  107,   46,  178,  234,  235,
 /*   450 */   236,  113,  114,  115,  116,  117,  118,  119,  120,  121,
 /*   460 */   122,  123,  124,  125,  126,    1,    2,    3,    4,    5,
 /*   470 */     6,    7,    8,    9,   10,   11,   12,   13,  176,   15,
 /*   480 */    16,   17,   18,   19,   20,   21,   22,   23,   24,   25,
 /*   490 */    26,   27,   28,   29,   30,   31,   32,   33,   34,   35,
 /*   500 */    36,   37,   38,   39,   40,   42,   43,   44,   45,   46,
 /*   510 */    14,   47,  224,  178,   50,   63,  228,  229,   66,   67,
 /*   520 */    68,  171,   70,   71,   72,   50,   62,  178,    1,    2,
 /*   530 */     3,    4,    5,    6,    7,    8,    9,   10,   11,   12,
 /*   540 */    13,   66,   15,   16,   17,   18,   19,   20,   21,   22,
 /*   550 */    23,   24,   25,   26,   27,   28,   29,   30,   31,   32,
 /*   560 */    33,   34,   35,   36,   37,   38,   39,   40,   66,  178,
 /*   570 */    33,   34,   70,   71,   47,   50,   50,   50,  202,   42,
 /*   580 */    43,   44,   45,   50,  234,  235,  236,   62,   62,   62,
 /*   590 */    53,   54,   49,   50,  142,   62,  193,   50,   61,  170,
 /*   600 */   171,   64,   49,   50,   29,   30,   31,   32,   33,   34,
 /*   610 */    35,   36,   37,   38,   39,   40,   79,  214,  215,  216,
 /*   620 */   217,  178,   47,  220,   87,   88,   89,   90,   91,   92,
 /*   630 */    93,   94,   95,   96,   97,   98,   99,  100,  101,  102,
 /*   640 */   103,  154,  105,  106,   30,   31,   32,   33,   34,   35,
 /*   650 */    36,   37,   38,   39,   40,   45,   49,  170,  171,  112,
 /*   660 */   205,   47,   61,  234,  235,  236,  237,  238,  131,  132,
 /*   670 */   133,  134,  135,  136,  137,  138,  139,  140,  141,    1,
 /*   680 */     2,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*   690 */    12,   13,  206,   15,   16,   17,   18,   19,   20,   21,
 /*   700 */    22,   23,   24,   25,   26,   27,   28,   29,   30,   31,
 /*   710 */    32,   33,   34,   35,   36,   37,   38,   39,   40,   54,
 /*   720 */    45,  234,  235,  236,  204,   47,   54,    1,    2,    3,
 /*   730 */     4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   740 */    62,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*   750 */    24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
 /*   760 */    34,   35,   36,   37,   38,   39,   40,  102,  187,   46,
 /*   770 */   204,   54,  253,   47,  229,   70,   50,   54,    1,    2,
 /*   780 */     3,    4,    5,    6,    7,    8,    9,   10,   11,   12,
 /*   790 */    13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
 /*   800 */    23,   24,   25,   26,   27,   28,   29,   30,   31,   32,
 /*   810 */    33,   34,   35,   36,   37,   38,   39,   40,  227,  178,
 /*   820 */    20,  221,  178,  191,   47,   50,    1,    2,    3,    4,
 /*   830 */     5,    6,    7,    8,    9,   10,   11,   12,   13,  168,
 /*   840 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /*   850 */    25,   26,   27,   28,   29,   30,   31,   32,   33,   34,
 /*   860 */    35,   36,   37,   38,   39,   40,   49,  167,   14,  192,
 /*   870 */   167,   61,   47,  171,    1,    2,    3,    4,    5,    6,
 /*   880 */     7,    8,    9,   10,   11,   12,   13,   62,   15,   16,
 /*   890 */    17,   18,   19,   20,   21,   22,   23,   24,   25,   26,
 /*   900 */    27,   28,   29,   30,   31,   32,   33,   34,   35,   36,
 /*   910 */    37,   38,   39,   40,  177,  173,  205,  205,  205,  188,
 /*   920 */    47,  173,    1,    2,    3,    4,    5,    6,    7,    8,
 /*   930 */     9,   10,   11,   12,   13,   62,   15,   16,   17,   18,
 /*   940 */    19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*   950 */    29,   30,   31,   32,   33,   34,   35,   36,   37,   38,
 /*   960 */    39,   40,   44,   62,   61,   45,   54,   54,   47,   53,
 /*   970 */     1,    2,    3,    4,    5,    6,    7,    8,    9,   10,
 /*   980 */    11,   12,   13,   62,   15,   16,   17,   18,   19,   20,
 /*   990 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*  1000 */    31,   32,   33,   34,   35,   36,   37,   38,   39,   40,
 /*  1010 */    49,   65,   47,   47,   66,   66,   47,   49,    1,    2,
 /*  1020 */     3,    4,    5,    6,    7,    8,    9,   10,   11,   12,
 /*  1030 */    13,   62,   15,   16,   17,   18,   19,   20,   21,   22,
 /*  1040 */    23,   24,   25,   26,   27,   28,   29,   30,   31,   32,
 /*  1050 */    33,   34,   35,   36,   37,   38,   39,   40,  170,  171,
 /*  1060 */   169,  170,  171,   49,   47,   66,    1,    2,    3,    4,
 /*  1070 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*  1080 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /*  1090 */    25,   26,   27,   28,   29,   30,   31,   32,   33,   34,
 /*  1100 */    35,   36,   37,   38,   39,   40,   56,   57,   58,  171,
 /*  1110 */    60,   45,   47,   61,   45,   65,   65,   62,   61,   69,
 /*  1120 */    45,   62,  234,  235,  236,  234,  235,  236,   50,  112,
 /*  1130 */   242,    1,    2,    3,    4,    5,    6,    7,    8,    9,
 /*  1140 */    10,   11,   12,   13,   66,   15,   16,   17,   18,   19,
 /*  1150 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*  1160 */    30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
 /*  1170 */    40,   61,  234,  235,  236,   62,   45,   47,   61,    1,
 /*  1180 */     2,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*  1190 */    12,   13,   62,   15,   16,   17,   18,   19,   20,   21,
 /*  1200 */    22,   23,   24,   25,   26,   27,   28,   29,   30,   31,
 /*  1210 */    32,   33,   34,   35,   36,   37,   38,   39,   40,   45,
 /*  1220 */    54,   49,    1,   54,   66,   47,   50,   49,   65,    1,
 /*  1230 */     2,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*  1240 */    12,   13,  171,   15,   16,   17,   18,   19,   20,   21,
 /*  1250 */    22,   23,   24,   25,   26,   27,   28,   29,   30,   31,
 /*  1260 */    32,   33,   34,   35,   36,   37,   38,   39,   40,   50,
 /*  1270 */    50,    1,   45,  151,   13,   47,   15,   16,   17,   18,
 /*  1280 */    19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*  1290 */    29,   30,   31,   32,   33,   34,   35,   36,   37,   38,
 /*  1300 */    39,   40,   44,  170,  171,  234,  235,  236,   47,  154,
 /*  1310 */   155,   53,   54,  170,  171,   14,   45,  170,  171,  164,
 /*  1320 */   165,   49,   64,   26,   27,   28,   29,   30,   31,   32,
 /*  1330 */    33,   34,   35,   36,   37,   38,   39,   40,  183,  184,
 /*  1340 */   185,  208,   21,   49,   47,   87,   88,   89,   90,   91,
 /*  1350 */    92,   93,   94,   95,   96,   97,   98,   99,  100,  101,
 /*  1360 */   102,  103,   50,  105,  106,   44,   49,  234,  235,  236,
 /*  1370 */   237,  238,   45,   50,   62,  193,   45,  234,  235,  236,
 /*  1380 */   225,  234,  235,  236,  154,  242,  128,  129,  130,   66,
 /*  1390 */    45,   65,   49,  250,    1,   49,  214,  215,  216,  217,
 /*  1400 */   170,  171,  220,   16,   17,   18,   19,   20,   21,   22,
 /*  1410 */    23,   24,   25,   26,   27,   28,   29,   30,   31,   32,
 /*  1420 */    33,   34,   35,   36,   37,   38,   39,   40,  193,  154,
 /*  1430 */   171,   54,  170,  171,   47,    0,   50,  112,   33,   34,
 /*  1440 */    33,   34,    1,  213,   49,  170,  171,   65,   62,  214,
 /*  1450 */   215,  216,  217,  193,   49,  220,   49,  182,   46,   54,
 /*  1460 */    50,   54,  112,   49,  234,  235,  236,   54,  193,   49,
 /*  1470 */   208,   66,   62,   66,  214,  215,  216,  217,   49,   62,
 /*  1480 */   205,   50,  207,   48,  112,   21,   51,   52,   53,  214,
 /*  1490 */   215,  216,  217,  234,  235,  236,  234,  235,  236,  237,
 /*  1500 */   238,  171,   20,   68,   50,   70,   71,   21,   20,  234,
 /*  1510 */   235,  236,  170,  171,  239,  240,  241,  242,  243,  244,
 /*  1520 */   245,  246,  247,  248,   20,   54,  251,   17,   18,   19,
 /*  1530 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*  1540 */    30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
 /*  1550 */    40,  170,  171,   21,   21,  213,   54,   47,  154,  171,
 /*  1560 */     1,  193,   66,   65,  234,  235,  236,  170,  171,   54,
 /*  1570 */   170,  171,  154,   45,  170,  171,  234,  235,  236,   33,
 /*  1580 */    34,   62,  214,  215,  216,  217,  182,   21,   42,   43,
 /*  1590 */    44,   45,  170,  171,  213,   49,  178,  193,  170,  171,
 /*  1600 */    54,   54,   20,  170,  171,   62,   54,   61,   47,   61,
 /*  1610 */   213,  207,   14,  213,    1,  234,  235,  236,  214,  215,
 /*  1620 */   216,  217,  234,  235,  236,   79,   54,  209,  210,  211,
 /*  1630 */   212,  234,  235,  236,  234,  235,  236,  154,  234,  235,
 /*  1640 */   236,  213,   66,  239,  240,  241,  242,  243,  244,  245,
 /*  1650 */   246,  247,  248,  170,  171,  251,  234,  235,  236,   54,
 /*  1660 */    50,   54,  234,  235,  236,  182,   50,  234,  235,  236,
 /*  1670 */    50,   49,   14,  254,  254,  154,  193,  131,  132,  133,
 /*  1680 */   134,  135,  136,  137,  138,  139,  140,  141,  205,   54,
 /*  1690 */   254,  170,  171,  254,  254,  254,  254,  214,  215,  216,
 /*  1700 */   217,  254,  254,  182,  254,  254,  254,  254,  254,  254,
 /*  1710 */   170,  171,  254,  254,  193,  170,  171,  234,  235,  236,
 /*  1720 */   170,  171,  239,  240,  241,  242,  243,  244,  245,  246,
 /*  1730 */   247,  248,  170,  171,  251,  214,  215,  216,  217,  254,
 /*  1740 */   254,  155,  254,  170,  171,  254,  254,  254,  254,  254,
 /*  1750 */   164,  165,  254,  213,  254,  234,  235,  236,  254,  254,
 /*  1760 */   239,  240,  241,  242,  243,  244,  245,  246,  247,  248,
 /*  1770 */   254,  185,  251,  154,  234,  235,  236,  254,  254,  234,
 /*  1780 */   235,  236,  170,  171,  234,  235,  236,  254,  254,  170,
 /*  1790 */   171,  254,  254,  254,   33,   34,  234,  235,  236,  254,
 /*  1800 */   254,  182,  254,   42,   43,  254,   45,  234,  235,  236,
 /*  1810 */    49,  225,  193,  254,  254,   54,  254,  170,  171,  254,
 /*  1820 */   170,  171,   61,  170,  171,  254,  254,  254,  254,  254,
 /*  1830 */   254,  254,  254,  214,  215,  216,  217,  254,  254,  254,
 /*  1840 */    79,  254,  254,  254,  254,  254,  234,  235,  236,  254,
 /*  1850 */   254,  254,  154,  234,  235,  236,  170,  171,  239,  240,
 /*  1860 */   241,  242,  243,  244,  245,  246,  247,  248,  170,  171,
 /*  1870 */   251,  254,  254,  254,  254,  254,  254,  254,  254,  254,
 /*  1880 */   182,  234,  235,  236,  234,  235,  236,  234,  235,  236,
 /*  1890 */   154,  193,  131,  132,  133,  134,  135,  136,  137,  138,
 /*  1900 */   139,  140,  141,  170,  171,  254,  170,  171,  254,  254,
 /*  1910 */   254,  254,  214,  215,  216,  217,  254,  254,  182,  254,
 /*  1920 */   234,  235,  236,  254,  254,  254,  170,  171,  254,  193,
 /*  1930 */   254,  254,  234,  235,  236,  170,  171,  239,  240,  241,
 /*  1940 */   242,  243,  244,  245,  246,  247,  248,  170,  171,  251,
 /*  1950 */   214,  215,  216,  217,  254,  254,  254,  254,  254,  254,
 /*  1960 */   170,  171,  254,  254,  254,  254,  254,  234,  235,  236,
 /*  1970 */   234,  235,  236,  254,  254,  239,  240,  241,  242,  243,
 /*  1980 */   244,  245,  246,  247,  248,  254,  254,  251,  154,  254,
 /*  1990 */   234,  235,  236,  170,  171,  254,  254,  254,  254,  234,
 /*  2000 */   235,  236,  254,  254,  170,  171,  254,  254,  254,   33,
 /*  2010 */    34,  234,  235,  236,  254,  254,  182,  254,   42,   43,
 /*  2020 */   254,   45,  254,  254,  234,  235,  236,  193,  254,   53,
 /*  2030 */    54,  254,  170,  171,  254,  170,  171,   61,  170,  171,
 /*  2040 */   254,  254,  254,  254,  254,  254,  254,  254,  214,  215,
 /*  2050 */   216,  217,  254,  254,  254,   79,  254,  234,  235,  236,
 /*  2060 */   170,  171,  254,  254,  254,  254,  254,  154,  234,  235,
 /*  2070 */   236,  170,  171,  239,  240,  241,  242,  243,  244,  245,
 /*  2080 */   246,  247,  248,  170,  171,  251,  254,  254,  254,  254,
 /*  2090 */   254,  254,  254,  254,  254,  182,  234,  235,  236,  234,
 /*  2100 */   235,  236,  234,  235,  236,  154,  193,  131,  132,  133,
 /*  2110 */   134,  135,  136,  137,  138,  139,  140,  141,  170,  171,
 /*  2120 */   254,  170,  171,  254,  234,  235,  236,  214,  215,  216,
 /*  2130 */   217,  254,  254,  182,  254,  234,  235,  236,  254,  170,
 /*  2140 */   171,  254,  254,  254,  193,  254,  254,  234,  235,  236,
 /*  2150 */   254,  254,  239,  240,  241,  242,  243,  244,  245,  246,
 /*  2160 */   247,  248,  254,  254,  251,  214,  215,  216,  217,  254,
 /*  2170 */   254,  254,  254,  254,  254,  254,  254,  254,  254,  254,
 /*  2180 */   254,  254,  234,  235,  236,  234,  235,  236,  254,  254,
 /*  2190 */   239,  240,  241,  242,  243,  244,  245,  246,  247,  248,
 /*  2200 */   254,  254,  251,  234,  235,  236,   20,   21,   22,   23,
 /*  2210 */    24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
 /*  2220 */    34,   35,   36,   37,   38,   39,   40,   33,   34,  170,
 /*  2230 */   171,  254,  254,   47,  254,  254,   42,   43,  254,   45,
 /*  2240 */    33,   34,  254,  254,  170,  171,  254,  254,   54,   42,
 /*  2250 */    43,  254,   45,   33,   34,   61,  254,  254,  254,   65,
 /*  2260 */   254,   54,   42,   43,  254,   45,  254,  193,   61,  254,
 /*  2270 */   254,  254,  254,   79,   54,  254,  254,  254,  254,  254,
 /*  2280 */   254,   61,  254,  254,  254,  254,   79,  254,  214,  215,
 /*  2290 */   216,  217,  254,  234,  235,  236,  254,  254,  254,   79,
 /*  2300 */   170,  171,  254,  254,  170,  171,  254,  254,  234,  235,
 /*  2310 */   236,  170,  171,  254,  254,  254,  242,  254,  170,  171,
 /*  2320 */   254,  247,  254,  249,  250,  131,  132,  133,  134,  135,
 /*  2330 */   136,  137,  138,  139,  140,  141,  170,  171,  131,  132,
 /*  2340 */   133,  134,  135,  136,  137,  138,  139,  140,  141,  254,
 /*  2350 */   254,  131,  132,  133,  134,  135,  136,  137,  138,  139,
 /*  2360 */   140,  141,  170,  171,  234,  235,  236,  254,  234,  235,
 /*  2370 */   236,  254,  254,  170,  171,  234,  235,  236,  170,  171,
 /*  2380 */   254,  254,  234,  235,  236,  170,  171,  254,  170,  171,
 /*  2390 */   254,  170,  171,  254,  170,  171,  254,  170,  171,  254,
 /*  2400 */   234,  235,  236,  254,  170,  171,  254,  170,  171,  254,
 /*  2410 */   170,  171,  254,  254,  254,  170,  171,  254,  254,  170,
 /*  2420 */   171,  254,  254,  170,  171,  254,  234,  235,  236,  254,
 /*  2430 */   170,  171,  254,  170,  171,  254,  254,  234,  235,  236,
 /*  2440 */   254,  254,  234,  235,  236,  170,  171,  254,  254,  234,
 /*  2450 */   235,  236,  234,  235,  236,  234,  235,  236,  234,  235,
 /*  2460 */   236,  234,  235,  236,  170,  171,  254,  254,  234,  235,
 /*  2470 */   236,  234,  235,  236,  234,  235,  236,  254,  254,  234,
 /*  2480 */   235,  236,  254,  234,  235,  236,  254,  234,  235,  236,
 /*  2490 */   170,  171,  254,  254,  234,  235,  236,  234,  235,  236,
 /*  2500 */   170,  171,  254,  170,  171,  254,  170,  171,  254,  234,
 /*  2510 */   235,  236,  170,  171,  254,  170,  171,  254,  170,  171,
 /*  2520 */   254,  254,  170,  171,  254,  170,  171,  254,  234,  235,
 /*  2530 */   236,  170,  171,  254,  170,  171,  254,  254,  254,  254,
 /*  2540 */   254,  254,  254,  254,  254,  254,  254,  254,  254,  254,
 /*  2550 */   254,  254,  254,  254,  234,  235,  236,  254,  254,  254,
 /*  2560 */   254,  254,  254,  254,  234,  235,  236,  234,  235,  236,
 /*  2570 */   234,  235,  236,  254,  254,  254,  234,  235,  236,  234,
 /*  2580 */   235,  236,  234,  235,  236,  254,  234,  235,  236,  234,
 /*  2590 */   235,  236,  254,  254,  254,  234,  235,  236,  234,  235,
 /*  2600 */   236,
};
#define YY_SHIFT_USE_DFLT (2601)
#define YY_SHIFT_COUNT    (361)
#define YY_SHIFT_MIN      (-44)
#define YY_SHIFT_MAX      (2220)
static const short yy_shift_ofst[] = {
 /*     0 */  2601,  231,  -33,  231,   99,  231,  231,  231,  231,  231,
 /*    10 */   231,  537,  452,  219,  338, 2207, 2207, 2207,  -23, 2220,
 /*    20 */  2220, 2207, 1435,  253,  253,  253,  253, 1546, 1761, 1976,
 /*    30 */  2220, 2220, 2220, 2220, 2220, 2220, 2220, 1405, 1258,  253,
 /*    40 */  2194, 2220, 2220, 2220, 2220, 2220, 2220, 2220, 2220, 2220,
 /*    50 */  2220, 2220, 2220, 2220, 2220, 2220, 2220, 2220, 2220, 2220,
 /*    60 */  2220, 2220, 2220, 2220, 2220, 2220, 2220, 2220, 2220, 2220,
 /*    70 */  2220, 2220, 2220, 2220, 2220, 2220, 2220, 2220, 2220, 2220,
 /*    80 */  2220, 2220, 2220, 2220, 2220, 2220, 2220, 2220, 2220, 2220,
 /*    90 */  2220, 2220, 2220, 2220, 2220, 2220, 2220, 2220, 2220, 2220,
 /*   100 */  1407,  502, 2220, 2220, 2220, 2220, 2220, 2220, 2220, 2220,
 /*   110 */   184,  120,   17,   39,   69,  218,  262,  104,  -44,  -30,
 /*   120 */    93,  -44,   97, 2601, 1228,  133,  -15,  -15,  -15,  202,
 /*   130 */   400,  273,  244,  339,  339,  496,  339,  339,  339,  339,
 /*   140 */   610,  607,  601,  675,  672,  675,  717,   93,  705,  -44,
 /*   150 */   -44,  339,  800,  339,   39,  775,  817,  854,  817,  810,
 /*   160 */  2601, 2601, 2601, 2601, 2601, 2601, 2601,  464,  527,  678,
 /*   170 */   726,  777,  825,  873,  921,  969, 1017, 1065, 1130, 1178,
 /*   180 */  1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
 /*   190 */  1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228, 1228,
 /*   200 */  1228, 1228, 1228, 1261, 1387, 1510, 2186, 2186, 2186, 1297,
 /*   210 */  1297, 1297, 1297, 1297, 1297,   47,  179,  575,  614,   88,
 /*   220 */    88,   88,    2,    2,  360, 1050,  463,  251,  -22,  374,
 /*   230 */   525,  533,   81, 1312,  543,  340,  475,  547,  526,  553,
 /*   240 */  1078, 1323,  723,  337, 1321,  665, 1386, 1410,  -25,  -25,
 /*   250 */   -25,  -25,  -25,  918,  901,  903,  920,  918,  912,  913,
 /*   260 */   916,  918,  918,  961,  946,  965,  966,  968, 1014,  948,
 /*   270 */   949,  999, 1052, 1066, 1069, 1051, 1055, 1057, 1075, 1059,
 /*   280 */  1110, 1131, 1113, 1117, 1174, 1166, 1172, 1221, 1169, 1176,
 /*   290 */  1219, 1158, 1163, 1220, 1270, 1301, 1227, 1271, 1122, 1272,
 /*   300 */  1294, 1327, 1331, 1345,  607, 1317, 1343, 1346, 1326, 1393,
 /*   310 */  1377, 1325, 1395, 1382, 1441, 1350, 1412, 1414, 1420, 1429,
 /*   320 */  1413, 1417, 1431, 1372, 1464, 1482, 1486, 1454, 1488, 1504,
 /*   330 */   918, 1532, 1471, 1533, 1488, 1502, 1559, 1496, 1498, 1515,
 /*   340 */  1528, 1519, 1566, 1547, 1582, 1543, 1552, 1561, 1548, 1598,
 /*   350 */  1613, 1572, 1576, 1605, 1610, 1607, 1616, 1620, 1622, 1658,
 /*   360 */  1635, 1548,
};
#define YY_REDUCE_USE_DFLT (-184)
#define YY_REDUCE_COUNT (166)
#define YY_REDUCE_MIN   (-183)
#define YY_REDUCE_MAX   (2364)
static const short yy_reduce_ofst[] = {
 /*     0 */   245, 1275, 1404, 1483, 1521, 1619, 1698, 1736, 1834, 1913,
 /*    10 */  1951, 2074, -129, -129,  -47,  -79, 1133, 1262, 1155, 1230,
 /*    20 */  1143,  429, -158,  194,  403, 1182, 1235, 1342, 1381,  487,
 /*    30 */   888, 1397, 1400, -146, 1428, 1540,  891, 1418, 1260, 1368,
 /*    40 */  1147, 1422, 1433, 1545, 1550, 1562, 1573, 1612, 1647, 1650,
 /*    50 */  1653, 1686, 1733, 1756, 1765, 1777, 1790, 1823, 1862, 1865,
 /*    60 */  1868, 1890, 1901, 1948, 1969, 2059, 2130, 2134, 2141, 2148,
 /*    70 */  2166, 2192, 2203, 2208, 2215, 2218, 2221, 2224, 2227, 2234,
 /*    80 */  2237, 2240, 2245, 2249, 2253, 2260, 2263, 2275, 2294, 2320,
 /*    90 */  2330, 2333, 2336, 2342, 2345, 2348, 2352, 2355, 2361, 2364,
 /*   100 */   101, 1586,   35,  214,  350,  938, 1071, 1259, 1330, 1388,
 /*   110 */   -59,  -52,  288,  -14,   27, -183,  -92,    6,    6,   21,
 /*   120 */    86,  166,  226,  203,  -42,  -27,    4,   79,   89,   90,
 /*   130 */   112,   68,  185,  222,  269,  302,  335,  349,  391,  443,
 /*   140 */   376,  455,  486,  520,  581,  566,  545,  519,  591,  112,
 /*   150 */   112,  641,  600,  644,  632,  671,  700,  677,  703,  702,
 /*   160 */   737,  742,  711,  712,  713,  731,  748,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */   948, 1016, 1291, 1016, 1291, 1291, 1291, 1291, 1291, 1291,
 /*    10 */  1291, 1241, 1105, 1105, 1291, 1202, 1202, 1202, 1105, 1291,
 /*    20 */  1241, 1202, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*    30 */  1291, 1291, 1291,  956, 1291, 1291,  956, 1291, 1291, 1291,
 /*    40 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*    50 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*    60 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*    70 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*    80 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*    90 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*   100 */  1291, 1105, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*   110 */  1291, 1136, 1291, 1008, 1291, 1047, 1252, 1102, 1102, 1136,
 /*   120 */  1291, 1271, 1291, 1017, 1033, 1291, 1030, 1030, 1030, 1291,
 /*   130 */  1253, 1291, 1291, 1291, 1291,  961, 1291, 1291, 1291, 1291,
 /*   140 */  1049, 1016, 1291, 1012, 1291, 1012, 1291, 1291, 1127, 1103,
 /*   150 */  1093, 1291, 1089, 1291, 1263, 1262, 1260, 1004, 1260, 1291,
 /*   160 */   963,  976, 1016, 1016, 1016,  990,  976, 1291, 1291, 1291,
 /*   170 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*   180 */  1031, 1135, 1254, 1250, 1200, 1282, 1233, 1264, 1010, 1204,
 /*   190 */  1197, 1196, 1195, 1194, 1193, 1192, 1191, 1190, 1189, 1188,
 /*   200 */  1187, 1186, 1203, 1199, 1185, 1184, 1180, 1179, 1178, 1177,
 /*   210 */  1176, 1175, 1174, 1173, 1172, 1171, 1183, 1182, 1181, 1170,
 /*   220 */  1169, 1168, 1160, 1161,  960, 1291, 1280, 1291, 1291, 1291,
 /*   230 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*   240 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1167, 1166,
 /*   250 */  1164, 1163, 1162,  962, 1291, 1291, 1291,  968, 1291, 1291,
 /*   260 */  1291, 1061, 1060, 1291, 1291, 1291,  970, 1291, 1291, 1291,
 /*   270 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*   280 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1134, 1291, 1277,
 /*   290 */  1240, 1291, 1291, 1251, 1291, 1291, 1291, 1291, 1244, 1291,
 /*   300 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*   310 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*   320 */  1140, 1291, 1273, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*   330 */  1085, 1291, 1291, 1291, 1118, 1291, 1009, 1291, 1291, 1291,
 /*   340 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1165, 1285, 1140,
 /*   350 */  1291, 1291, 1291, 1291,  988, 1291, 1291,  987, 1291, 1291,
 /*   360 */  1291,  957,
};
/********** End of lemon-generated parsing tables *****************************/

/* The next table maps tokens (terminal symbols) into fallback tokens.  
** If a construct like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
**
** This feature can be used, for example, to cause some keywords in a language
** to revert to identifiers if they keyword does not apply in the context where
** it appears.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
    0,  /*          $ => nothing */
    0,  /*         EQ => nothing */
    0,  /*      MULEQ => nothing */
    0,  /*      DIVEQ => nothing */
    0,  /*      MODEQ => nothing */
    0,  /*      ADDEQ => nothing */
    0,  /*      SUBEQ => nothing */
    0,  /*      LSHEQ => nothing */
    0,  /*      RSHEQ => nothing */
    0,  /*      ANDEQ => nothing */
    0,  /*       OREQ => nothing */
    0,  /*      XOREQ => nothing */
    0,  /*     URSHEQ => nothing */
    0,  /*   QUESTION => nothing */
    0,  /*      COLON => nothing */
    0,  /*       OROR => nothing */
    0,  /*     ANDAND => nothing */
    0,  /*       EQEQ => nothing */
    0,  /*        NEQ => nothing */
    0,  /*   APPROXEQ => nothing */
    0,  /*         LT => nothing */
    0,  /*         GT => nothing */
    0,  /*       LTEQ => nothing */
    0,  /*       GTEQ => nothing */
    0,  /*     LTGTEQ => nothing */
    0,  /*         IS => nothing */
    0,  /*     DOTDOT => nothing */
    0,  /*         OR => nothing */
    0,  /*        XOR => nothing */
    0,  /*        AND => nothing */
    0,  /*        LSH => nothing */
    0,  /*        RSH => nothing */
    0,  /*       URSH => nothing */
    0,  /*        SUB => nothing */
    0,  /*        ADD => nothing */
    0,  /*        MUL => nothing */
    0,  /*        DIV => nothing */
    0,  /*        MOD => nothing */
    0,  /*  CROSSPROD => nothing */
    0,  /*    DOTPROD => nothing */
    0,  /*        POW => nothing */
    0,  /*      UNARY => nothing */
    0,  /*     ADDADD => nothing */
    0,  /*     SUBSUB => nothing */
    0,  /*        DOT => nothing */
    0,  /*     LPAREN => nothing */
    0,  /*   LBRACKET => nothing */
    0,  /*      SCOPE => nothing */
    0,  /*        EOF => nothing */
    0,  /*  SEMICOLON => nothing */
    0,  /*      COMMA => nothing */
    0,  /*    INCLUDE => nothing */
    0,  /*     EXTEND => nothing */
    0,  /*      CLASS => nothing */
    0,  /* IDENTIFIER => nothing */
    0,  /*   ABSTRACT => nothing */
    0,  /*     NATIVE => nothing */
    0,  /*         UI => nothing */
    0,  /*       PLAY => nothing */
    0,  /*   REPLACES => nothing */
    0,  /*    VERSION => nothing */
    0,  /*   STRCONST => nothing */
    0,  /*     RPAREN => nothing */
   54,  /*    DEFAULT => IDENTIFIER */
   54,  /*      COLOR => IDENTIFIER */
    0,  /*     LBRACE => nothing */
    0,  /*     RBRACE => nothing */
   54,  /*   PROPERTY => IDENTIFIER */
    0,  /*     STRUCT => nothing */
    0,  /* CLEARSCOPE => nothing */
    0,  /*      CONST => nothing */
    0,  /*       ENUM => nothing */
    0,  /*     STATES => nothing */
    0,  /*        NWS => nothing */
    0,  /*       STOP => nothing */
    0,  /*       WAIT => nothing */
    0,  /*       FAIL => nothing */
    0,  /*       LOOP => nothing */
    0,  /*       GOTO => nothing */
    0,  /*      SUPER => nothing */
    0,  /*     BRIGHT => nothing */
    0,  /*       FAST => nothing */
    0,  /*       SLOW => nothing */
    0,  /*    NODELAY => nothing */
    0,  /*   CANRAISE => nothing */
    0,  /*     OFFSET => nothing */
    0,  /*      LIGHT => nothing */
   54,  /*      SBYTE => IDENTIFIER */
   54,  /*       BYTE => IDENTIFIER */
   54,  /*      SHORT => IDENTIFIER */
   54,  /*     USHORT => IDENTIFIER */
   54,  /*        INT => IDENTIFIER */
   54,  /*       UINT => IDENTIFIER */
   54,  /*       BOOL => IDENTIFIER */
   54,  /*      FLOAT => IDENTIFIER */
   54,  /*     DOUBLE => IDENTIFIER */
   54,  /*    VECTOR2 => IDENTIFIER */
   54,  /*    VECTOR3 => IDENTIFIER */
   54,  /*       NAME => IDENTIFIER */
   54,  /*      SOUND => IDENTIFIER */
   54,  /*      STATE => IDENTIFIER */
    0,  /*        LET => nothing */
    0,  /*     ATSIGN => nothing */
    0,  /*   READONLY => nothing */
   54,  /*     STRING => IDENTIFIER */
   54,  /*        MAP => IDENTIFIER */
   54,  /*      ARRAY => IDENTIFIER */
   54,  /*       VOID => IDENTIFIER */
   54,  /*      UINT8 => IDENTIFIER */
   54,  /*       INT8 => IDENTIFIER */
   54,  /*     UINT16 => IDENTIFIER */
   54,  /*      INT16 => IDENTIFIER */
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
**
** After the "shift" half of a SHIFTREDUCE action, the stateno field
** actually contains the reduce action for the second half of the
** SHIFTREDUCE.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number, or reduce action in SHIFTREDUCE */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  yyStackEntry *yytos;          /* Pointer to top element of the stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyhwm;                    /* High-water mark of the stack */
#endif
#ifndef YYNOERRORRECOVERY
  int yyerrcnt;                 /* Shifts left before out of the error */
#endif
  ZCCParseARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
  yyStackEntry yystk0;          /* First stack entry */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/* 
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void ZCCParseTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  "$",             "EQ",            "MULEQ",         "DIVEQ",       
  "MODEQ",         "ADDEQ",         "SUBEQ",         "LSHEQ",       
  "RSHEQ",         "ANDEQ",         "OREQ",          "XOREQ",       
  "URSHEQ",        "QUESTION",      "COLON",         "OROR",        
  "ANDAND",        "EQEQ",          "NEQ",           "APPROXEQ",    
  "LT",            "GT",            "LTEQ",          "GTEQ",        
  "LTGTEQ",        "IS",            "DOTDOT",        "OR",          
  "XOR",           "AND",           "LSH",           "RSH",         
  "URSH",          "SUB",           "ADD",           "MUL",         
  "DIV",           "MOD",           "CROSSPROD",     "DOTPROD",     
  "POW",           "UNARY",         "ADDADD",        "SUBSUB",      
  "DOT",           "LPAREN",        "LBRACKET",      "SCOPE",       
  "EOF",           "SEMICOLON",     "COMMA",         "INCLUDE",     
  "EXTEND",        "CLASS",         "IDENTIFIER",    "ABSTRACT",    
  "NATIVE",        "UI",            "PLAY",          "REPLACES",    
  "VERSION",       "STRCONST",      "RPAREN",        "DEFAULT",     
  "COLOR",         "LBRACE",        "RBRACE",        "PROPERTY",    
  "STRUCT",        "CLEARSCOPE",    "CONST",         "ENUM",        
  "STATES",        "NWS",           "STOP",          "WAIT",        
  "FAIL",          "LOOP",          "GOTO",          "SUPER",       
  "BRIGHT",        "FAST",          "SLOW",          "NODELAY",     
  "CANRAISE",      "OFFSET",        "LIGHT",         "SBYTE",       
  "BYTE",          "SHORT",         "USHORT",        "INT",         
  "UINT",          "BOOL",          "FLOAT",         "DOUBLE",      
  "VECTOR2",       "VECTOR3",       "NAME",          "SOUND",       
  "STATE",         "LET",           "ATSIGN",        "READONLY",    
  "STRING",        "MAP",           "ARRAY",         "VOID",        
  "UINT8",         "INT8",          "UINT16",        "INT16",       
  "RBRACKET",      "ACTION",        "DEPRECATED",    "STATIC",      
  "PRIVATE",       "PROTECTED",     "LATENT",        "FINAL",       
  "META",          "TRANSIENT",     "INTERNAL",      "VIRTUAL",     
  "OVERRIDE",      "VARARG",        "VIRTUALSCOPE",  "ELLIPSIS",    
  "IN",            "OUT",           "OPTIONAL",      "TILDE",       
  "BANG",          "SIZEOF",        "ALIGNOF",       "INTCONST",    
  "UINTCONST",     "FLOATCONST",    "NAMECONST",     "FALSE",       
  "TRUE",          "NULLPTR",       "STATICCONST",   "CONTINUE",    
  "BREAK",         "RETURN",        "DO",            "FOR",         
  "WHILE",         "UNTIL",         "IF",            "ELSE",        
  "SWITCH",        "CASE",          "error",         "declarator",  
  "declarator_no_fun",  "opt_func_body",  "function_body",  "main",        
  "translation_unit",  "external_declaration",  "class_definition",  "struct_def",  
  "enum_def",      "const_def",     "include_def",   "opt_semicolon",
  "opt_comma",     "opt_expr",      "expr",          "string_constant",
  "class_head",    "class_innards",  "class_member",  "class_body",  
  "class_ancestry",  "class_flags",   "dottable_id",   "property_def",
  "states_def",    "default_def",   "staticarray_statement",  "opt_struct_body",
  "struct_body",   "struct_member",  "identifier_list",  "states_opt",  
  "struct_flags",  "enum_list",     "opt_enum_list",  "enumerator",  
  "enum_type",     "int_type",      "states_body",   "state_line",  
  "state_label",   "state_flow",    "state_flow_type",  "state_goto_offset",
  "state_action",  "state_call",    "state_call_params",  "state_opts",  
  "states_opts",   "scanner_mode",  "light_list",    "statement_list",
  "func_expr_list",  "default_statement_list",  "default_statement",  "property_statement",
  "flag_statement",  "expr_list",     "type_name",     "type_name1",  
  "aggregate_type",  "type",          "type_list",     "type_list_or_void",
  "type_or_array",  "class_restrictor",  "array_size",    "array_size_expr",
  "variables_or_function",  "decl_flags",    "func_params",   "func_const",  
  "variable_list",  "variable_name",  "decl_flag",     "func_param_list",
  "func_param",    "func_param_flags",  "primary",       "unary_expr",  
  "constant",      "func_expr_item",  "named_expr",    "compound_statement",
  "statement",     "labeled_statement",  "expression_statement",  "selection_statement",
  "iteration_statement",  "jump_statement",  "assign_statement",  "local_var",   
  "while_or_until",  "for_init",      "for_bump",      "if_front",    
  "variable_list_with_init",  "var_init",    
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "main ::= translation_unit",
 /*   1 */ "translation_unit ::=",
 /*   2 */ "translation_unit ::= translation_unit external_declaration",
 /*   3 */ "translation_unit ::= error",
 /*   4 */ "external_declaration ::= class_definition",
 /*   5 */ "external_declaration ::= struct_def",
 /*   6 */ "external_declaration ::= enum_def",
 /*   7 */ "external_declaration ::= const_def",
 /*   8 */ "external_declaration ::= include_def",
 /*   9 */ "opt_expr ::=",
 /*  10 */ "include_def ::= INCLUDE string_constant",
 /*  11 */ "class_definition ::= class_head class_body",
 /*  12 */ "class_head ::= EXTEND CLASS IDENTIFIER",
 /*  13 */ "class_head ::= CLASS IDENTIFIER class_ancestry class_flags",
 /*  14 */ "class_ancestry ::=",
 /*  15 */ "class_ancestry ::= COLON dottable_id",
 /*  16 */ "class_flags ::=",
 /*  17 */ "class_flags ::= class_flags ABSTRACT",
 /*  18 */ "class_flags ::= class_flags NATIVE",
 /*  19 */ "class_flags ::= class_flags UI",
 /*  20 */ "class_flags ::= class_flags PLAY",
 /*  21 */ "class_flags ::= class_flags REPLACES dottable_id",
 /*  22 */ "class_flags ::= class_flags VERSION LPAREN STRCONST RPAREN",
 /*  23 */ "dottable_id ::= IDENTIFIER",
 /*  24 */ "dottable_id ::= dottable_id DOT IDENTIFIER",
 /*  25 */ "dottable_id ::= dottable_id DOT DEFAULT",
 /*  26 */ "dottable_id ::= dottable_id DOT COLOR",
 /*  27 */ "class_body ::= SEMICOLON class_innards EOF",
 /*  28 */ "class_body ::= LBRACE class_innards RBRACE",
 /*  29 */ "class_innards ::=",
 /*  30 */ "class_innards ::= class_innards class_member",
 /*  31 */ "class_member ::= declarator",
 /*  32 */ "class_member ::= enum_def",
 /*  33 */ "class_member ::= struct_def",
 /*  34 */ "class_member ::= states_def",
 /*  35 */ "class_member ::= default_def",
 /*  36 */ "class_member ::= const_def",
 /*  37 */ "class_member ::= property_def",
 /*  38 */ "class_member ::= staticarray_statement",
 /*  39 */ "property_def ::= PROPERTY IDENTIFIER COLON identifier_list SEMICOLON",
 /*  40 */ "identifier_list ::= IDENTIFIER",
 /*  41 */ "identifier_list ::= states_opt COMMA IDENTIFIER",
 /*  42 */ "struct_def ::= STRUCT IDENTIFIER struct_flags LBRACE opt_struct_body RBRACE opt_semicolon",
 /*  43 */ "struct_flags ::=",
 /*  44 */ "struct_flags ::= struct_flags UI",
 /*  45 */ "struct_flags ::= struct_flags PLAY",
 /*  46 */ "struct_flags ::= struct_flags CLEARSCOPE",
 /*  47 */ "struct_flags ::= struct_flags NATIVE",
 /*  48 */ "struct_flags ::= struct_flags VERSION LPAREN STRCONST RPAREN",
 /*  49 */ "opt_struct_body ::=",
 /*  50 */ "opt_struct_body ::= error",
 /*  51 */ "struct_body ::= struct_body struct_member",
 /*  52 */ "struct_member ::= declarator",
 /*  53 */ "struct_member ::= enum_def",
 /*  54 */ "struct_member ::= const_def",
 /*  55 */ "const_def ::= CONST IDENTIFIER EQ expr SEMICOLON",
 /*  56 */ "enum_def ::= ENUM IDENTIFIER enum_type LBRACE opt_enum_list RBRACE opt_semicolon",
 /*  57 */ "enum_type ::=",
 /*  58 */ "enum_type ::= COLON int_type",
 /*  59 */ "enum_list ::= error",
 /*  60 */ "enum_list ::= enum_list COMMA enumerator",
 /*  61 */ "opt_enum_list ::=",
 /*  62 */ "enumerator ::= IDENTIFIER",
 /*  63 */ "enumerator ::= IDENTIFIER EQ expr",
 /*  64 */ "states_def ::= STATES states_opts scanner_mode LBRACE states_body RBRACE",
 /*  65 */ "states_opts ::=",
 /*  66 */ "states_opts ::= LPAREN states_opt RPAREN",
 /*  67 */ "states_opt ::= IDENTIFIER",
 /*  68 */ "states_opt ::= states_opt COMMA IDENTIFIER",
 /*  69 */ "scanner_mode ::=",
 /*  70 */ "states_body ::=",
 /*  71 */ "states_body ::= error",
 /*  72 */ "states_body ::= states_body state_line",
 /*  73 */ "states_body ::= states_body state_label",
 /*  74 */ "states_body ::= states_body state_flow",
 /*  75 */ "state_label ::= NWS COLON",
 /*  76 */ "state_flow_type ::= STOP",
 /*  77 */ "state_flow_type ::= WAIT",
 /*  78 */ "state_flow_type ::= FAIL",
 /*  79 */ "state_flow_type ::= LOOP",
 /*  80 */ "state_flow_type ::= GOTO dottable_id state_goto_offset",
 /*  81 */ "state_flow_type ::= GOTO IDENTIFIER SCOPE dottable_id state_goto_offset",
 /*  82 */ "state_flow_type ::= GOTO SUPER SCOPE dottable_id state_goto_offset",
 /*  83 */ "state_goto_offset ::=",
 /*  84 */ "state_goto_offset ::= ADD expr",
 /*  85 */ "state_line ::= NWS NWS expr state_opts state_action",
 /*  86 */ "state_opts ::=",
 /*  87 */ "state_opts ::= state_opts BRIGHT",
 /*  88 */ "state_opts ::= state_opts FAST",
 /*  89 */ "state_opts ::= state_opts SLOW",
 /*  90 */ "state_opts ::= state_opts NODELAY",
 /*  91 */ "state_opts ::= state_opts CANRAISE",
 /*  92 */ "state_opts ::= state_opts OFFSET LPAREN expr COMMA expr RPAREN",
 /*  93 */ "state_opts ::= state_opts LIGHT LPAREN light_list RPAREN",
 /*  94 */ "light_list ::= STRCONST",
 /*  95 */ "light_list ::= light_list COMMA STRCONST",
 /*  96 */ "state_action ::= LBRACE statement_list scanner_mode RBRACE",
 /*  97 */ "state_action ::= LBRACE scanner_mode RBRACE",
 /*  98 */ "state_action ::= LBRACE error scanner_mode RBRACE",
 /*  99 */ "state_action ::= state_call scanner_mode SEMICOLON",
 /* 100 */ "state_call ::=",
 /* 101 */ "state_call ::= IDENTIFIER state_call_params",
 /* 102 */ "state_call_params ::=",
 /* 103 */ "state_call_params ::= LPAREN func_expr_list RPAREN",
 /* 104 */ "default_def ::= DEFAULT LBRACE RBRACE",
 /* 105 */ "default_def ::= DEFAULT LBRACE default_statement_list RBRACE",
 /* 106 */ "default_def ::= DEFAULT LBRACE error RBRACE",
 /* 107 */ "default_statement_list ::= default_statement",
 /* 108 */ "default_statement_list ::= default_statement_list default_statement",
 /* 109 */ "default_statement ::= SEMICOLON",
 /* 110 */ "default_statement ::= error SEMICOLON",
 /* 111 */ "default_statement ::= property_statement",
 /* 112 */ "default_statement ::= flag_statement",
 /* 113 */ "flag_statement ::= ADD dottable_id",
 /* 114 */ "flag_statement ::= SUB dottable_id",
 /* 115 */ "property_statement ::= dottable_id expr_list SEMICOLON",
 /* 116 */ "property_statement ::= dottable_id SEMICOLON",
 /* 117 */ "int_type ::= SBYTE",
 /* 118 */ "int_type ::= BYTE",
 /* 119 */ "int_type ::= SHORT",
 /* 120 */ "int_type ::= USHORT",
 /* 121 */ "int_type ::= INT",
 /* 122 */ "int_type ::= UINT",
 /* 123 */ "type_name1 ::= BOOL",
 /* 124 */ "type_name1 ::= FLOAT",
 /* 125 */ "type_name1 ::= DOUBLE",
 /* 126 */ "type_name1 ::= VECTOR2",
 /* 127 */ "type_name1 ::= VECTOR3",
 /* 128 */ "type_name1 ::= NAME",
 /* 129 */ "type_name1 ::= SOUND",
 /* 130 */ "type_name1 ::= STATE",
 /* 131 */ "type_name1 ::= COLOR",
 /* 132 */ "type_name1 ::= LET",
 /* 133 */ "type_name ::= type_name1",
 /* 134 */ "type_name ::= IDENTIFIER",
 /* 135 */ "type_name ::= ATSIGN IDENTIFIER",
 /* 136 */ "type_name ::= READONLY LT IDENTIFIER GT",
 /* 137 */ "type_name ::= READONLY LT ATSIGN IDENTIFIER GT",
 /* 138 */ "type_name ::= DOT dottable_id",
 /* 139 */ "aggregate_type ::= MAP LT type_or_array COMMA type_or_array GT",
 /* 140 */ "aggregate_type ::= ARRAY LT type_or_array GT",
 /* 141 */ "aggregate_type ::= CLASS class_restrictor",
 /* 142 */ "class_restrictor ::=",
 /* 143 */ "class_restrictor ::= LT dottable_id GT",
 /* 144 */ "type ::= type_name",
 /* 145 */ "type ::= aggregate_type",
 /* 146 */ "type_or_array ::= type array_size",
 /* 147 */ "type_list ::= type_list COMMA type_or_array",
 /* 148 */ "type_list_or_void ::= VOID",
 /* 149 */ "array_size_expr ::= LBRACKET opt_expr RBRACKET",
 /* 150 */ "array_size ::= array_size array_size_expr",
 /* 151 */ "declarator ::= decl_flags type_list_or_void variables_or_function",
 /* 152 */ "variables_or_function ::= IDENTIFIER LPAREN func_params RPAREN func_const opt_func_body",
 /* 153 */ "variables_or_function ::= variable_list SEMICOLON",
 /* 154 */ "variables_or_function ::= error SEMICOLON",
 /* 155 */ "variable_name ::= IDENTIFIER",
 /* 156 */ "variable_name ::= IDENTIFIER array_size",
 /* 157 */ "variable_list ::= variable_list COMMA variable_name",
 /* 158 */ "decl_flags ::=",
 /* 159 */ "decl_flags ::= decl_flags decl_flag",
 /* 160 */ "decl_flags ::= decl_flags ACTION states_opts",
 /* 161 */ "decl_flags ::= decl_flags DEPRECATED LPAREN STRCONST RPAREN",
 /* 162 */ "decl_flags ::= decl_flags VERSION LPAREN STRCONST RPAREN",
 /* 163 */ "decl_flag ::= NATIVE",
 /* 164 */ "decl_flag ::= STATIC",
 /* 165 */ "decl_flag ::= PRIVATE",
 /* 166 */ "decl_flag ::= PROTECTED",
 /* 167 */ "decl_flag ::= LATENT",
 /* 168 */ "decl_flag ::= FINAL",
 /* 169 */ "decl_flag ::= META",
 /* 170 */ "decl_flag ::= TRANSIENT",
 /* 171 */ "decl_flag ::= READONLY",
 /* 172 */ "decl_flag ::= INTERNAL",
 /* 173 */ "decl_flag ::= VIRTUAL",
 /* 174 */ "decl_flag ::= OVERRIDE",
 /* 175 */ "decl_flag ::= VARARG",
 /* 176 */ "decl_flag ::= UI",
 /* 177 */ "decl_flag ::= PLAY",
 /* 178 */ "decl_flag ::= CLEARSCOPE",
 /* 179 */ "decl_flag ::= VIRTUALSCOPE",
 /* 180 */ "func_const ::=",
 /* 181 */ "func_const ::= CONST",
 /* 182 */ "opt_func_body ::= SEMICOLON",
 /* 183 */ "func_params ::=",
 /* 184 */ "func_params ::= VOID",
 /* 185 */ "func_params ::= func_param_list COMMA ELLIPSIS",
 /* 186 */ "func_param_list ::= func_param_list COMMA func_param",
 /* 187 */ "func_param ::= func_param_flags type IDENTIFIER",
 /* 188 */ "func_param ::= func_param_flags type IDENTIFIER EQ expr",
 /* 189 */ "func_param_flags ::=",
 /* 190 */ "func_param_flags ::= func_param_flags IN",
 /* 191 */ "func_param_flags ::= func_param_flags OUT",
 /* 192 */ "func_param_flags ::= func_param_flags OPTIONAL",
 /* 193 */ "primary ::= IDENTIFIER",
 /* 194 */ "primary ::= SUPER",
 /* 195 */ "primary ::= constant",
 /* 196 */ "primary ::= LPAREN expr COMMA expr COMMA expr RPAREN",
 /* 197 */ "primary ::= LPAREN expr COMMA expr RPAREN",
 /* 198 */ "primary ::= LPAREN expr RPAREN",
 /* 199 */ "primary ::= primary LPAREN func_expr_list RPAREN",
 /* 200 */ "primary ::= LPAREN CLASS LT IDENTIFIER GT RPAREN LPAREN func_expr_list RPAREN",
 /* 201 */ "primary ::= primary LBRACKET expr RBRACKET",
 /* 202 */ "primary ::= primary DOT IDENTIFIER",
 /* 203 */ "primary ::= primary ADDADD",
 /* 204 */ "primary ::= primary SUBSUB",
 /* 205 */ "unary_expr ::= SUB unary_expr",
 /* 206 */ "unary_expr ::= ADD unary_expr",
 /* 207 */ "unary_expr ::= SUBSUB unary_expr",
 /* 208 */ "unary_expr ::= ADDADD unary_expr",
 /* 209 */ "unary_expr ::= TILDE unary_expr",
 /* 210 */ "unary_expr ::= BANG unary_expr",
 /* 211 */ "unary_expr ::= SIZEOF unary_expr",
 /* 212 */ "unary_expr ::= ALIGNOF unary_expr",
 /* 213 */ "expr ::= expr ADD expr",
 /* 214 */ "expr ::= expr SUB expr",
 /* 215 */ "expr ::= expr MUL expr",
 /* 216 */ "expr ::= expr DIV expr",
 /* 217 */ "expr ::= expr MOD expr",
 /* 218 */ "expr ::= expr POW expr",
 /* 219 */ "expr ::= expr CROSSPROD expr",
 /* 220 */ "expr ::= expr DOTPROD expr",
 /* 221 */ "expr ::= expr LSH expr",
 /* 222 */ "expr ::= expr RSH expr",
 /* 223 */ "expr ::= expr URSH expr",
 /* 224 */ "expr ::= expr DOTDOT expr",
 /* 225 */ "expr ::= expr LT expr",
 /* 226 */ "expr ::= expr GT expr",
 /* 227 */ "expr ::= expr LTEQ expr",
 /* 228 */ "expr ::= expr GTEQ expr",
 /* 229 */ "expr ::= expr LTGTEQ expr",
 /* 230 */ "expr ::= expr IS expr",
 /* 231 */ "expr ::= expr EQEQ expr",
 /* 232 */ "expr ::= expr NEQ expr",
 /* 233 */ "expr ::= expr APPROXEQ expr",
 /* 234 */ "expr ::= expr AND expr",
 /* 235 */ "expr ::= expr XOR expr",
 /* 236 */ "expr ::= expr OR expr",
 /* 237 */ "expr ::= expr ANDAND expr",
 /* 238 */ "expr ::= expr OROR expr",
 /* 239 */ "expr ::= expr EQ expr",
 /* 240 */ "expr ::= expr ADDEQ expr",
 /* 241 */ "expr ::= expr SUBEQ expr",
 /* 242 */ "expr ::= expr MULEQ expr",
 /* 243 */ "expr ::= expr DIVEQ expr",
 /* 244 */ "expr ::= expr MODEQ expr",
 /* 245 */ "expr ::= expr LSHEQ expr",
 /* 246 */ "expr ::= expr RSHEQ expr",
 /* 247 */ "expr ::= expr URSHEQ expr",
 /* 248 */ "expr ::= expr ANDEQ expr",
 /* 249 */ "expr ::= expr OREQ expr",
 /* 250 */ "expr ::= expr XOREQ expr",
 /* 251 */ "expr ::= expr SCOPE expr",
 /* 252 */ "expr ::= expr QUESTION expr COLON expr",
 /* 253 */ "expr_list ::= expr_list COMMA expr",
 /* 254 */ "func_expr_list ::= func_expr_list COMMA func_expr_item",
 /* 255 */ "func_expr_item ::=",
 /* 256 */ "named_expr ::= IDENTIFIER COLON expr",
 /* 257 */ "named_expr ::= expr",
 /* 258 */ "string_constant ::= STRCONST",
 /* 259 */ "string_constant ::= string_constant STRCONST",
 /* 260 */ "constant ::= INTCONST",
 /* 261 */ "constant ::= UINTCONST",
 /* 262 */ "constant ::= FLOATCONST",
 /* 263 */ "constant ::= NAMECONST",
 /* 264 */ "constant ::= FALSE",
 /* 265 */ "constant ::= TRUE",
 /* 266 */ "constant ::= NULLPTR",
 /* 267 */ "statement ::= SEMICOLON",
 /* 268 */ "statement ::= labeled_statement",
 /* 269 */ "statement ::= compound_statement",
 /* 270 */ "statement ::= expression_statement SEMICOLON",
 /* 271 */ "statement ::= assign_statement SEMICOLON",
 /* 272 */ "statement ::= local_var SEMICOLON",
 /* 273 */ "statement ::= error SEMICOLON",
 /* 274 */ "statement ::= staticarray_statement",
 /* 275 */ "staticarray_statement ::= STATICCONST type IDENTIFIER LBRACKET RBRACKET EQ LBRACE expr_list RBRACE SEMICOLON",
 /* 276 */ "staticarray_statement ::= STATICCONST type LBRACKET RBRACKET IDENTIFIER EQ LBRACE expr_list RBRACE SEMICOLON",
 /* 277 */ "jump_statement ::= CONTINUE SEMICOLON",
 /* 278 */ "jump_statement ::= BREAK SEMICOLON",
 /* 279 */ "jump_statement ::= RETURN SEMICOLON",
 /* 280 */ "jump_statement ::= RETURN expr_list SEMICOLON",
 /* 281 */ "compound_statement ::= LBRACE RBRACE",
 /* 282 */ "compound_statement ::= LBRACE statement_list RBRACE",
 /* 283 */ "compound_statement ::= LBRACE error RBRACE",
 /* 284 */ "statement_list ::= statement",
 /* 285 */ "statement_list ::= statement_list statement",
 /* 286 */ "expression_statement ::= expr",
 /* 287 */ "iteration_statement ::= while_or_until LPAREN expr RPAREN statement",
 /* 288 */ "iteration_statement ::= DO statement while_or_until LPAREN expr RPAREN",
 /* 289 */ "iteration_statement ::= FOR LPAREN for_init SEMICOLON opt_expr SEMICOLON for_bump RPAREN statement",
 /* 290 */ "while_or_until ::= WHILE",
 /* 291 */ "while_or_until ::= UNTIL",
 /* 292 */ "for_init ::= local_var",
 /* 293 */ "for_init ::= for_bump",
 /* 294 */ "for_bump ::=",
 /* 295 */ "for_bump ::= expression_statement",
 /* 296 */ "for_bump ::= for_bump COMMA expression_statement",
 /* 297 */ "selection_statement ::= if_front",
 /* 298 */ "selection_statement ::= if_front ELSE statement",
 /* 299 */ "if_front ::= IF LPAREN expr RPAREN statement",
 /* 300 */ "selection_statement ::= SWITCH LPAREN expr RPAREN statement",
 /* 301 */ "labeled_statement ::= CASE expr COLON",
 /* 302 */ "labeled_statement ::= DEFAULT COLON",
 /* 303 */ "assign_statement ::= LBRACKET expr_list RBRACKET EQ expr",
 /* 304 */ "local_var ::= type variable_list_with_init",
 /* 305 */ "var_init ::= IDENTIFIER",
 /* 306 */ "var_init ::= IDENTIFIER array_size",
 /* 307 */ "var_init ::= IDENTIFIER EQ expr",
 /* 308 */ "var_init ::= IDENTIFIER EQ LBRACE expr_list RBRACE",
 /* 309 */ "var_init ::= IDENTIFIER array_size EQ LBRACE expr_list RBRACE",
 /* 310 */ "var_init ::= IDENTIFIER EQ LBRACE error RBRACE",
 /* 311 */ "variable_list_with_init ::= variable_list_with_init COMMA var_init",
 /* 312 */ "translation_unit ::= translation_unit EOF",
 /* 313 */ "opt_semicolon ::=",
 /* 314 */ "opt_semicolon ::= SEMICOLON",
 /* 315 */ "opt_comma ::=",
 /* 316 */ "opt_comma ::= COMMA",
 /* 317 */ "opt_expr ::= expr",
 /* 318 */ "opt_struct_body ::= struct_body",
 /* 319 */ "struct_body ::= struct_member",
 /* 320 */ "enum_list ::= enumerator",
 /* 321 */ "opt_enum_list ::= enum_list opt_comma",
 /* 322 */ "state_flow ::= state_flow_type scanner_mode SEMICOLON",
 /* 323 */ "type_name1 ::= int_type",
 /* 324 */ "type_or_array ::= type",
 /* 325 */ "type_list ::= type_or_array",
 /* 326 */ "type_list_or_void ::= type_list",
 /* 327 */ "array_size ::= array_size_expr",
 /* 328 */ "variable_list ::= variable_name",
 /* 329 */ "opt_func_body ::= function_body",
 /* 330 */ "func_params ::= func_param_list",
 /* 331 */ "func_param_list ::= func_param",
 /* 332 */ "primary ::= LPAREN error RPAREN",
 /* 333 */ "unary_expr ::= primary",
 /* 334 */ "expr ::= unary_expr",
 /* 335 */ "expr_list ::= expr",
 /* 336 */ "func_expr_list ::= func_expr_item",
 /* 337 */ "func_expr_item ::= named_expr",
 /* 338 */ "constant ::= string_constant",
 /* 339 */ "function_body ::= compound_statement",
 /* 340 */ "statement ::= selection_statement",
 /* 341 */ "statement ::= iteration_statement",
 /* 342 */ "statement ::= jump_statement",
 /* 343 */ "variable_list_with_init ::= var_init",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.  Return the number
** of errors.  Return 0 on success.
*/
static int yyGrowStack(yyParser *p){
  int newSize;
  int idx;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  idx = p->yytos ? (int)(p->yytos - p->yystack) : 0;
  if( p->yystack==&p->yystk0 ){
    pNew = (yyStackEntry *)malloc(newSize*sizeof(pNew[0]));
    if( pNew ) pNew[0] = p->yystk0;
  }else{
    pNew = (yyStackEntry *)realloc(p->yystack, newSize*sizeof(pNew[0]));
  }
  if( pNew ){
    p->yystack = pNew;
    p->yytos = &p->yystack[idx];
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows from %d to %d entries.\n",
              yyTracePrompt, p->yystksz, newSize);
      fflush(yyTraceFILE);
    }
#endif
    p->yystksz = newSize;
  }
  return pNew==0; 
}
#endif

/* Datatype of the argument to the memory allocated passed as the
** second argument to ZCCParseAlloc() below.  This can be changed by
** putting an appropriate #define in the %include section of the input
** grammar.
*/
#ifndef YYMALLOCARGTYPE
# define YYMALLOCARGTYPE size_t
#endif

/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to ZCCParse and ZCCParseFree.
*/
void *ZCCParseAlloc(void *(CDECL *mallocProc)(YYMALLOCARGTYPE)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (YYMALLOCARGTYPE)sizeof(yyParser) );
  if( pParser ){
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyhwm = 0;
#endif
#if YYSTACKDEPTH<=0
    pParser->yytos = NULL;
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    if( yyGrowStack(pParser) ){
      pParser->yystack = &pParser->yystk0;
      pParser->yystksz = 1;
    }
#endif
#ifndef YYNOERRORRECOVERY
    pParser->yyerrcnt = -1;
#endif
    pParser->yytos = pParser->yystack;
    pParser->yystack[0].stateno = 0;
    pParser->yystack[0].major = 0;
  }
  return pParser;
}

/* The following function deletes the "minor type" or semantic value
** associated with a symbol.  The symbol can be either a terminal
** or nonterminal. "yymajor" is the symbol code, and "yypminor" is
** a pointer to the value to be deleted.  The code used to do the 
** deletions is derived from the %destructor and/or %token_destructor
** directives of the input grammar.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  ZCCParseARG_FETCH;
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are *not* used
    ** inside the C code.
    */
/********* Begin destructor definitions ***************************************/
      /* TERMINAL Destructor */
    case 1: /* EQ */
    case 2: /* MULEQ */
    case 3: /* DIVEQ */
    case 4: /* MODEQ */
    case 5: /* ADDEQ */
    case 6: /* SUBEQ */
    case 7: /* LSHEQ */
    case 8: /* RSHEQ */
    case 9: /* ANDEQ */
    case 10: /* OREQ */
    case 11: /* XOREQ */
    case 12: /* URSHEQ */
    case 13: /* QUESTION */
    case 14: /* COLON */
    case 15: /* OROR */
    case 16: /* ANDAND */
    case 17: /* EQEQ */
    case 18: /* NEQ */
    case 19: /* APPROXEQ */
    case 20: /* LT */
    case 21: /* GT */
    case 22: /* LTEQ */
    case 23: /* GTEQ */
    case 24: /* LTGTEQ */
    case 25: /* IS */
    case 26: /* DOTDOT */
    case 27: /* OR */
    case 28: /* XOR */
    case 29: /* AND */
    case 30: /* LSH */
    case 31: /* RSH */
    case 32: /* URSH */
    case 33: /* SUB */
    case 34: /* ADD */
    case 35: /* MUL */
    case 36: /* DIV */
    case 37: /* MOD */
    case 38: /* CROSSPROD */
    case 39: /* DOTPROD */
    case 40: /* POW */
    case 41: /* UNARY */
    case 42: /* ADDADD */
    case 43: /* SUBSUB */
    case 44: /* DOT */
    case 45: /* LPAREN */
    case 46: /* LBRACKET */
    case 47: /* SCOPE */
    case 48: /* EOF */
    case 49: /* SEMICOLON */
    case 50: /* COMMA */
    case 51: /* INCLUDE */
    case 52: /* EXTEND */
    case 53: /* CLASS */
    case 54: /* IDENTIFIER */
    case 55: /* ABSTRACT */
    case 56: /* NATIVE */
    case 57: /* UI */
    case 58: /* PLAY */
    case 59: /* REPLACES */
    case 60: /* VERSION */
    case 61: /* STRCONST */
    case 62: /* RPAREN */
    case 63: /* DEFAULT */
    case 64: /* COLOR */
    case 65: /* LBRACE */
    case 66: /* RBRACE */
    case 67: /* PROPERTY */
    case 68: /* STRUCT */
    case 69: /* CLEARSCOPE */
    case 70: /* CONST */
    case 71: /* ENUM */
    case 72: /* STATES */
    case 73: /* NWS */
    case 74: /* STOP */
    case 75: /* WAIT */
    case 76: /* FAIL */
    case 77: /* LOOP */
    case 78: /* GOTO */
    case 79: /* SUPER */
    case 80: /* BRIGHT */
    case 81: /* FAST */
    case 82: /* SLOW */
    case 83: /* NODELAY */
    case 84: /* CANRAISE */
    case 85: /* OFFSET */
    case 86: /* LIGHT */
    case 87: /* SBYTE */
    case 88: /* BYTE */
    case 89: /* SHORT */
    case 90: /* USHORT */
    case 91: /* INT */
    case 92: /* UINT */
    case 93: /* BOOL */
    case 94: /* FLOAT */
    case 95: /* DOUBLE */
    case 96: /* VECTOR2 */
    case 97: /* VECTOR3 */
    case 98: /* NAME */
    case 99: /* SOUND */
    case 100: /* STATE */
    case 101: /* LET */
    case 102: /* ATSIGN */
    case 103: /* READONLY */
    case 104: /* STRING */
    case 105: /* MAP */
    case 106: /* ARRAY */
    case 107: /* VOID */
    case 108: /* UINT8 */
    case 109: /* INT8 */
    case 110: /* UINT16 */
    case 111: /* INT16 */
    case 112: /* RBRACKET */
    case 113: /* ACTION */
    case 114: /* DEPRECATED */
    case 115: /* STATIC */
    case 116: /* PRIVATE */
    case 117: /* PROTECTED */
    case 118: /* LATENT */
    case 119: /* FINAL */
    case 120: /* META */
    case 121: /* TRANSIENT */
    case 122: /* INTERNAL */
    case 123: /* VIRTUAL */
    case 124: /* OVERRIDE */
    case 125: /* VARARG */
    case 126: /* VIRTUALSCOPE */
    case 127: /* ELLIPSIS */
    case 128: /* IN */
    case 129: /* OUT */
    case 130: /* OPTIONAL */
    case 131: /* TILDE */
    case 132: /* BANG */
    case 133: /* SIZEOF */
    case 134: /* ALIGNOF */
    case 135: /* INTCONST */
    case 136: /* UINTCONST */
    case 137: /* FLOATCONST */
    case 138: /* NAMECONST */
    case 139: /* FALSE */
    case 140: /* TRUE */
    case 141: /* NULLPTR */
    case 142: /* STATICCONST */
    case 143: /* CONTINUE */
    case 144: /* BREAK */
    case 145: /* RETURN */
    case 146: /* DO */
    case 147: /* FOR */
    case 148: /* WHILE */
    case 149: /* UNTIL */
    case 150: /* IF */
    case 151: /* ELSE */
    case 152: /* SWITCH */
    case 153: /* CASE */
{
#line 117 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"

#line 1833 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
      break;
/********* End destructor definitions *****************************************/
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
*/
static void yy_pop_parser_stack(yyParser *pParser){
  yyStackEntry *yytos;
  assert( pParser->yytos!=0 );
  assert( pParser->yytos > pParser->yystack );
  yytos = pParser->yytos--;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
    fflush(yyTraceFILE);
  }
#endif
  yy_destructor(pParser, yytos->major, &yytos->minor);
}

/* 
** Deallocate and destroy a parser.  Destructors are called for
** all stack elements before shutting the parser down.
**
** If the YYPARSEFREENEVERNULL macro exists (for example because it
** is defined in a %include section of the input grammar) then it is
** assumed that the input pointer is never NULL.
*/
void ZCCParseFree(
  void *p,                    /* The parser to be deleted */
  void (CDECL *freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
#ifndef YYPARSEFREENEVERNULL
  if( pParser==0 ) return;
#endif
  while( pParser->yytos>pParser->yystack ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  if( pParser->yystack!=&pParser->yystk0 ) free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int ZCCParseStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyhwm;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
*/
static unsigned int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yytos->stateno;
 
  if( stateno>=YY_MIN_REDUCE ) return stateno;
  assert( stateno <= YY_SHIFT_COUNT );
  do{
    i = yy_shift_ofst[stateno];
    assert( iLookAhead!=YYNOCODE );
    i += iLookAhead;
    if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
          fflush(yyTraceFILE);
        }
#endif
        assert( yyFallback[iFallback]==0 ); /* Fallback loop must terminate */
        iLookAhead = iFallback;
        continue;
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( 
#if YY_SHIFT_MIN+YYWILDCARD<0
          j>=0 &&
#endif
#if YY_SHIFT_MAX+YYWILDCARD>=YY_ACTTAB_COUNT
          j<YY_ACTTAB_COUNT &&
#endif
          yy_lookahead[j]==YYWILDCARD && iLookAhead>0
        ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead],
               yyTokenName[YYWILDCARD]);
            fflush(yyTraceFILE);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
      return yy_default[stateno];
    }else{
      return yy_action[i];
    }
  }while(1);
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_COUNT ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_COUNT );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_ACTTAB_COUNT );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser){
   ZCCParseARG_FETCH;
   yypParser->yytos--;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
     fflush(yyTraceFILE);
   }
#endif
   while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
/******** Begin %stack_overflow code ******************************************/
/******** End %stack_overflow code ********************************************/
   ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Print tracing information for a SHIFT action
*/
#ifndef NDEBUG
static void yyTraceShift(yyParser *yypParser, int yyNewState){
  if( yyTraceFILE ){
    if( yyNewState<YYNSTATE ){
      fprintf(yyTraceFILE,"%sShift '%s', go to state %d\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major],
         yyNewState);
    }else{
      fprintf(yyTraceFILE,"%sShift '%s'\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major]);
    }
    fflush(yyTraceFILE);
  }
}
#else
# define yyTraceShift(X,Y)
#endif

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  ZCCParseTOKENTYPE yyMinor        /* The minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yytos++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
    yypParser->yyhwm++;
    assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack) );
  }
#endif
#if YYSTACKDEPTH>0 
  if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH] ){
    yyStackOverflow(yypParser);
    return;
  }
#else
  if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz] ){
    if( yyGrowStack(yypParser) ){
      yyStackOverflow(yypParser);
      return;
    }
  }
#endif
  if( yyNewState > YY_MAX_SHIFT ){
    yyNewState += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
  }
  yytos = yypParser->yytos;
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor.yy0 = yyMinor;
  yyTraceShift(yypParser, yyNewState);
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 159, 1 },
  { 160, 0 },
  { 160, 2 },
  { 160, 1 },
  { 161, 1 },
  { 161, 1 },
  { 161, 1 },
  { 161, 1 },
  { 161, 1 },
  { 169, 0 },
  { 166, 2 },
  { 162, 2 },
  { 172, 3 },
  { 172, 4 },
  { 176, 0 },
  { 176, 2 },
  { 177, 0 },
  { 177, 2 },
  { 177, 2 },
  { 177, 2 },
  { 177, 2 },
  { 177, 3 },
  { 177, 5 },
  { 178, 1 },
  { 178, 3 },
  { 178, 3 },
  { 178, 3 },
  { 175, 3 },
  { 175, 3 },
  { 173, 0 },
  { 173, 2 },
  { 174, 1 },
  { 174, 1 },
  { 174, 1 },
  { 174, 1 },
  { 174, 1 },
  { 174, 1 },
  { 174, 1 },
  { 174, 1 },
  { 179, 5 },
  { 186, 1 },
  { 186, 3 },
  { 163, 7 },
  { 188, 0 },
  { 188, 2 },
  { 188, 2 },
  { 188, 2 },
  { 188, 2 },
  { 188, 5 },
  { 183, 0 },
  { 183, 1 },
  { 184, 2 },
  { 185, 1 },
  { 185, 1 },
  { 185, 1 },
  { 165, 5 },
  { 164, 7 },
  { 192, 0 },
  { 192, 2 },
  { 189, 1 },
  { 189, 3 },
  { 190, 0 },
  { 191, 1 },
  { 191, 3 },
  { 180, 6 },
  { 204, 0 },
  { 204, 3 },
  { 187, 1 },
  { 187, 3 },
  { 205, 0 },
  { 194, 0 },
  { 194, 1 },
  { 194, 2 },
  { 194, 2 },
  { 194, 2 },
  { 196, 2 },
  { 198, 1 },
  { 198, 1 },
  { 198, 1 },
  { 198, 1 },
  { 198, 3 },
  { 198, 5 },
  { 198, 5 },
  { 199, 0 },
  { 199, 2 },
  { 195, 5 },
  { 203, 0 },
  { 203, 2 },
  { 203, 2 },
  { 203, 2 },
  { 203, 2 },
  { 203, 2 },
  { 203, 7 },
  { 203, 5 },
  { 206, 1 },
  { 206, 3 },
  { 200, 4 },
  { 200, 3 },
  { 200, 4 },
  { 200, 3 },
  { 201, 0 },
  { 201, 2 },
  { 202, 0 },
  { 202, 3 },
  { 181, 3 },
  { 181, 4 },
  { 181, 4 },
  { 209, 1 },
  { 209, 2 },
  { 210, 1 },
  { 210, 2 },
  { 210, 1 },
  { 210, 1 },
  { 212, 2 },
  { 212, 2 },
  { 211, 3 },
  { 211, 2 },
  { 193, 1 },
  { 193, 1 },
  { 193, 1 },
  { 193, 1 },
  { 193, 1 },
  { 193, 1 },
  { 215, 1 },
  { 215, 1 },
  { 215, 1 },
  { 215, 1 },
  { 215, 1 },
  { 215, 1 },
  { 215, 1 },
  { 215, 1 },
  { 215, 1 },
  { 215, 1 },
  { 214, 1 },
  { 214, 1 },
  { 214, 2 },
  { 214, 4 },
  { 214, 5 },
  { 214, 2 },
  { 216, 6 },
  { 216, 4 },
  { 216, 2 },
  { 221, 0 },
  { 221, 3 },
  { 217, 1 },
  { 217, 1 },
  { 220, 2 },
  { 218, 3 },
  { 219, 1 },
  { 223, 3 },
  { 222, 2 },
  { 155, 3 },
  { 224, 6 },
  { 224, 2 },
  { 224, 2 },
  { 229, 1 },
  { 229, 2 },
  { 228, 3 },
  { 225, 0 },
  { 225, 2 },
  { 225, 3 },
  { 225, 5 },
  { 225, 5 },
  { 230, 1 },
  { 230, 1 },
  { 230, 1 },
  { 230, 1 },
  { 230, 1 },
  { 230, 1 },
  { 230, 1 },
  { 230, 1 },
  { 230, 1 },
  { 230, 1 },
  { 230, 1 },
  { 230, 1 },
  { 230, 1 },
  { 230, 1 },
  { 230, 1 },
  { 230, 1 },
  { 230, 1 },
  { 227, 0 },
  { 227, 1 },
  { 157, 1 },
  { 226, 0 },
  { 226, 1 },
  { 226, 3 },
  { 231, 3 },
  { 232, 3 },
  { 232, 5 },
  { 233, 0 },
  { 233, 2 },
  { 233, 2 },
  { 233, 2 },
  { 234, 1 },
  { 234, 1 },
  { 234, 1 },
  { 234, 7 },
  { 234, 5 },
  { 234, 3 },
  { 234, 4 },
  { 234, 9 },
  { 234, 4 },
  { 234, 3 },
  { 234, 2 },
  { 234, 2 },
  { 235, 2 },
  { 235, 2 },
  { 235, 2 },
  { 235, 2 },
  { 235, 2 },
  { 235, 2 },
  { 235, 2 },
  { 235, 2 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 3 },
  { 170, 5 },
  { 213, 3 },
  { 208, 3 },
  { 237, 0 },
  { 238, 3 },
  { 238, 1 },
  { 171, 1 },
  { 171, 2 },
  { 236, 1 },
  { 236, 1 },
  { 236, 1 },
  { 236, 1 },
  { 236, 1 },
  { 236, 1 },
  { 236, 1 },
  { 240, 1 },
  { 240, 1 },
  { 240, 1 },
  { 240, 2 },
  { 240, 2 },
  { 240, 2 },
  { 240, 2 },
  { 240, 1 },
  { 182, 10 },
  { 182, 10 },
  { 245, 2 },
  { 245, 2 },
  { 245, 2 },
  { 245, 3 },
  { 239, 2 },
  { 239, 3 },
  { 239, 3 },
  { 207, 1 },
  { 207, 2 },
  { 242, 1 },
  { 244, 5 },
  { 244, 6 },
  { 244, 9 },
  { 248, 1 },
  { 248, 1 },
  { 249, 1 },
  { 249, 1 },
  { 250, 0 },
  { 250, 1 },
  { 250, 3 },
  { 243, 1 },
  { 243, 3 },
  { 251, 5 },
  { 243, 5 },
  { 241, 3 },
  { 241, 2 },
  { 246, 5 },
  { 247, 2 },
  { 253, 1 },
  { 253, 2 },
  { 253, 3 },
  { 253, 5 },
  { 253, 6 },
  { 253, 5 },
  { 252, 3 },
  { 160, 2 },
  { 167, 0 },
  { 167, 1 },
  { 168, 0 },
  { 168, 1 },
  { 169, 1 },
  { 183, 1 },
  { 184, 1 },
  { 189, 1 },
  { 190, 2 },
  { 197, 3 },
  { 215, 1 },
  { 220, 1 },
  { 218, 1 },
  { 219, 1 },
  { 222, 1 },
  { 228, 1 },
  { 157, 1 },
  { 226, 1 },
  { 231, 1 },
  { 234, 3 },
  { 235, 1 },
  { 170, 1 },
  { 213, 1 },
  { 208, 1 },
  { 237, 1 },
  { 236, 1 },
  { 158, 1 },
  { 240, 1 },
  { 240, 1 },
  { 240, 1 },
  { 252, 1 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  unsigned int yyruleno        /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  ZCCParseARG_FETCH;
  yymsp = yypParser->yytos;
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    yysize = yyRuleInfo[yyruleno].nrhs;
    fprintf(yyTraceFILE, "%sReduce [%s], go to state %d.\n", yyTracePrompt,
      yyRuleName[yyruleno], yymsp[-yysize].stateno);
    fflush(yyTraceFILE);
  }
#endif /* NDEBUG */

  /* Check that the stack is large enough to grow by a single entry
  ** if the RHS of the rule is empty.  This ensures that there is room
  ** enough on the stack to push the LHS value */
  if( yyRuleInfo[yyruleno].nrhs==0 ){
#ifdef YYTRACKMAXSTACKDEPTH
    if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
      yypParser->yyhwm++;
      assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack));
    }
#endif
#if YYSTACKDEPTH>0 
    if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH-1] ){
      yyStackOverflow(yypParser);
      return;
    }
#else
    if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz-1] ){
      if( yyGrowStack(yypParser) ){
        yyStackOverflow(yypParser);
        return;
      }
      yymsp = yypParser->yytos;
    }
#endif
  }

  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
/********** Begin reduce actions **********************************************/
        YYMINORTYPE yylhsminor;
      case 0: /* main ::= translation_unit */
#line 173 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ stat->TopNode = yymsp[0].minor.yy40; DPrintf(DMSG_SPAMMY, "Parse complete\n"); }
#line 2491 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 1: /* translation_unit ::= */
      case 29: /*class_innards ::= */ yytestcase(yyruleno==29);
      case 49: /*opt_struct_body ::= */ yytestcase(yyruleno==49);
#line 176 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy40 = NULL; }
#line 2498 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 2: /* translation_unit ::= translation_unit external_declaration */
      case 30: /*class_innards ::= class_innards class_member */ yytestcase(yyruleno==30);
#line 177 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ SAFE_APPEND(yymsp[-1].minor.yy40,yymsp[0].minor.yy40); }
#line 2504 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 3: /* translation_unit ::= error */
      case 50: /*opt_struct_body ::= error */ yytestcase(yyruleno==50);
#line 179 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy40 = NULL; }
#line 2510 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 4: /* external_declaration ::= class_definition */
#line 182 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy40 = yymsp[0].minor.yy32; /*X-overwrites-A*/ }
#line 2515 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 5: /* external_declaration ::= struct_def */
      case 33: /*class_member ::= struct_def */ yytestcase(yyruleno==33);
#line 183 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy40 = yymsp[0].minor.yy179; /*X-overwrites-A*/ }
#line 2521 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 6: /* external_declaration ::= enum_def */
      case 32: /*class_member ::= enum_def */ yytestcase(yyruleno==32);
      case 53: /*struct_member ::= enum_def */ yytestcase(yyruleno==53);
#line 184 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy40 = yymsp[0].minor.yy151; /*X-overwrites-A*/ }
#line 2528 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 7: /* external_declaration ::= const_def */
      case 36: /*class_member ::= const_def */ yytestcase(yyruleno==36);
      case 54: /*struct_member ::= const_def */ yytestcase(yyruleno==54);
#line 185 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy40 = yymsp[0].minor.yy375; /*X-overwrites-A*/ }
#line 2535 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 8: /* external_declaration ::= include_def */
#line 186 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy40 = nullptr; }
#line 2540 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 9: /* opt_expr ::= */
#line 197 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[1].minor.yy494 = NULL;
}
#line 2547 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 10: /* include_def ::= INCLUDE string_constant */
{  yy_destructor(yypParser,51,&yymsp[-1].minor);
#line 204 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	AddInclude(yymsp[0].minor.yy135);
}
#line 2555 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
        break;
      case 11: /* class_definition ::= class_head class_body */
#line 218 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[-1].minor.yy32->Body = yymsp[0].minor.yy40;
	yymsp[-1].minor.yy32 = yymsp[-1].minor.yy32; /*X-overwrites-A*/
}
#line 2564 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 12: /* class_head ::= EXTEND CLASS IDENTIFIER */
{  yy_destructor(yypParser,52,&yymsp[-2].minor);
#line 224 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Class,head,yymsp[-1].minor.yy0);
	head->NodeName = yymsp[0].minor.yy0.Name();
	head->ParentName = nullptr;
	head->Flags =  ZCC_Extension;
	head->Replaces = nullptr;
	head->Version = {0, 0};
	head->Type = nullptr;
	head->Symbol = nullptr;
	yymsp[-2].minor.yy32 = head;
}
#line 2580 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
        break;
      case 13: /* class_head ::= CLASS IDENTIFIER class_ancestry class_flags */
#line 237 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Class,head,yymsp[-3].minor.yy0);
	head->NodeName = yymsp[-2].minor.yy0.Name();
	head->ParentName = yymsp[-1].minor.yy17;
	head->Flags = yymsp[0].minor.yy335.Flags;
	head->Replaces = yymsp[0].minor.yy335.Replaces;
	head->Version = yymsp[0].minor.yy335.Version;
	head->Type = nullptr;
	head->Symbol = nullptr;
	yylhsminor.yy32 = head;
}
#line 2596 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[-3].minor.yy32 = yylhsminor.yy32;
        break;
      case 14: /* class_ancestry ::= */
      case 142: /*class_restrictor ::= */ yytestcase(yyruleno==142);
#line 250 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy17 = NULL; }
#line 2603 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 15: /* class_ancestry ::= COLON dottable_id */
{  yy_destructor(yypParser,14,&yymsp[-1].minor);
#line 251 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy17 = yymsp[0].minor.yy17; /*yymsp[-1].minor.yy17-overwrites-yymsp[0].minor.yy17*/ }
#line 2609 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
        break;
      case 16: /* class_flags ::= */
#line 254 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy335.Flags = 0; yymsp[1].minor.yy335.Replaces = NULL; yymsp[1].minor.yy335.Version = {0,0}; }
#line 2615 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 17: /* class_flags ::= class_flags ABSTRACT */
#line 255 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-1].minor.yy335.Flags | ZCC_Abstract; yylhsminor.yy335.Replaces = yymsp[-1].minor.yy335.Replaces; }
#line 2620 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,55,&yymsp[0].minor);
  yymsp[-1].minor.yy335 = yylhsminor.yy335;
        break;
      case 18: /* class_flags ::= class_flags NATIVE */
#line 256 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-1].minor.yy335.Flags | ZCC_Native; yylhsminor.yy335.Replaces = yymsp[-1].minor.yy335.Replaces; }
#line 2627 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,56,&yymsp[0].minor);
  yymsp[-1].minor.yy335 = yylhsminor.yy335;
        break;
      case 19: /* class_flags ::= class_flags UI */
#line 257 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-1].minor.yy335.Flags | ZCC_UIFlag; yylhsminor.yy335.Replaces = yymsp[-1].minor.yy335.Replaces; }
#line 2634 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,57,&yymsp[0].minor);
  yymsp[-1].minor.yy335 = yylhsminor.yy335;
        break;
      case 20: /* class_flags ::= class_flags PLAY */
#line 258 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-1].minor.yy335.Flags | ZCC_Play; yylhsminor.yy335.Replaces = yymsp[-1].minor.yy335.Replaces; }
#line 2641 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,58,&yymsp[0].minor);
  yymsp[-1].minor.yy335 = yylhsminor.yy335;
        break;
      case 21: /* class_flags ::= class_flags REPLACES dottable_id */
#line 259 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-2].minor.yy335.Flags; yylhsminor.yy335.Replaces = yymsp[0].minor.yy17; }
#line 2648 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,59,&yymsp[-1].minor);
  yymsp[-2].minor.yy335 = yylhsminor.yy335;
        break;
      case 22: /* class_flags ::= class_flags VERSION LPAREN STRCONST RPAREN */
#line 260 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-4].minor.yy335.Flags | ZCC_Version; yylhsminor.yy335.Replaces = yymsp[-4].minor.yy335.Replaces; yylhsminor.yy335.Version = yymsp[-1].minor.yy0.String->GetChars(); }
#line 2655 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,60,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-4].minor.yy335 = yylhsminor.yy335;
        break;
      case 23: /* dottable_id ::= IDENTIFIER */
      case 40: /*identifier_list ::= IDENTIFIER */ yytestcase(yyruleno==40);
      case 67: /*states_opt ::= IDENTIFIER */ yytestcase(yyruleno==67);
#line 268 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id,yymsp[0].minor.yy0);
	id->Id = yymsp[0].minor.yy0.Name();
	yylhsminor.yy17 = id;
}
#line 2670 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy17 = yylhsminor.yy17;
        break;
      case 24: /* dottable_id ::= dottable_id DOT IDENTIFIER */
#line 274 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id2,yymsp[-2].minor.yy17);
	id2->Id = yymsp[0].minor.yy0.Name();
	AppendTreeNodeSibling(yymsp[-2].minor.yy17, id2);
	yymsp[-2].minor.yy17 = yymsp[-2].minor.yy17; /*X-overwrites-A*/
}
#line 2681 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
        break;
      case 25: /* dottable_id ::= dottable_id DOT DEFAULT */
#line 281 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id2,yymsp[-2].minor.yy17);
	id2->Id = NAME_Default;
	AppendTreeNodeSibling(yymsp[-2].minor.yy17, id2);
	yymsp[-2].minor.yy17 = yymsp[-2].minor.yy17; /*X-overwrites-A*/
}
#line 2692 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
  yy_destructor(yypParser,63,&yymsp[0].minor);
        break;
      case 26: /* dottable_id ::= dottable_id DOT COLOR */
#line 292 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id2,yymsp[-2].minor.yy17);
	id2->Id = NAME_Color;
	AppendTreeNodeSibling(yymsp[-2].minor.yy17, id2);
	yymsp[-2].minor.yy17 = yymsp[-2].minor.yy17; /*X-overwrites-A*/
}
#line 2704 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
  yy_destructor(yypParser,64,&yymsp[0].minor);
        break;
      case 27: /* class_body ::= SEMICOLON class_innards EOF */
{  yy_destructor(yypParser,49,&yymsp[-2].minor);
#line 309 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy40 = yymsp[-1].minor.yy40; /*yymsp[-2].minor.yy40-overwrites-yymsp[-1].minor.yy40*/ }
#line 2712 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,48,&yymsp[0].minor);
}
        break;
      case 28: /* class_body ::= LBRACE class_innards RBRACE */
{  yy_destructor(yypParser,65,&yymsp[-2].minor);
#line 310 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy40 = yymsp[-1].minor.yy40; /*yymsp[-2].minor.yy40-overwrites-yymsp[-1].minor.yy40*/ }
#line 2720 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 31: /* class_member ::= declarator */
      case 52: /*struct_member ::= declarator */ yytestcase(yyruleno==52);
#line 321 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy40 = yymsp[0].minor.yy411; /*X-overwrites-A*/ }
#line 2728 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 34: /* class_member ::= states_def */
#line 324 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy40 = yymsp[0].minor.yy258; /*X-overwrites-A*/ }
#line 2733 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 35: /* class_member ::= default_def */
#line 325 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy40 = yymsp[0].minor.yy479; /*X-overwrites-A*/ }
#line 2738 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 37: /* class_member ::= property_def */
#line 327 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy40 = yymsp[0].minor.yy336; /*X-overwrites-A*/ }
#line 2743 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 38: /* class_member ::= staticarray_statement */
#line 328 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy40 = yymsp[0].minor.yy202; /*X-overwrites-A*/ }
#line 2748 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 39: /* property_def ::= PROPERTY IDENTIFIER COLON identifier_list SEMICOLON */
#line 340 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Property,def,yymsp[-4].minor.yy0);
	def->NodeName = yymsp[-3].minor.yy0.Name();
	def->Body = yymsp[-1].minor.yy17;
	yylhsminor.yy336 = def;
}
#line 2758 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[-2].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-4].minor.yy336 = yylhsminor.yy336;
        break;
      case 41: /* identifier_list ::= states_opt COMMA IDENTIFIER */
      case 68: /*states_opt ::= states_opt COMMA IDENTIFIER */ yytestcase(yyruleno==68);
#line 355 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id,yymsp[0].minor.yy0);
	id->Id = yymsp[0].minor.yy0.Name();
	yymsp[-2].minor.yy17 = yymsp[-2].minor.yy17; /*X-overwrites-A*/
	AppendTreeNodeSibling(yymsp[-2].minor.yy17, id);
}
#line 2772 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 42: /* struct_def ::= STRUCT IDENTIFIER struct_flags LBRACE opt_struct_body RBRACE opt_semicolon */
#line 363 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Struct,def,yymsp[-6].minor.yy0);
	def->NodeName = yymsp[-5].minor.yy0.Name();
	def->Body = yymsp[-2].minor.yy40;
	def->Type = nullptr;
	def->Symbol = nullptr;
	def->Version = yymsp[-4].minor.yy335.Version;
	def->Flags = yymsp[-4].minor.yy335.Flags;
	yylhsminor.yy179 = def;
}
#line 2787 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,65,&yymsp[-3].minor);
  yy_destructor(yypParser,66,&yymsp[-1].minor);
  yymsp[-6].minor.yy179 = yylhsminor.yy179;
        break;
      case 43: /* struct_flags ::= */
#line 375 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy335.Flags = 0; yymsp[1].minor.yy335.Version = {0, 0}; }
#line 2795 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 44: /* struct_flags ::= struct_flags UI */
#line 376 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-1].minor.yy335.Flags | ZCC_UIFlag; }
#line 2800 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,57,&yymsp[0].minor);
  yymsp[-1].minor.yy335 = yylhsminor.yy335;
        break;
      case 45: /* struct_flags ::= struct_flags PLAY */
#line 377 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-1].minor.yy335.Flags | ZCC_Play; }
#line 2807 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,58,&yymsp[0].minor);
  yymsp[-1].minor.yy335 = yylhsminor.yy335;
        break;
      case 46: /* struct_flags ::= struct_flags CLEARSCOPE */
#line 378 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-1].minor.yy335.Flags | ZCC_ClearScope; }
#line 2814 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,69,&yymsp[0].minor);
  yymsp[-1].minor.yy335 = yylhsminor.yy335;
        break;
      case 47: /* struct_flags ::= struct_flags NATIVE */
#line 379 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-1].minor.yy335.Flags | ZCC_Native; }
#line 2821 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,56,&yymsp[0].minor);
  yymsp[-1].minor.yy335 = yylhsminor.yy335;
        break;
      case 48: /* struct_flags ::= struct_flags VERSION LPAREN STRCONST RPAREN */
#line 380 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-4].minor.yy335.Flags | ZCC_Version; yylhsminor.yy335.Version = yymsp[-1].minor.yy0.String->GetChars(); }
#line 2828 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,60,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-4].minor.yy335 = yylhsminor.yy335;
        break;
      case 51: /* struct_body ::= struct_body struct_member */
#line 388 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy40 = yymsp[-1].minor.yy40; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-1].minor.yy40, yymsp[0].minor.yy40); }
#line 2837 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 55: /* const_def ::= CONST IDENTIFIER EQ expr SEMICOLON */
#line 397 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ConstantDef,def,yymsp[-4].minor.yy0);
	def->NodeName = yymsp[-3].minor.yy0.Name();
	def->Value = yymsp[-1].minor.yy494;
	def->Symbol = NULL;
	yylhsminor.yy375 = def;
}
#line 2848 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-2].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-4].minor.yy375 = yylhsminor.yy375;
        break;
      case 56: /* enum_def ::= ENUM IDENTIFIER enum_type LBRACE opt_enum_list RBRACE opt_semicolon */
#line 414 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Enum,def,yymsp[-6].minor.yy0);
	def->NodeName = yymsp[-5].minor.yy0.Name();
	def->EnumType = (EZCCBuiltinType)yymsp[-4].minor.yy0.Int;
	def->Elements = yymsp[-2].minor.yy375;
	def->Symbol = nullptr;

	// If the first element does not have an explicit value, make it 0.
	if (yymsp[-2].minor.yy375 != NULL)
	{
		ZCC_ConstantDef *node = yymsp[-2].minor.yy375, *prev = node;

		if (node->Value == NULL)
		{
			NEW_INTCONST_NODE(zero, TypeSInt32, 0, yymsp[-2].minor.yy375);
			node->Value = zero;
		}
		for (node = static_cast<ZCC_ConstantDef *>(node->SiblingNext);
			node != yymsp[-2].minor.yy375;
			prev = node, node = static_cast<ZCC_ConstantDef *>(node->SiblingNext))
		{
			assert(node->NodeType == AST_ConstantDef);
			// Leave explicit values alone.
			if (node->Value != NULL)
			{
				continue;
			}
			// Compute implicit values by adding one to the preceding value.
			assert(prev->Value != NULL);
			// If the preceding node is a constant, then we can do this now.
			if (prev->Value->Operation == PEX_ConstValue && prev->Value->Type->isInt())
			{
				NEW_INTCONST_NODE(cval, prev->Value->Type, static_cast<ZCC_ExprConstant *>(prev->Value)->IntVal + 1, node);
				node->Value = cval;
			}
			// Otherwise, create a new addition expression to add 1.
			else
			{
				NEW_INTCONST_NODE(one, TypeSInt32, 1, yymsp[-6].minor.yy0);
				NEW_AST_NODE(ExprID, label, node);
				label->Operation = PEX_ID;
				label->Identifier = prev->NodeName;
				label->Type = NULL;

				BINARY_EXPR(label, one, PEX_Add);
				node->Value = expr2;
			}
		}
		// Add a new terminating node, to indicate that the ConstantDefs for this enum are done.
		NEW_AST_NODE(EnumTerminator,term,yymsp[-1].minor.yy0);
		AppendTreeNodeSibling(yymsp[-2].minor.yy375, term);
	}
	if (yymsp[-2].minor.yy375 != NULL)
	{
		AppendTreeNodeSibling(def, yymsp[-2].minor.yy375);
	}
	yylhsminor.yy151 = def;
}
#line 2913 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,65,&yymsp[-3].minor);
  yymsp[-6].minor.yy151 = yylhsminor.yy151;
        break;
      case 57: /* enum_type ::= */
#line 473 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy0.Int = ZCC_IntAuto; yymsp[1].minor.yy0.SourceLoc = stat->sc->GetMessageLine(); }
#line 2920 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 58: /* enum_type ::= COLON int_type */
{  yy_destructor(yypParser,14,&yymsp[-1].minor);
#line 474 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy0 = yymsp[0].minor.yy0; /*yymsp[-1].minor.yy0-overwrites-yymsp[0].minor.yy0*/ }
#line 2926 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
        break;
      case 59: /* enum_list ::= error */
#line 476 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy375 = NULL; }
#line 2932 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 60: /* enum_list ::= enum_list COMMA enumerator */
#line 478 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy375 = yymsp[-2].minor.yy375; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy375, yymsp[0].minor.yy375); }
#line 2937 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 61: /* opt_enum_list ::= */
#line 480 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy375 = NULL; }
#line 2943 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 62: /* enumerator ::= IDENTIFIER */
#line 484 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ConstantDef,node,yymsp[0].minor.yy0);
	node->NodeName = yymsp[0].minor.yy0.Name();
	node->Value = NULL;
	node->Symbol = NULL;
	yylhsminor.yy375 = node;
}
#line 2954 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy375 = yylhsminor.yy375;
        break;
      case 63: /* enumerator ::= IDENTIFIER EQ expr */
#line 492 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ConstantDef,node,yymsp[-2].minor.yy0);
	node->NodeName = yymsp[-2].minor.yy0.Name();
	node->Value = yymsp[0].minor.yy494;
	node->Symbol = NULL;
	yylhsminor.yy375 = node;
}
#line 2966 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-2].minor.yy375 = yylhsminor.yy375;
        break;
      case 64: /* states_def ::= STATES states_opts scanner_mode LBRACE states_body RBRACE */
#line 517 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(States,def,yymsp[-5].minor.yy0);
	def->Flags = yymsp[-4].minor.yy17;
	def->Body = yymsp[-1].minor.yy386;
	yylhsminor.yy258 = def;
}
#line 2978 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,65,&yymsp[-2].minor);
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-5].minor.yy258 = yylhsminor.yy258;
        break;
      case 65: /* states_opts ::= */
#line 524 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy17 = nullptr; }
#line 2986 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 66: /* states_opts ::= LPAREN states_opt RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 525 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy17 = yymsp[-1].minor.yy17; /*yymsp[-2].minor.yy17-overwrites-yymsp[-1].minor.yy17*/ }
#line 2992 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 69: /* scanner_mode ::= */
#line 554 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ stat->sc->SetStateMode(true); }
#line 2999 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 70: /* states_body ::= */
#line 556 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy386 = NULL; }
#line 3004 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 71: /* states_body ::= error */
#line 557 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy386 = NULL; }
#line 3009 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 72: /* states_body ::= states_body state_line */
      case 73: /*states_body ::= states_body state_label */ yytestcase(yyruleno==73);
      case 74: /*states_body ::= states_body state_flow */ yytestcase(yyruleno==74);
#line 558 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ SAFE_APPEND(yymsp[-1].minor.yy386,yymsp[0].minor.yy386); }
#line 3016 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 75: /* state_label ::= NWS COLON */
#line 563 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(StateLabel, label, yymsp[-1].minor.yy0);
	label->Label = yymsp[-1].minor.yy0.Name();
	yylhsminor.yy386 = label;
}
#line 3025 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[0].minor);
  yymsp[-1].minor.yy386 = yylhsminor.yy386;
        break;
      case 76: /* state_flow_type ::= STOP */
#line 571 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ NEW_AST_NODE(StateStop, flow, yymsp[0].minor.yy0); yylhsminor.yy386 = flow; }
#line 3032 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy386 = yylhsminor.yy386;
        break;
      case 77: /* state_flow_type ::= WAIT */
#line 572 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ NEW_AST_NODE(StateWait, flow, yymsp[0].minor.yy0); yylhsminor.yy386 = flow; }
#line 3038 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy386 = yylhsminor.yy386;
        break;
      case 78: /* state_flow_type ::= FAIL */
#line 573 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ NEW_AST_NODE(StateFail, flow, yymsp[0].minor.yy0); yylhsminor.yy386 = flow; }
#line 3044 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy386 = yylhsminor.yy386;
        break;
      case 79: /* state_flow_type ::= LOOP */
#line 574 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ NEW_AST_NODE(StateLoop, flow, yymsp[0].minor.yy0); yylhsminor.yy386 = flow; }
#line 3050 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy386 = yylhsminor.yy386;
        break;
      case 80: /* state_flow_type ::= GOTO dottable_id state_goto_offset */
#line 576 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(StateGoto, flow, yymsp[-2].minor.yy0);
	flow->Label = yymsp[-1].minor.yy17;
	flow->Offset = yymsp[0].minor.yy494;
	flow->Qualifier = nullptr;
	yylhsminor.yy386 = flow;
}
#line 3062 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[-2].minor.yy386 = yylhsminor.yy386;
        break;
      case 81: /* state_flow_type ::= GOTO IDENTIFIER SCOPE dottable_id state_goto_offset */
#line 585 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(StateGoto, flow, yymsp[-4].minor.yy0);
	flow->Label = yymsp[-1].minor.yy17;
	flow->Offset = yymsp[0].minor.yy494;

	NEW_AST_NODE(Identifier,id,yymsp[-3].minor.yy0);
	id->Id = yymsp[-3].minor.yy0.Name();
	flow->Qualifier =id;
	yylhsminor.yy386 = flow;
}
#line 3077 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,47,&yymsp[-2].minor);
  yymsp[-4].minor.yy386 = yylhsminor.yy386;
        break;
      case 82: /* state_flow_type ::= GOTO SUPER SCOPE dottable_id state_goto_offset */
#line 597 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(StateGoto, flow, yymsp[-4].minor.yy0);
	flow->Label = yymsp[-1].minor.yy17;
	flow->Offset = yymsp[0].minor.yy494;

	NEW_AST_NODE(Identifier,id,yymsp[-3].minor.yy0);
	id->Id = NAME_Super;
	flow->Qualifier =id;
	yylhsminor.yy386 = flow;
}
#line 3093 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,47,&yymsp[-2].minor);
  yymsp[-4].minor.yy386 = yylhsminor.yy386;
        break;
      case 83: /* state_goto_offset ::= */
#line 608 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy494 = NULL; }
#line 3100 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 84: /* state_goto_offset ::= ADD expr */
{  yy_destructor(yypParser,34,&yymsp[-1].minor);
#line 609 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy494 = yymsp[0].minor.yy494; /*yymsp[-1].minor.yy494-overwrites-yymsp[0].minor.yy494*/ }
#line 3106 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
        break;
      case 85: /* state_line ::= NWS NWS expr state_opts state_action */
#line 612 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(StateLine, line, yymsp[-4].minor.yy0);
	line->Sprite = stat->Strings.Alloc(FName(yymsp[-4].minor.yy0.Name()).GetChars());
	line->Frames = stat->Strings.Alloc(FName(yymsp[-3].minor.yy0.Name()).GetChars());
	line->Duration = yymsp[-2].minor.yy494;
	line->bBright = yymsp[-1].minor.yy504.Bright;
	line->bFast = yymsp[-1].minor.yy504.Fast;
	line->bSlow = yymsp[-1].minor.yy504.Slow;
	line->bNoDelay = yymsp[-1].minor.yy504.NoDelay;
	line->bCanRaise = yymsp[-1].minor.yy504.CanRaise;
	line->Offset = yymsp[-1].minor.yy504.Offset;
	line->Lights = yymsp[-1].minor.yy504.Lights;
	line->Action = yymsp[0].minor.yy40;
	yylhsminor.yy386 = line;
}
#line 3126 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[-4].minor.yy386 = yylhsminor.yy386;
        break;
      case 86: /* state_opts ::= */
#line 628 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ StateOpts opts; opts.Zero(); yymsp[1].minor.yy504 = opts; }
#line 3132 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 87: /* state_opts ::= state_opts BRIGHT */
#line 629 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy504.Bright = true; yymsp[-1].minor.yy504 = yymsp[-1].minor.yy504; /*X-overwrites-A*/ }
#line 3137 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,80,&yymsp[0].minor);
        break;
      case 88: /* state_opts ::= state_opts FAST */
#line 630 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy504.Fast = true; yymsp[-1].minor.yy504 = yymsp[-1].minor.yy504; /*X-overwrites-A*/ }
#line 3143 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,81,&yymsp[0].minor);
        break;
      case 89: /* state_opts ::= state_opts SLOW */
#line 631 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy504.Slow = true; yymsp[-1].minor.yy504 = yymsp[-1].minor.yy504; /*X-overwrites-A*/ }
#line 3149 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,82,&yymsp[0].minor);
        break;
      case 90: /* state_opts ::= state_opts NODELAY */
#line 632 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy504.NoDelay = true; yymsp[-1].minor.yy504 = yymsp[-1].minor.yy504; /*X-overwrites-A*/ }
#line 3155 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,83,&yymsp[0].minor);
        break;
      case 91: /* state_opts ::= state_opts CANRAISE */
#line 633 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy504.CanRaise = true; yymsp[-1].minor.yy504 = yymsp[-1].minor.yy504; /*X-overwrites-A*/ }
#line 3161 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,84,&yymsp[0].minor);
        break;
      case 92: /* state_opts ::= state_opts OFFSET LPAREN expr COMMA expr RPAREN */
#line 634 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-6].minor.yy504.Offset = yymsp[-3].minor.yy494; AppendTreeNodeSibling(yymsp[-3].minor.yy494, yymsp[-1].minor.yy494); yymsp[-6].minor.yy504 = yymsp[-6].minor.yy504; /*X-overwrites-A*/ }
#line 3167 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,85,&yymsp[-5].minor);
  yy_destructor(yypParser,45,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
        break;
      case 93: /* state_opts ::= state_opts LIGHT LPAREN light_list RPAREN */
#line 635 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-4].minor.yy504 = yymsp[-4].minor.yy504; /*X-overwrites-A*/ yymsp[-4].minor.yy504.Lights = yymsp[-1].minor.yy135; }
#line 3176 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,86,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
        break;
      case 94: /* light_list ::= STRCONST */
      case 258: /*string_constant ::= STRCONST */ yytestcase(yyruleno==258);
#line 640 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, strconst, yymsp[0].minor.yy0);
	strconst->Operation = PEX_ConstValue;
	strconst->Type = TypeString;
	strconst->StringVal = yymsp[0].minor.yy0.String;
	yylhsminor.yy135 = strconst;
}
#line 3191 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy135 = yylhsminor.yy135;
        break;
      case 95: /* light_list ::= light_list COMMA STRCONST */
#line 649 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, strconst, yymsp[0].minor.yy0);
	strconst->Operation = PEX_ConstValue;
	strconst->Type = TypeString;
	strconst->StringVal = yymsp[0].minor.yy0.String;
	AppendTreeNodeSibling(yymsp[-2].minor.yy135, strconst); 
	yymsp[-2].minor.yy135 = yymsp[-2].minor.yy135; /*X-overwrites-A*/
}
#line 3204 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 96: /* state_action ::= LBRACE statement_list scanner_mode RBRACE */
#line 660 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-3].minor.yy0);
	stmt->Content = yymsp[-2].minor.yy475;
	yylhsminor.yy40 = stmt;
}
#line 3214 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-3].minor.yy40 = yylhsminor.yy40;
        break;
      case 97: /* state_action ::= LBRACE scanner_mode RBRACE */
{  yy_destructor(yypParser,65,&yymsp[-2].minor);
#line 666 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[-2].minor.yy40 = NULL;
}
#line 3224 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 98: /* state_action ::= LBRACE error scanner_mode RBRACE */
{  yy_destructor(yypParser,65,&yymsp[-3].minor);
#line 669 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-3].minor.yy40 = NULL; }
#line 3232 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 99: /* state_action ::= state_call scanner_mode SEMICOLON */
#line 670 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy40 = yymsp[-2].minor.yy465; /*X-overwrites-A*/ }
#line 3239 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 100: /* state_call ::= */
#line 672 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy465 = NULL; }
#line 3245 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 101: /* state_call ::= IDENTIFIER state_call_params */
#line 674 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprFuncCall, expr, yymsp[-1].minor.yy0);
	NEW_AST_NODE(ExprID, func, yymsp[-1].minor.yy0);

	func->Operation = PEX_ID;
	func->Identifier = yymsp[-1].minor.yy0.Name();
	expr->Operation = PEX_FuncCall;
	expr->Function = func;
	expr->Parameters = yymsp[0].minor.yy366;
	yylhsminor.yy465 = expr;
}
#line 3260 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[-1].minor.yy465 = yylhsminor.yy465;
        break;
      case 102: /* state_call_params ::= */
#line 686 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy366 = NULL; }
#line 3266 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 103: /* state_call_params ::= LPAREN func_expr_list RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 687 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy366 = yymsp[-1].minor.yy366; /*yymsp[-2].minor.yy366-overwrites-yymsp[-1].minor.yy366*/ }
#line 3272 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 104: /* default_def ::= DEFAULT LBRACE RBRACE */
{  yy_destructor(yypParser,63,&yymsp[-2].minor);
#line 695 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Default,stmt,yymsp[-1].minor.yy0);
	stmt->Content = NULL;
	yymsp[-2].minor.yy479 = stmt;
}
#line 3284 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 105: /* default_def ::= DEFAULT LBRACE default_statement_list RBRACE */
{  yy_destructor(yypParser,63,&yymsp[-3].minor);
#line 701 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Default,stmt,yymsp[-2].minor.yy0);
	stmt->Content = yymsp[-1].minor.yy475;
	yymsp[-3].minor.yy479 = stmt;
}
#line 3296 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 106: /* default_def ::= DEFAULT LBRACE error RBRACE */
{  yy_destructor(yypParser,63,&yymsp[-3].minor);
#line 707 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Default,stmt,yymsp[-2].minor.yy0);
	stmt->Content = NULL;
	yymsp[-3].minor.yy479 = stmt;
}
#line 3308 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 107: /* default_statement_list ::= default_statement */
      case 284: /*statement_list ::= statement */ yytestcase(yyruleno==284);
#line 714 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[0].minor.yy475 = yymsp[0].minor.yy475; /*X-overwrites-A*/
}
#line 3318 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 108: /* default_statement_list ::= default_statement_list default_statement */
      case 285: /*statement_list ::= statement_list statement */ yytestcase(yyruleno==285);
#line 718 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	SAFE_APPEND(yymsp[-1].minor.yy475,yymsp[0].minor.yy475);
}
#line 3326 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 109: /* default_statement ::= SEMICOLON */
      case 267: /*statement ::= SEMICOLON */ yytestcase(yyruleno==267);
{  yy_destructor(yypParser,49,&yymsp[0].minor);
#line 723 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy475 = NULL; }
#line 3333 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
        break;
      case 110: /* default_statement ::= error SEMICOLON */
      case 273: /*statement ::= error SEMICOLON */ yytestcase(yyruleno==273);
#line 724 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy475 = NULL; }
#line 3340 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 111: /* default_statement ::= property_statement */
#line 726 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy475 = yymsp[0].minor.yy31; /*X-overwrites-A*/ }
#line 3346 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 112: /* default_statement ::= flag_statement */
#line 727 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy475 = yymsp[0].minor.yy8; /*X-overwrites-A*/ }
#line 3351 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 113: /* flag_statement ::= ADD dottable_id */
{  yy_destructor(yypParser,34,&yymsp[-1].minor);
#line 732 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(FlagStmt, type, yymsp[0].minor.yy17);
	type->set = true;
	type->name = yymsp[0].minor.yy17;
	yymsp[-1].minor.yy8 = type;
}
#line 3362 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
        break;
      case 114: /* flag_statement ::= SUB dottable_id */
{  yy_destructor(yypParser,33,&yymsp[-1].minor);
#line 739 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(FlagStmt, type, yymsp[0].minor.yy17);
	type->set = false;
	type->name = yymsp[0].minor.yy17;
	yymsp[-1].minor.yy8 = type;
}
#line 3374 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
        break;
      case 115: /* property_statement ::= dottable_id expr_list SEMICOLON */
#line 749 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(PropertyStmt,stmt,yymsp[-2].minor.yy17);
	stmt->Prop = yymsp[-2].minor.yy17;
	stmt->Values = yymsp[-1].minor.yy494;
	yylhsminor.yy31 = stmt;
}
#line 3385 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-2].minor.yy31 = yylhsminor.yy31;
        break;
      case 116: /* property_statement ::= dottable_id SEMICOLON */
#line 757 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(PropertyStmt,stmt,yymsp[-1].minor.yy17);
	stmt->Prop = yymsp[-1].minor.yy17;
	stmt->Values = nullptr;
	yylhsminor.yy31 = stmt;
}
#line 3397 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy31 = yylhsminor.yy31;
        break;
      case 117: /* int_type ::= SBYTE */
#line 769 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_SInt8; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3404 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 118: /* int_type ::= BYTE */
#line 770 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UInt8; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3410 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 119: /* int_type ::= SHORT */
#line 771 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_SInt16; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3416 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 120: /* int_type ::= USHORT */
#line 772 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UInt16; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3422 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 121: /* int_type ::= INT */
#line 773 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_SInt32; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3428 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 122: /* int_type ::= UINT */
#line 774 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UInt32; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3434 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 123: /* type_name1 ::= BOOL */
#line 776 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Bool; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3440 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 124: /* type_name1 ::= FLOAT */
#line 778 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_FloatAuto; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3446 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 125: /* type_name1 ::= DOUBLE */
#line 779 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Float64; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3452 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 126: /* type_name1 ::= VECTOR2 */
#line 781 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Vector2; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3458 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 127: /* type_name1 ::= VECTOR3 */
#line 782 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Vector3; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3464 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 128: /* type_name1 ::= NAME */
#line 783 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Name; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3470 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 129: /* type_name1 ::= SOUND */
#line 784 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Sound; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3476 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 130: /* type_name1 ::= STATE */
#line 785 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_State; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3482 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 131: /* type_name1 ::= COLOR */
#line 786 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Color; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3488 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 132: /* type_name1 ::= LET */
#line 787 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Let; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3494 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 133: /* type_name ::= type_name1 */
#line 790 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy0);
	type->Type = (EZCCBuiltinType)yymsp[0].minor.yy0.Int;
	type->UserType = NULL;
	type->isconst = false;
	yylhsminor.yy474 = type;
}
#line 3506 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy474 = yylhsminor.yy474;
        break;
      case 134: /* type_name ::= IDENTIFIER */
#line 798 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[0].minor.yy0);
	type->Type = ZCC_UserType;
	type->UserType = id;
	type->isconst = false;
	id->Id = yymsp[0].minor.yy0.Name();
	yylhsminor.yy474 = type;
}
#line 3520 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy474 = yylhsminor.yy474;
        break;
      case 135: /* type_name ::= ATSIGN IDENTIFIER */
{  yy_destructor(yypParser,102,&yymsp[-1].minor);
#line 809 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[0].minor.yy0);
	type->Type = ZCC_NativeType;
	type->UserType = id;
	type->isconst = false;
	id->Id = yymsp[0].minor.yy0.Name();
	yymsp[-1].minor.yy474 = type;
}
#line 3535 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
        break;
      case 136: /* type_name ::= READONLY LT IDENTIFIER GT */
{  yy_destructor(yypParser,103,&yymsp[-3].minor);
#line 820 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[-1].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[-1].minor.yy0);
	type->Type = ZCC_UserType;
	type->UserType = id;
	type->isconst = true;
	id->Id = yymsp[-1].minor.yy0.Name();
	yymsp[-3].minor.yy474 = type;
}
#line 3550 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-2].minor);
  yy_destructor(yypParser,21,&yymsp[0].minor);
}
        break;
      case 137: /* type_name ::= READONLY LT ATSIGN IDENTIFIER GT */
{  yy_destructor(yypParser,103,&yymsp[-4].minor);
#line 831 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[-1].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[-1].minor.yy0);
	type->Type = ZCC_NativeType;
	type->UserType = id;
	type->isconst = true;
	id->Id = yymsp[-1].minor.yy0.Name();
	yymsp[-4].minor.yy474 = type;
}
#line 3567 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-3].minor);
  yy_destructor(yypParser,102,&yymsp[-2].minor);
  yy_destructor(yypParser,21,&yymsp[0].minor);
}
        break;
      case 138: /* type_name ::= DOT dottable_id */
{  yy_destructor(yypParser,44,&yymsp[-1].minor);
#line 842 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy17);
	type->Type = ZCC_UserType;
	type->UserType = yymsp[0].minor.yy17;
	type->isconst = false;
	yymsp[-1].minor.yy474 = type;
}
#line 3583 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
        break;
      case 139: /* aggregate_type ::= MAP LT type_or_array COMMA type_or_array GT */
#line 866 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(MapType,map,yymsp[-5].minor.yy0);
	map->KeyType = yymsp[-3].minor.yy344;
	map->ValueType = yymsp[-1].minor.yy344;
	yylhsminor.yy344 = map;
}
#line 3594 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,21,&yymsp[0].minor);
  yymsp[-5].minor.yy344 = yylhsminor.yy344;
        break;
      case 140: /* aggregate_type ::= ARRAY LT type_or_array GT */
#line 874 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(DynArrayType,arr,yymsp[-3].minor.yy0);
	arr->ElementType = yymsp[-1].minor.yy344;
	yylhsminor.yy344 = arr;
}
#line 3607 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-2].minor);
  yy_destructor(yypParser,21,&yymsp[0].minor);
  yymsp[-3].minor.yy344 = yylhsminor.yy344;
        break;
      case 141: /* aggregate_type ::= CLASS class_restrictor */
#line 881 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ClassType,cls,yymsp[-1].minor.yy0);
	cls->Restriction = yymsp[0].minor.yy17;
	yylhsminor.yy344 = cls;
}
#line 3619 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[-1].minor.yy344 = yylhsminor.yy344;
        break;
      case 143: /* class_restrictor ::= LT dottable_id GT */
{  yy_destructor(yypParser,20,&yymsp[-2].minor);
#line 887 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy17 = yymsp[-1].minor.yy17; /*yymsp[-2].minor.yy17-overwrites-yymsp[-1].minor.yy17*/ }
#line 3626 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,21,&yymsp[0].minor);
}
        break;
      case 144: /* type ::= type_name */
#line 889 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy344 = yymsp[0].minor.yy474; /*X-overwrites-A*/ yymsp[0].minor.yy344->ArraySize = NULL; }
#line 3633 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 145: /* type ::= aggregate_type */
#line 890 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy344 = yymsp[0].minor.yy344; /*X-overwrites-A*/ yymsp[0].minor.yy344->ArraySize = NULL; }
#line 3638 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 146: /* type_or_array ::= type array_size */
#line 893 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy344 = yymsp[-1].minor.yy344; /*X-overwrites-A*/ yymsp[-1].minor.yy344->ArraySize = yymsp[0].minor.yy494; }
#line 3643 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 147: /* type_list ::= type_list COMMA type_or_array */
#line 896 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy344 = yymsp[-2].minor.yy344; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy344, yymsp[0].minor.yy344); }
#line 3648 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 148: /* type_list_or_void ::= VOID */
{  yy_destructor(yypParser,107,&yymsp[0].minor);
#line 898 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy344 = NULL; }
#line 3655 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
        break;
      case 149: /* array_size_expr ::= LBRACKET opt_expr RBRACKET */
#line 902 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	if (yymsp[-1].minor.yy494 == NULL)
	{
		NEW_AST_NODE(Expression,nil,yymsp[-2].minor.yy0.SourceLoc);
		nil->Operation = PEX_Nil;
		nil->Type = NULL;
		yylhsminor.yy494 = nil;
	}
	else
	{
		yylhsminor.yy494 = yymsp[-1].minor.yy494;
	}
}
#line 3673 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,112,&yymsp[0].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 150: /* array_size ::= array_size array_size_expr */
#line 917 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	AppendTreeNodeSibling(yymsp[-1].minor.yy494, yymsp[0].minor.yy494);
	yymsp[-1].minor.yy494 = yymsp[-1].minor.yy494; /*X-overwrites-A*/
}
#line 3683 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 151: /* declarator ::= decl_flags type_list_or_void variables_or_function */
#line 926 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	if (yymsp[0].minor.yy476.FuncName == NAME_None && yymsp[0].minor.yy476.VarNames == NULL)
	{ // An error. yymsp[-2].minor.yy331 message was already printed.
		yylhsminor.yy411 = NULL;
	}
	else if (yymsp[0].minor.yy476.FuncName != NAME_None)
	{ // yymsp[-2].minor.yy331 function
		NEW_AST_NODE(FuncDeclarator, decl, yymsp[-2].minor.yy331 == nullptr? yymsp[0].minor.yy476.SourceLoc : yymsp[-2].minor.yy331->SourceLoc);
		decl->Type = yymsp[-1].minor.yy344;
		decl->Params = yymsp[0].minor.yy476.FuncParams;
		decl->Name = yymsp[0].minor.yy476.FuncName;
		decl->UseFlags = yymsp[-2].minor.yy331 == nullptr? nullptr : yymsp[-2].minor.yy331->Id;
		decl->Flags = (yymsp[-2].minor.yy331 == nullptr? 0 : yymsp[-2].minor.yy331->Flags) | yymsp[0].minor.yy476.FuncFlags;
		if (yymsp[-2].minor.yy331 == nullptr) decl->Version = {0,0,0};
		else decl->Version = yymsp[-2].minor.yy331->Version;

		decl->Body = yymsp[0].minor.yy476.FuncBody;
		yylhsminor.yy411 = decl;
	}
	else if (yymsp[-1].minor.yy344 != NULL && yymsp[-1].minor.yy344->SiblingNext == yymsp[-1].minor.yy344)
	{ // yymsp[-2].minor.yy331 variable
		NEW_AST_NODE(VarDeclarator, decl, yymsp[-2].minor.yy331 == nullptr? yymsp[-1].minor.yy344->SourceLoc : yymsp[-2].minor.yy331->SourceLoc);
		decl->Type = yymsp[-1].minor.yy344;
		decl->Names = yymsp[0].minor.yy476.VarNames;
		if (yymsp[-2].minor.yy331 == nullptr)
		{
			decl->Flags = 0;
			decl->Version = {0,0,0};
		}
		else
		{
			decl->Flags = yymsp[-2].minor.yy331->Flags;
			decl->Version = yymsp[-2].minor.yy331->Version;
		}
		yylhsminor.yy411 = decl;
	}
	else
	{ // An invalid
		if (yymsp[-1].minor.yy344 == NULL)
		{
			stat->sc->ScriptMessage("Variables may not be of type void.\n");
		}
		else
		{
			stat->sc->ScriptMessage("Variables may be of only one type.\n");
		}
		yylhsminor.yy411 = NULL;
	}
}
#line 3736 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[-2].minor.yy411 = yylhsminor.yy411;
        break;
      case 152: /* variables_or_function ::= IDENTIFIER LPAREN func_params RPAREN func_const opt_func_body */
#line 978 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	VarOrFun fun;

	fun.VarNames = NULL;
	fun.FuncParams = yymsp[-3].minor.yy480;
	fun.FuncFlags = yymsp[-1].minor.yy0.Int;
	fun.FuncName = yymsp[-5].minor.yy0.Name();
	fun.FuncBody = yymsp[0].minor.yy35;
	fun.SourceLoc = yymsp[-5].minor.yy0.SourceLoc;
	yylhsminor.yy476 = fun;
}
#line 3752 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-4].minor);
  yy_destructor(yypParser,62,&yymsp[-2].minor);
  yymsp[-5].minor.yy476 = yylhsminor.yy476;
        break;
      case 153: /* variables_or_function ::= variable_list SEMICOLON */
#line 990 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	VarOrFun var;

	var.VarNames = yymsp[-1].minor.yy320;
	var.FuncParams = NULL;
	var.FuncFlags = 0;
	var.FuncName = NAME_None;
	var.FuncBody = NULL;
	var.SourceLoc = yymsp[-1].minor.yy320->SourceLoc;
	yylhsminor.yy476 = var;
}
#line 3770 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy476 = yylhsminor.yy476;
        break;
      case 154: /* variables_or_function ::= error SEMICOLON */
#line 1002 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	VarOrFun bad;
	bad.VarNames = NULL;
	bad.FuncParams = NULL;
	bad.FuncFlags = 0;
	bad.FuncName = NAME_None;
	bad.FuncBody = NULL;
	bad.SourceLoc = yymsp[0].minor.yy0.SourceLoc;
	yymsp[-1].minor.yy476 = bad;
}
#line 3786 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 155: /* variable_name ::= IDENTIFIER */
#line 1019 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(VarName,var,yymsp[0].minor.yy0);
	var->Name = ENamedName(yymsp[0].minor.yy0.Int);
	var->ArraySize = NULL;
	yylhsminor.yy320 = var;
}
#line 3796 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy320 = yylhsminor.yy320;
        break;
      case 156: /* variable_name ::= IDENTIFIER array_size */
#line 1026 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(VarName,var,yymsp[-1].minor.yy0);
	var->Name = ENamedName(yymsp[-1].minor.yy0.Int);
	var->ArraySize = yymsp[0].minor.yy494;
	yylhsminor.yy320 = var;
}
#line 3807 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[-1].minor.yy320 = yylhsminor.yy320;
        break;
      case 157: /* variable_list ::= variable_list COMMA variable_name */
#line 1035 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	AppendTreeNodeSibling(yymsp[-2].minor.yy320, yymsp[0].minor.yy320);
	yymsp[-2].minor.yy320 = yymsp[-2].minor.yy320; /*X-overwrites-A*/
}
#line 3816 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 158: /* decl_flags ::= */
#line 1041 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy331 = NULL; }
#line 3822 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 159: /* decl_flags ::= decl_flags decl_flag */
#line 1043 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	if (yymsp[-1].minor.yy331 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[0].minor.yy0);
		yylhsminor.yy331 = nil_f;
		yylhsminor.yy331->Id = nullptr;
		yylhsminor.yy331->Flags = yymsp[0].minor.yy0.Int;
		yylhsminor.yy331->Version = { 0, 0 };
	}
	else
	{
		yylhsminor.yy331 = yymsp[-1].minor.yy331;
		yylhsminor.yy331->Flags |= yymsp[0].minor.yy0.Int;
	}
}
#line 3841 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[-1].minor.yy331 = yylhsminor.yy331;
        break;
      case 160: /* decl_flags ::= decl_flags ACTION states_opts */
#line 1061 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	if (yymsp[-2].minor.yy331 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[-1].minor.yy0.SourceLoc);
		yylhsminor.yy331 = nil_f;
		yylhsminor.yy331->Flags = ZCC_Action;
		yylhsminor.yy331->Id = nullptr;
		yylhsminor.yy331->Version = { 0, 0 };
	}
	else
	{
		yylhsminor.yy331 = yymsp[-2].minor.yy331;
		yylhsminor.yy331->Flags |= ZCC_Action;
	}
	yylhsminor.yy331->Id = yymsp[0].minor.yy17;
}
#line 3862 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[-2].minor.yy331 = yylhsminor.yy331;
        break;
      case 161: /* decl_flags ::= decl_flags DEPRECATED LPAREN STRCONST RPAREN */
#line 1079 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ 
	if (yymsp[-4].minor.yy331 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[-3].minor.yy0.SourceLoc);
		yylhsminor.yy331 = nil_f;
		yylhsminor.yy331->Flags = ZCC_Deprecated;
		yylhsminor.yy331->Id = nullptr;
		yylhsminor.yy331->Version = { 0, 0 };
	}
	else
	{
		yylhsminor.yy331 = yymsp[-4].minor.yy331;
		yylhsminor.yy331->Flags |= ZCC_Deprecated;
	}
	yylhsminor.yy331->Version = yymsp[-1].minor.yy0.String->GetChars();
}
#line 3883 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-4].minor.yy331 = yylhsminor.yy331;
        break;
      case 162: /* decl_flags ::= decl_flags VERSION LPAREN STRCONST RPAREN */
#line 1097 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ 
	if (yymsp[-4].minor.yy331 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[-3].minor.yy0.SourceLoc);
		yylhsminor.yy331 = nil_f;
		yylhsminor.yy331->Flags = ZCC_Version;
		yylhsminor.yy331->Id = nullptr;
		yylhsminor.yy331->Version = { 0, 0 };
	}
	else
	{
		yylhsminor.yy331 = yymsp[-4].minor.yy331;
		yylhsminor.yy331->Flags |= ZCC_Version;
	}
	yylhsminor.yy331->Version = yymsp[-1].minor.yy0.String->GetChars();
}
#line 3906 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-4].minor.yy331 = yylhsminor.yy331;
        break;
      case 163: /* decl_flag ::= NATIVE */
#line 1114 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Native; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 3914 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 164: /* decl_flag ::= STATIC */
#line 1115 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Static; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 3920 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 165: /* decl_flag ::= PRIVATE */
#line 1116 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Private; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 3926 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 166: /* decl_flag ::= PROTECTED */
#line 1117 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Protected; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 3932 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 167: /* decl_flag ::= LATENT */
#line 1118 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Latent; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 3938 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 168: /* decl_flag ::= FINAL */
#line 1119 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Final; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 3944 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 169: /* decl_flag ::= META */
#line 1120 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Meta; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 3950 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 170: /* decl_flag ::= TRANSIENT */
#line 1121 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Transient; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 3956 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 171: /* decl_flag ::= READONLY */
#line 1122 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_ReadOnly; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 3962 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 172: /* decl_flag ::= INTERNAL */
#line 1123 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Internal; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 3968 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 173: /* decl_flag ::= VIRTUAL */
#line 1124 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Virtual; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 3974 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 174: /* decl_flag ::= OVERRIDE */
#line 1125 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Override; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 3980 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 175: /* decl_flag ::= VARARG */
#line 1126 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_VarArg; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3986 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 176: /* decl_flag ::= UI */
#line 1127 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UIFlag; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3992 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 177: /* decl_flag ::= PLAY */
#line 1128 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Play; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3998 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 178: /* decl_flag ::= CLEARSCOPE */
#line 1129 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_ClearScope; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4004 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 179: /* decl_flag ::= VIRTUALSCOPE */
#line 1130 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_VirtualScope; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4010 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 180: /* func_const ::= */
#line 1132 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy0.Int = 0; yymsp[1].minor.yy0.SourceLoc = stat->sc->GetMessageLine(); }
#line 4016 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 181: /* func_const ::= CONST */
#line 1133 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_FuncConst; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4021 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 182: /* opt_func_body ::= SEMICOLON */
{  yy_destructor(yypParser,49,&yymsp[0].minor);
#line 1135 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy35 = NULL; }
#line 4028 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
        break;
      case 183: /* func_params ::= */
#line 1142 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy480 = NULL; }
#line 4034 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 184: /* func_params ::= VOID */
{  yy_destructor(yypParser,107,&yymsp[0].minor);
#line 1143 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy480 = NULL; }
#line 4040 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
        break;
      case 185: /* func_params ::= func_param_list COMMA ELLIPSIS */
#line 1147 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParamDecl,parm,stat->sc->GetMessageLine());
	parm->Type = nullptr;
	parm->Name = NAME_None;
	parm->Flags = 0;
	parm->Default = nullptr;
	yymsp[-2].minor.yy480 = yymsp[-2].minor.yy480; /*X-overwrites-A*/ 
	AppendTreeNodeSibling(yymsp[-2].minor.yy480, parm);
}
#line 4054 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
  yy_destructor(yypParser,127,&yymsp[0].minor);
        break;
      case 186: /* func_param_list ::= func_param_list COMMA func_param */
#line 1158 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy480 = yymsp[-2].minor.yy480; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy480, yymsp[0].minor.yy480); }
#line 4061 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 187: /* func_param ::= func_param_flags type IDENTIFIER */
#line 1161 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParamDecl,parm,yymsp[-2].minor.yy0.SourceLoc ? yymsp[-2].minor.yy0.SourceLoc : yymsp[-1].minor.yy344->SourceLoc);
	parm->Type = yymsp[-1].minor.yy344;
	parm->Name = yymsp[0].minor.yy0.Name();
	parm->Flags = yymsp[-2].minor.yy0.Int;
	parm->Default = nullptr;
	yylhsminor.yy480 = parm;
}
#line 4074 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[-2].minor.yy480 = yylhsminor.yy480;
        break;
      case 188: /* func_param ::= func_param_flags type IDENTIFIER EQ expr */
#line 1171 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParamDecl,parm,yymsp[-4].minor.yy0.SourceLoc ? yymsp[-4].minor.yy0.SourceLoc : yymsp[-3].minor.yy344->SourceLoc);
	parm->Type = yymsp[-3].minor.yy344;
	parm->Name = yymsp[-2].minor.yy0.Name();
	parm->Flags = yymsp[-4].minor.yy0.Int;
	parm->Default = yymsp[0].minor.yy494;
	yylhsminor.yy480 = parm;
}
#line 4087 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-4].minor.yy480 = yylhsminor.yy480;
        break;
      case 189: /* func_param_flags ::= */
#line 1180 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy0.Int = 0; yymsp[1].minor.yy0.SourceLoc = 0; }
#line 4094 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 190: /* func_param_flags ::= func_param_flags IN */
#line 1181 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = yymsp[-1].minor.yy0.Int | ZCC_In; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4099 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[-1].minor.yy0 = yylhsminor.yy0;
        break;
      case 191: /* func_param_flags ::= func_param_flags OUT */
#line 1182 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = yymsp[-1].minor.yy0.Int | ZCC_Out; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4105 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[-1].minor.yy0 = yylhsminor.yy0;
        break;
      case 192: /* func_param_flags ::= func_param_flags OPTIONAL */
#line 1183 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = yymsp[-1].minor.yy0.Int | ZCC_Optional; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4111 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[-1].minor.yy0 = yylhsminor.yy0;
        break;
      case 193: /* primary ::= IDENTIFIER */
#line 1199 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprID, expr, yymsp[0].minor.yy0);
	expr->Operation = PEX_ID;
	expr->Identifier = yymsp[0].minor.yy0.Name();
	expr->Type = NULL;
	yylhsminor.yy494 = expr;
}
#line 4123 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy494 = yylhsminor.yy494;
        break;
      case 194: /* primary ::= SUPER */
#line 1207 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Expression, expr, yymsp[0].minor.yy0);
	expr->Operation = PEX_Super;
	expr->Type = NULL;
	yylhsminor.yy494 = expr;
}
#line 4134 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy494 = yylhsminor.yy494;
        break;
      case 195: /* primary ::= constant */
#line 1213 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy494 = yymsp[0].minor.yy135; /*X-overwrites-A*/ }
#line 4140 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 196: /* primary ::= LPAREN expr COMMA expr COMMA expr RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-6].minor);
#line 1215 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(VectorValue, expr, yymsp[-5].minor.yy494);
	expr->Operation = PEX_Vector;
	expr->Type = TypeVector3;
	expr->X = yymsp[-5].minor.yy494;
	expr->Y = yymsp[-3].minor.yy494;
	expr->Z = yymsp[-1].minor.yy494;
	yymsp[-6].minor.yy494 = expr;
}
#line 4154 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 197: /* primary ::= LPAREN expr COMMA expr RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-4].minor);
#line 1225 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(VectorValue, expr, yymsp[-3].minor.yy494);
	expr->Operation = PEX_Vector;
	expr->Type = TypeVector2;
	expr->X = yymsp[-3].minor.yy494;
	expr->Y = yymsp[-1].minor.yy494;
	expr->Z = nullptr;
	yymsp[-4].minor.yy494 = expr;
}
#line 4172 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 198: /* primary ::= LPAREN expr RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 1235 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[-2].minor.yy494 = yymsp[-1].minor.yy494; /*yymsp[-2].minor.yy494-overwrites-yymsp[-1].minor.yy494*/
}
#line 4183 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 199: /* primary ::= primary LPAREN func_expr_list RPAREN */
#line 1240 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprFuncCall, expr, yymsp[-3].minor.yy494);
	expr->Operation = PEX_FuncCall;
	expr->Type = NULL;
	expr->Function = yymsp[-3].minor.yy494;
	expr->Parameters = yymsp[-1].minor.yy366;
	yylhsminor.yy494 = expr;
}
#line 4197 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-3].minor.yy494 = yylhsminor.yy494;
        break;
      case 200: /* primary ::= LPAREN CLASS LT IDENTIFIER GT RPAREN LPAREN func_expr_list RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-8].minor);
#line 1249 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ClassCast, expr, yymsp[-5].minor.yy0);
	expr->Operation = PEX_ClassCast;
	expr->ClassName = ENamedName(yymsp[-5].minor.yy0.Int);
	expr->Parameters = yymsp[-1].minor.yy366;
	yymsp[-8].minor.yy494 = expr;
}
#line 4212 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,53,&yymsp[-7].minor);
  yy_destructor(yypParser,20,&yymsp[-6].minor);
  yy_destructor(yypParser,21,&yymsp[-4].minor);
  yy_destructor(yypParser,62,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 201: /* primary ::= primary LBRACKET expr RBRACKET */
#line 1257 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprBinary, expr, yymsp[-1].minor.yy494);
	expr->Operation = PEX_ArrayAccess;
	expr->Type = NULL;
	expr->Left = yymsp[-3].minor.yy494;
	expr->Right = yymsp[-1].minor.yy494;
	yylhsminor.yy494 = expr;
}
#line 4231 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,46,&yymsp[-2].minor);
  yy_destructor(yypParser,112,&yymsp[0].minor);
  yymsp[-3].minor.yy494 = yylhsminor.yy494;
        break;
      case 202: /* primary ::= primary DOT IDENTIFIER */
#line 1266 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprMemberAccess, expr, yymsp[0].minor.yy0);
	expr->Operation = PEX_MemberAccess;
	expr->Type = NULL;
	expr->Left = yymsp[-2].minor.yy494;
	expr->Right = ENamedName(yymsp[0].minor.yy0.Int);
	yylhsminor.yy494 = expr;
}
#line 4246 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 203: /* primary ::= primary ADDADD */
#line 1275 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[-1].minor.yy494,PEX_PostInc);
	yylhsminor.yy494 = expr1;
}
#line 4256 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,42,&yymsp[0].minor);
  yymsp[-1].minor.yy494 = yylhsminor.yy494;
        break;
      case 204: /* primary ::= primary SUBSUB */
#line 1280 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[-1].minor.yy494,PEX_PostDec);
	yylhsminor.yy494 = expr1;
}
#line 4266 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,43,&yymsp[0].minor);
  yymsp[-1].minor.yy494 = yylhsminor.yy494;
        break;
      case 205: /* unary_expr ::= SUB unary_expr */
{  yy_destructor(yypParser,33,&yymsp[-1].minor);
#line 1296 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	ZCC_ExprConstant *con = static_cast<ZCC_ExprConstant *>(yymsp[0].minor.yy494);
	if (yymsp[0].minor.yy494->Operation == PEX_ConstValue && (con->Type->isInt() || con->Type->isFloat()))
	{ // For constants, manipulate the child node directly, and don't create a new node.
		if (con->Type->isInt())
		{
			con->IntVal = -con->IntVal;
		}
		else
		{
			con->DoubleVal = -con->DoubleVal;
		}
		yymsp[-1].minor.yy494 = yymsp[0].minor.yy494;
	}
	else
	{ // For everything else, create a new node and do the negation later.
		UNARY_EXPR(yymsp[0].minor.yy494,PEX_Negate);
		yymsp[-1].minor.yy494 = expr1;
	}
}
#line 4293 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
        break;
      case 206: /* unary_expr ::= ADD unary_expr */
{  yy_destructor(yypParser,34,&yymsp[-1].minor);
#line 1317 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	// Even though this is really a no-op, we still need to make a node for
	// it so we can type check that it is being applied to something numeric.
	// But we can do that right now for constant numerals.
	ZCC_ExprConstant *con = static_cast<ZCC_ExprConstant *>(yymsp[0].minor.yy494);
	if (yymsp[0].minor.yy494->Operation != PEX_ConstValue || (!con->Type->isInt() && !con->Type->isFloat()))
	{
		UNARY_EXPR(yymsp[0].minor.yy494,PEX_AntiNegate);
		yymsp[-1].minor.yy494 = expr1;
	}
	else
	{
		yymsp[-1].minor.yy494 = yymsp[0].minor.yy494;
	}
}
#line 4314 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
        break;
      case 207: /* unary_expr ::= SUBSUB unary_expr */
{  yy_destructor(yypParser,43,&yymsp[-1].minor);
#line 1333 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy494,PEX_PreDec);
	yymsp[-1].minor.yy494 = expr1;
}
#line 4324 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
        break;
      case 208: /* unary_expr ::= ADDADD unary_expr */
{  yy_destructor(yypParser,42,&yymsp[-1].minor);
#line 1338 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy494,PEX_PreInc);
	yymsp[-1].minor.yy494 = expr1;
}
#line 4334 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
        break;
      case 209: /* unary_expr ::= TILDE unary_expr */
{  yy_destructor(yypParser,131,&yymsp[-1].minor);
#line 1343 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy494,PEX_BitNot);
	yymsp[-1].minor.yy494 = expr1;
}
#line 4344 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
        break;
      case 210: /* unary_expr ::= BANG unary_expr */
{  yy_destructor(yypParser,132,&yymsp[-1].minor);
#line 1348 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy494,PEX_BoolNot);
	yymsp[-1].minor.yy494 = expr1;
}
#line 4354 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
        break;
      case 211: /* unary_expr ::= SIZEOF unary_expr */
{  yy_destructor(yypParser,133,&yymsp[-1].minor);
#line 1353 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy494,PEX_SizeOf);
	yymsp[-1].minor.yy494 = expr1;
}
#line 4364 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
        break;
      case 212: /* unary_expr ::= ALIGNOF unary_expr */
{  yy_destructor(yypParser,134,&yymsp[-1].minor);
#line 1358 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy494,PEX_AlignOf);
	yymsp[-1].minor.yy494 = expr1;
}
#line 4374 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
        break;
      case 213: /* expr ::= expr ADD expr */
#line 1371 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_Add);
	yylhsminor.yy494 = expr2;
}
#line 4383 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,34,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 214: /* expr ::= expr SUB expr */
#line 1376 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_Sub);
	yylhsminor.yy494 = expr2;
}
#line 4393 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,33,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 215: /* expr ::= expr MUL expr */
#line 1381 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_Mul);
	yylhsminor.yy494 = expr2;
}
#line 4403 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,35,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 216: /* expr ::= expr DIV expr */
#line 1386 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_Div);
	yylhsminor.yy494 = expr2;
}
#line 4413 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,36,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 217: /* expr ::= expr MOD expr */
#line 1391 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_Mod);
	yylhsminor.yy494 = expr2;
}
#line 4423 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,37,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 218: /* expr ::= expr POW expr */
#line 1396 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_Pow);
	yylhsminor.yy494 = expr2;
}
#line 4433 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,40,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 219: /* expr ::= expr CROSSPROD expr */
#line 1401 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_CrossProduct);
	yylhsminor.yy494 = expr2;
}
#line 4443 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,38,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 220: /* expr ::= expr DOTPROD expr */
#line 1406 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_DotProduct);
	yylhsminor.yy494 = expr2;
}
#line 4453 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,39,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 221: /* expr ::= expr LSH expr */
#line 1411 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_LeftShift);
	yylhsminor.yy494 = expr2;
}
#line 4463 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,30,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 222: /* expr ::= expr RSH expr */
#line 1416 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_RightShift);
	yylhsminor.yy494 = expr2;
}
#line 4473 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,31,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 223: /* expr ::= expr URSH expr */
#line 1421 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_URightShift);
	yylhsminor.yy494 = expr2;
}
#line 4483 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,32,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 224: /* expr ::= expr DOTDOT expr */
#line 1426 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_Concat);
	yylhsminor.yy494 = expr2;
}
#line 4493 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,26,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 225: /* expr ::= expr LT expr */
#line 1432 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_LT);
	yylhsminor.yy494 = expr2;
}
#line 4503 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 226: /* expr ::= expr GT expr */
#line 1437 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_GT);
	yylhsminor.yy494 = expr2;
}
#line 4513 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,21,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 227: /* expr ::= expr LTEQ expr */
#line 1442 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_LTEQ);
	yylhsminor.yy494 = expr2;
}
#line 4523 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,22,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 228: /* expr ::= expr GTEQ expr */
#line 1447 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_GTEQ);
	yylhsminor.yy494 = expr2;
}
#line 4533 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,23,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 229: /* expr ::= expr LTGTEQ expr */
#line 1452 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_LTGTEQ);
	yylhsminor.yy494 = expr2;
}
#line 4543 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,24,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 230: /* expr ::= expr IS expr */
#line 1457 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_Is);
	yylhsminor.yy494 = expr2;
}
#line 4553 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,25,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 231: /* expr ::= expr EQEQ expr */
#line 1463 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_EQEQ);
	yylhsminor.yy494 = expr2;
}
#line 4563 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,17,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 232: /* expr ::= expr NEQ expr */
#line 1468 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_NEQ);
	yylhsminor.yy494 = expr2;
}
#line 4573 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,18,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 233: /* expr ::= expr APPROXEQ expr */
#line 1473 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_APREQ);
	yylhsminor.yy494 = expr2;
}
#line 4583 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,19,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 234: /* expr ::= expr AND expr */
#line 1479 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_BitAnd);
	yylhsminor.yy494 = expr2;
}
#line 4593 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,29,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 235: /* expr ::= expr XOR expr */
#line 1484 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_BitXor);
	yylhsminor.yy494 = expr2;
}
#line 4603 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,28,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 236: /* expr ::= expr OR expr */
#line 1489 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_BitOr);
	yylhsminor.yy494 = expr2;
}
#line 4613 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,27,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 237: /* expr ::= expr ANDAND expr */
#line 1494 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_BoolAnd);
	yylhsminor.yy494 = expr2;
}
#line 4623 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,16,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 238: /* expr ::= expr OROR expr */
#line 1499 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_BoolOr);
	yylhsminor.yy494 = expr2;
}
#line 4633 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,15,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 239: /* expr ::= expr EQ expr */
#line 1504 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_Assign);
	yylhsminor.yy494 = expr2;
}
#line 4643 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 240: /* expr ::= expr ADDEQ expr */
#line 1509 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_AddAssign);
	yylhsminor.yy494 = expr2;
}
#line 4653 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,5,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 241: /* expr ::= expr SUBEQ expr */
#line 1514 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_SubAssign);
	yylhsminor.yy494 = expr2;
}
#line 4663 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,6,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 242: /* expr ::= expr MULEQ expr */
#line 1519 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_MulAssign);
	yylhsminor.yy494 = expr2;
}
#line 4673 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,2,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 243: /* expr ::= expr DIVEQ expr */
#line 1524 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_DivAssign);
	yylhsminor.yy494 = expr2;
}
#line 4683 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,3,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 244: /* expr ::= expr MODEQ expr */
#line 1529 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_ModAssign);
	yylhsminor.yy494 = expr2;
}
#line 4693 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,4,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 245: /* expr ::= expr LSHEQ expr */
#line 1534 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_LshAssign);
	yylhsminor.yy494 = expr2;
}
#line 4703 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,7,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 246: /* expr ::= expr RSHEQ expr */
#line 1539 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_RshAssign);
	yylhsminor.yy494 = expr2;
}
#line 4713 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,8,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 247: /* expr ::= expr URSHEQ expr */
#line 1544 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_URshAssign);
	yylhsminor.yy494 = expr2;
}
#line 4723 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,12,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 248: /* expr ::= expr ANDEQ expr */
#line 1549 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_AndAssign);
	yylhsminor.yy494 = expr2;
}
#line 4733 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,9,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 249: /* expr ::= expr OREQ expr */
#line 1554 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_OrAssign);
	yylhsminor.yy494 = expr2;
}
#line 4743 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,10,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 250: /* expr ::= expr XOREQ expr */
#line 1559 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_XorAssign);
	yylhsminor.yy494 = expr2;
}
#line 4753 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,11,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 251: /* expr ::= expr SCOPE expr */
#line 1566 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy494,yymsp[0].minor.yy494,PEX_Scope);
	yylhsminor.yy494 = expr2;
}
#line 4763 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,47,&yymsp[-1].minor);
  yymsp[-2].minor.yy494 = yylhsminor.yy494;
        break;
      case 252: /* expr ::= expr QUESTION expr COLON expr */
#line 1574 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprTrinary, expr, yymsp[-4].minor.yy494);
	expr->Operation = PEX_Trinary;
	expr->Type = NULL;
	expr->Test = yymsp[-4].minor.yy494;
	expr->Left = yymsp[-2].minor.yy494;
	expr->Right = yymsp[0].minor.yy494;
	yylhsminor.yy494 = expr;
}
#line 4778 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,13,&yymsp[-3].minor);
  yy_destructor(yypParser,14,&yymsp[-1].minor);
  yymsp[-4].minor.yy494 = yylhsminor.yy494;
        break;
      case 253: /* expr_list ::= expr_list COMMA expr */
#line 1590 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[-2].minor.yy494 = yymsp[-2].minor.yy494;	/*X-overwrites-A*/
	AppendTreeNodeSibling(yymsp[-2].minor.yy494, yymsp[0].minor.yy494);
}
#line 4789 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 254: /* func_expr_list ::= func_expr_list COMMA func_expr_item */
#line 1606 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	// Omitted parameters still need to appear as nodes in the list.
	if (yymsp[-2].minor.yy366 == NULL)
	{
		NEW_AST_NODE(FuncParm,nil_a,yymsp[-1].minor.yy0);
		nil_a->Value = NULL;
		nil_a->Label = NAME_None;
		yymsp[-2].minor.yy366 = nil_a;
	}
	if (yymsp[0].minor.yy366 == NULL)
	{
		NEW_AST_NODE(FuncParm,nil_b,yymsp[-1].minor.yy0);
		nil_b->Value = NULL;
		nil_b->Label = NAME_None;
		yymsp[0].minor.yy366 = nil_b;
	}
	yymsp[-2].minor.yy366 = yymsp[-2].minor.yy366;	/*X-overwrites-A*/
	AppendTreeNodeSibling(yymsp[-2].minor.yy366, yymsp[0].minor.yy366);
}
#line 4813 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 255: /* func_expr_item ::= */
#line 1627 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[1].minor.yy366 = NULL;
}
#line 4820 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 256: /* named_expr ::= IDENTIFIER COLON expr */
#line 1633 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParm, parm, yymsp[-2].minor.yy0);
	parm->Value = yymsp[0].minor.yy494;
	parm->Label = ENamedName(yymsp[-2].minor.yy0.Int);
	yylhsminor.yy366 = parm;
}
#line 4830 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[-1].minor);
  yymsp[-2].minor.yy366 = yylhsminor.yy366;
        break;
      case 257: /* named_expr ::= expr */
#line 1640 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParm, parm, yymsp[0].minor.yy494);
	parm->Value = yymsp[0].minor.yy494;
	parm->Label = NAME_None;
	yylhsminor.yy366 = parm;
}
#line 4842 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy366 = yylhsminor.yy366;
        break;
      case 259: /* string_constant ::= string_constant STRCONST */
#line 1661 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, strconst, yymsp[-1].minor.yy135);
	strconst->Operation = PEX_ConstValue;
	strconst->Type = TypeString;
	strconst->StringVal = stat->Strings.Alloc(*(yymsp[-1].minor.yy135->StringVal) + *(yymsp[0].minor.yy0.String));
	yylhsminor.yy135 = strconst;
}
#line 4854 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[-1].minor.yy135 = yylhsminor.yy135;
        break;
      case 260: /* constant ::= INTCONST */
#line 1671 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(intconst, TypeSInt32, yymsp[0].minor.yy0.Int, yymsp[0].minor.yy0);
	yylhsminor.yy135 = intconst;
}
#line 4863 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy135 = yylhsminor.yy135;
        break;
      case 261: /* constant ::= UINTCONST */
#line 1676 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(intconst, TypeUInt32, yymsp[0].minor.yy0.Int, yymsp[0].minor.yy0);
	yylhsminor.yy135 = intconst;
}
#line 4872 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy135 = yylhsminor.yy135;
        break;
      case 262: /* constant ::= FLOATCONST */
#line 1681 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, floatconst, yymsp[0].minor.yy0);
	floatconst->Operation = PEX_ConstValue;
	floatconst->Type = TypeFloat64;
	floatconst->DoubleVal = yymsp[0].minor.yy0.Float;
	yylhsminor.yy135 = floatconst;
}
#line 4884 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy135 = yylhsminor.yy135;
        break;
      case 263: /* constant ::= NAMECONST */
#line 1689 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, floatconst, yymsp[0].minor.yy0);
	floatconst->Operation = PEX_ConstValue;
	floatconst->Type = TypeName;
	floatconst->IntVal = yymsp[0].minor.yy0.Int;
	yylhsminor.yy135 = floatconst;
}
#line 4896 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy135 = yylhsminor.yy135;
        break;
      case 264: /* constant ::= FALSE */
#line 1697 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(boolconst, TypeBool, false, yymsp[0].minor.yy0);
	yylhsminor.yy135 = boolconst;
}
#line 4905 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy135 = yylhsminor.yy135;
        break;
      case 265: /* constant ::= TRUE */
#line 1702 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(boolconst, TypeBool, true, yymsp[0].minor.yy0);
	yylhsminor.yy135 = boolconst;
}
#line 4914 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy135 = yylhsminor.yy135;
        break;
      case 266: /* constant ::= NULLPTR */
#line 1707 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, nullptrconst, yymsp[0].minor.yy0);
	nullptrconst->Operation = PEX_ConstValue;
	nullptrconst->Type = TypeNullPtr;
	nullptrconst->StringVal = nullptr;
	yylhsminor.yy135 = nullptrconst;
}
#line 4926 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy135 = yylhsminor.yy135;
        break;
      case 268: /* statement ::= labeled_statement */
#line 1721 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy475 = yymsp[0].minor.yy422; /*X-overwrites-A*/ }
#line 4932 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 269: /* statement ::= compound_statement */
#line 1722 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy475 = yymsp[0].minor.yy35; /*X-overwrites-A*/ }
#line 4937 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 270: /* statement ::= expression_statement SEMICOLON */
#line 1723 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy475 = yymsp[-1].minor.yy262; /*X-overwrites-A*/ }
#line 4942 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 271: /* statement ::= assign_statement SEMICOLON */
#line 1727 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy475 = yymsp[-1].minor.yy195; /*X-overwrites-A*/ }
#line 4948 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 272: /* statement ::= local_var SEMICOLON */
#line 1728 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy475 = yymsp[-1].minor.yy150; /*X-overwrites-A*/ }
#line 4954 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 274: /* statement ::= staticarray_statement */
#line 1730 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy475 = yymsp[0].minor.yy202; /*X-overwrites-A*/ }
#line 4960 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 275: /* staticarray_statement ::= STATICCONST type IDENTIFIER LBRACKET RBRACKET EQ LBRACE expr_list RBRACE SEMICOLON */
{  yy_destructor(yypParser,142,&yymsp[-9].minor);
#line 1737 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(StaticArrayStatement, stmt, yymsp[-8].minor.yy344);
	stmt->Type = yymsp[-8].minor.yy344;
	stmt->Id = ENamedName(yymsp[-7].minor.yy0.Int);
	stmt->Values = yymsp[-2].minor.yy494;
	yymsp[-9].minor.yy202 = stmt;
}
#line 4972 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,46,&yymsp[-6].minor);
  yy_destructor(yypParser,112,&yymsp[-5].minor);
  yy_destructor(yypParser,1,&yymsp[-4].minor);
  yy_destructor(yypParser,65,&yymsp[-3].minor);
  yy_destructor(yypParser,66,&yymsp[-1].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
}
        break;
      case 276: /* staticarray_statement ::= STATICCONST type LBRACKET RBRACKET IDENTIFIER EQ LBRACE expr_list RBRACE SEMICOLON */
{  yy_destructor(yypParser,142,&yymsp[-9].minor);
#line 1746 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(StaticArrayStatement, stmt, yymsp[-8].minor.yy344);
	stmt->Type = yymsp[-8].minor.yy344;
	stmt->Id = ENamedName(yymsp[-5].minor.yy0.Int);
	stmt->Values = yymsp[-2].minor.yy494;
	yymsp[-9].minor.yy202 = stmt;
}
#line 4991 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,46,&yymsp[-7].minor);
  yy_destructor(yypParser,112,&yymsp[-6].minor);
  yy_destructor(yypParser,1,&yymsp[-4].minor);
  yy_destructor(yypParser,65,&yymsp[-3].minor);
  yy_destructor(yypParser,66,&yymsp[-1].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
}
        break;
      case 277: /* jump_statement ::= CONTINUE SEMICOLON */
#line 1759 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ContinueStmt, stmt, yymsp[-1].minor.yy0);
	yylhsminor.yy475 = stmt;
}
#line 5006 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy475 = yylhsminor.yy475;
        break;
      case 278: /* jump_statement ::= BREAK SEMICOLON */
#line 1764 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(BreakStmt, stmt, yymsp[-1].minor.yy0);
	yylhsminor.yy475 = stmt;
}
#line 5016 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy475 = yylhsminor.yy475;
        break;
      case 279: /* jump_statement ::= RETURN SEMICOLON */
#line 1769 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ReturnStmt, stmt, yymsp[-1].minor.yy0);
	stmt->Values = NULL;
	yylhsminor.yy475 = stmt;
}
#line 5027 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy475 = yylhsminor.yy475;
        break;
      case 280: /* jump_statement ::= RETURN expr_list SEMICOLON */
#line 1775 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ReturnStmt, stmt, yymsp[-2].minor.yy0);
	stmt->Values = yymsp[-1].minor.yy494;
	yylhsminor.yy475 = stmt;
}
#line 5038 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-2].minor.yy475 = yylhsminor.yy475;
        break;
      case 281: /* compound_statement ::= LBRACE RBRACE */
#line 1787 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-1].minor.yy0);
	stmt->Content = NULL;
	yylhsminor.yy35 = stmt;
}
#line 5049 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-1].minor.yy35 = yylhsminor.yy35;
        break;
      case 282: /* compound_statement ::= LBRACE statement_list RBRACE */
#line 1793 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-2].minor.yy0);
	stmt->Content = yymsp[-1].minor.yy475;
	yylhsminor.yy35 = stmt;
}
#line 5060 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-2].minor.yy35 = yylhsminor.yy35;
        break;
      case 283: /* compound_statement ::= LBRACE error RBRACE */
#line 1799 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-2].minor.yy0);
	stmt->Content = NULL;
	yylhsminor.yy35 = stmt;
}
#line 5071 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-2].minor.yy35 = yylhsminor.yy35;
        break;
      case 286: /* expression_statement ::= expr */
#line 1819 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExpressionStmt, stmt, yymsp[0].minor.yy494);
	stmt->Expression = yymsp[0].minor.yy494;
	yylhsminor.yy262 = stmt;
}
#line 5082 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy262 = yylhsminor.yy262;
        break;
      case 287: /* iteration_statement ::= while_or_until LPAREN expr RPAREN statement */
#line 1831 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(IterationStmt, iter, yymsp[-4].minor.yy0);
	if (yymsp[-4].minor.yy0.Int == ZCC_UNTIL)
	{ // Negate the loop condition
		UNARY_EXPR(yymsp[-2].minor.yy494,PEX_BoolNot);
		iter->LoopCondition = expr1;
	}
	else
	{
		iter->LoopCondition = yymsp[-2].minor.yy494;
	}
	iter->LoopStatement = yymsp[0].minor.yy475;
	iter->LoopBumper = NULL;
	iter->CheckAt = ZCC_IterationStmt::Start;
	yylhsminor.yy475 = iter;
}
#line 5103 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[-1].minor);
  yymsp[-4].minor.yy475 = yylhsminor.yy475;
        break;
      case 288: /* iteration_statement ::= DO statement while_or_until LPAREN expr RPAREN */
#line 1849 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(IterationStmt, iter, yymsp[-5].minor.yy0);
	if (yymsp[-3].minor.yy0.Int == ZCC_UNTIL)
	{ // Negate the loop condition
		UNARY_EXPR(yymsp[-1].minor.yy494,PEX_BoolNot);
		iter->LoopCondition = expr1;
	}
	else
	{
		iter->LoopCondition = yymsp[-1].minor.yy494;
	}
	iter->LoopStatement = yymsp[-4].minor.yy475;
	iter->LoopBumper = NULL;
	iter->CheckAt = ZCC_IterationStmt::End;
	yylhsminor.yy475 = iter;
}
#line 5126 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-5].minor.yy475 = yylhsminor.yy475;
        break;
      case 289: /* iteration_statement ::= FOR LPAREN for_init SEMICOLON opt_expr SEMICOLON for_bump RPAREN statement */
#line 1867 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(IterationStmt, iter, yymsp[-8].minor.yy0);
	iter->LoopCondition = yymsp[-4].minor.yy494;
	iter->LoopStatement = yymsp[0].minor.yy475;
	iter->LoopBumper = yymsp[-2].minor.yy475;
	iter->CheckAt = ZCC_IterationStmt::Start;
	// The initialization expression appears outside the loop
	// for_init may be NULL if there is no initialization.
	SAFE_APPEND(yymsp[-6].minor.yy475, iter);
	// And the whole thing gets wrapped inside a compound statement in case the loop
	// initializer defined any variables.
	NEW_AST_NODE(CompoundStmt, wrap, yymsp[-8].minor.yy0);
	wrap->Content = yymsp[-6].minor.yy475;
	yylhsminor.yy475 = wrap;
}
#line 5148 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-7].minor);
  yy_destructor(yypParser,49,&yymsp[-5].minor);
  yy_destructor(yypParser,49,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[-1].minor);
  yymsp[-8].minor.yy475 = yylhsminor.yy475;
        break;
      case 290: /* while_or_until ::= WHILE */
#line 1884 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	yylhsminor.yy0.Int = ZCC_WHILE;
	yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc;
}
#line 5161 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 291: /* while_or_until ::= UNTIL */
#line 1889 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	yylhsminor.yy0.Int = ZCC_UNTIL;
	yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc;
}
#line 5170 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 292: /* for_init ::= local_var */
#line 1895 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy475 = yymsp[0].minor.yy150 /*X-overwrites-A*/; }
#line 5176 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 293: /* for_init ::= for_bump */
#line 1896 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy475 = yymsp[0].minor.yy475 /*X-overwrites-A*/; }
#line 5181 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 294: /* for_bump ::= */
#line 1899 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy475 = NULL; }
#line 5186 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 295: /* for_bump ::= expression_statement */
#line 1900 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy475 = yymsp[0].minor.yy262; /*X-overwrites-A*/ }
#line 5191 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 296: /* for_bump ::= for_bump COMMA expression_statement */
#line 1901 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy475 = yymsp[-2].minor.yy475; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy475, yymsp[0].minor.yy262); }
#line 5196 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 297: /* selection_statement ::= if_front */
#line 1915 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[0].minor.yy475 = yymsp[0].minor.yy101; /*X-overwrites-A*/
}
#line 5204 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
        break;
      case 298: /* selection_statement ::= if_front ELSE statement */
#line 1919 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[-2].minor.yy101->FalsePath = yymsp[0].minor.yy475;
	yymsp[-2].minor.yy475 = yymsp[-2].minor.yy101; /*X-overwrites-A*/
}
#line 5212 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,151,&yymsp[-1].minor);
        break;
      case 299: /* if_front ::= IF LPAREN expr RPAREN statement */
#line 1925 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(IfStmt,stmt,yymsp[-4].minor.yy0);
	stmt->Condition = yymsp[-2].minor.yy494;
	stmt->TruePath = yymsp[0].minor.yy475;
	stmt->FalsePath = NULL;
	yylhsminor.yy101 = stmt;
}
#line 5224 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[-1].minor);
  yymsp[-4].minor.yy101 = yylhsminor.yy101;
        break;
      case 300: /* selection_statement ::= SWITCH LPAREN expr RPAREN statement */
#line 1936 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(SwitchStmt,stmt,yymsp[-4].minor.yy0);
	stmt->Condition = yymsp[-2].minor.yy494;
	stmt->Content = yymsp[0].minor.yy475;
	yylhsminor.yy475 = stmt;
}
#line 5237 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[-1].minor);
  yymsp[-4].minor.yy475 = yylhsminor.yy475;
        break;
      case 301: /* labeled_statement ::= CASE expr COLON */
#line 1948 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(CaseStmt,stmt,yymsp[-2].minor.yy0);
	stmt->Condition = yymsp[-1].minor.yy494;
	yylhsminor.yy422 = stmt;
}
#line 5249 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[0].minor);
  yymsp[-2].minor.yy422 = yylhsminor.yy422;
        break;
      case 302: /* labeled_statement ::= DEFAULT COLON */
#line 1954 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(CaseStmt,stmt,yymsp[-1].minor.yy0);
	stmt->Condition = NULL;
	yylhsminor.yy422 = stmt;
}
#line 5260 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[0].minor);
  yymsp[-1].minor.yy422 = yylhsminor.yy422;
        break;
      case 303: /* assign_statement ::= LBRACKET expr_list RBRACKET EQ expr */
{  yy_destructor(yypParser,46,&yymsp[-4].minor);
#line 1967 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(AssignStmt,stmt,yymsp[-3].minor.yy494);
	stmt->AssignOp = ZCC_EQ;
	stmt->Dests = yymsp[-3].minor.yy494;
	stmt->Sources = yymsp[0].minor.yy494;
	yymsp[-4].minor.yy195 = stmt;
}
#line 5274 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,112,&yymsp[-2].minor);
  yy_destructor(yypParser,1,&yymsp[-1].minor);
}
        break;
      case 304: /* local_var ::= type variable_list_with_init */
#line 1980 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(LocalVarStmt,vardef,yymsp[-1].minor.yy344);
	vardef->Type = yymsp[-1].minor.yy344;
	vardef->Vars = yymsp[0].minor.yy363;
	yylhsminor.yy150 = vardef;
}
#line 5287 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[-1].minor.yy150 = yylhsminor.yy150;
        break;
      case 305: /* var_init ::= IDENTIFIER */
#line 1989 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[0].minor.yy0);
	var->Name = ENamedName(yymsp[0].minor.yy0.Int);
	var->ArraySize = NULL;
	var->Init = NULL;
	var->InitIsArray = false;
	yylhsminor.yy363 = var;
}
#line 5300 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[0].minor.yy363 = yylhsminor.yy363;
        break;
      case 306: /* var_init ::= IDENTIFIER array_size */
#line 1999 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(VarInit,var,yymsp[-1].minor.yy0);
	var->Name = ENamedName(yymsp[-1].minor.yy0.Int);
	var->ArraySize = yymsp[0].minor.yy494;
	var->Init = NULL;
	var->InitIsArray = false;
	yylhsminor.yy363 = var;
}
#line 5313 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yymsp[-1].minor.yy363 = yylhsminor.yy363;
        break;
      case 307: /* var_init ::= IDENTIFIER EQ expr */
#line 2009 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[-2].minor.yy0);
	var->Name = ENamedName(yymsp[-2].minor.yy0.Int);
	var->ArraySize = NULL;
	var->Init = yymsp[0].minor.yy494;
	var->InitIsArray = false;
	yylhsminor.yy363 = var;
}
#line 5326 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-2].minor.yy363 = yylhsminor.yy363;
        break;
      case 308: /* var_init ::= IDENTIFIER EQ LBRACE expr_list RBRACE */
#line 2019 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[-4].minor.yy0);
	var->Name = ENamedName(yymsp[-4].minor.yy0.Int);
	var->ArraySize = NULL;
	var->Init = yymsp[-1].minor.yy494;
	var->InitIsArray = true;
	yylhsminor.yy363 = var;
}
#line 5340 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-3].minor);
  yy_destructor(yypParser,65,&yymsp[-2].minor);
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-4].minor.yy363 = yylhsminor.yy363;
        break;
      case 309: /* var_init ::= IDENTIFIER array_size EQ LBRACE expr_list RBRACE */
#line 2029 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[-5].minor.yy0);
	var->Name = ENamedName(yymsp[-5].minor.yy0.Int);
	var->ArraySize = yymsp[-4].minor.yy494;
	var->Init = yymsp[-1].minor.yy494;
	var->InitIsArray = true;
	yylhsminor.yy363 = var;
}
#line 5356 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-3].minor);
  yy_destructor(yypParser,65,&yymsp[-2].minor);
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-5].minor.yy363 = yylhsminor.yy363;
        break;
      case 310: /* var_init ::= IDENTIFIER EQ LBRACE error RBRACE */
{  yy_destructor(yypParser,54,&yymsp[-4].minor);
#line 2039 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{ 
	yymsp[-4].minor.yy363 = NULL;
}
#line 5368 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-3].minor);
  yy_destructor(yypParser,65,&yymsp[-2].minor);
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 311: /* variable_list_with_init ::= variable_list_with_init COMMA var_init */
#line 2047 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
	AppendTreeNodeSibling(yymsp[-2].minor.yy363, yymsp[0].minor.yy363);
	yymsp[-2].minor.yy363 = yymsp[-2].minor.yy363; /*X-overwrites-A*/
}
#line 5380 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 312: /* translation_unit ::= translation_unit EOF */
#line 178 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
}
#line 5387 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,48,&yymsp[0].minor);
        break;
      case 314: /* opt_semicolon ::= SEMICOLON */
{  yy_destructor(yypParser,49,&yymsp[0].minor);
#line 190 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
}
#line 5395 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
        break;
      case 316: /* opt_comma ::= COMMA */
{  yy_destructor(yypParser,50,&yymsp[0].minor);
#line 193 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
}
#line 5403 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
}
        break;
      case 322: /* state_flow ::= state_flow_type scanner_mode SEMICOLON */
#line 569 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
}
#line 5410 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 332: /* primary ::= LPAREN error RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 1238 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
{
}
#line 5418 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      default:
      /* (313) opt_semicolon ::= */ yytestcase(yyruleno==313);
      /* (315) opt_comma ::= */ yytestcase(yyruleno==315);
      /* (317) opt_expr ::= expr */ yytestcase(yyruleno==317);
      /* (318) opt_struct_body ::= struct_body */ yytestcase(yyruleno==318);
      /* (319) struct_body ::= struct_member */ yytestcase(yyruleno==319);
      /* (320) enum_list ::= enumerator */ yytestcase(yyruleno==320);
      /* (321) opt_enum_list ::= enum_list opt_comma */ yytestcase(yyruleno==321);
      /* (323) type_name1 ::= int_type */ yytestcase(yyruleno==323);
      /* (324) type_or_array ::= type */ yytestcase(yyruleno==324);
      /* (325) type_list ::= type_or_array */ yytestcase(yyruleno==325);
      /* (326) type_list_or_void ::= type_list */ yytestcase(yyruleno==326);
      /* (327) array_size ::= array_size_expr */ yytestcase(yyruleno==327);
      /* (328) variable_list ::= variable_name */ yytestcase(yyruleno==328);
      /* (329) opt_func_body ::= function_body */ yytestcase(yyruleno==329);
      /* (330) func_params ::= func_param_list */ yytestcase(yyruleno==330);
      /* (331) func_param_list ::= func_param */ yytestcase(yyruleno==331);
      /* (333) unary_expr ::= primary */ yytestcase(yyruleno==333);
      /* (334) expr ::= unary_expr */ yytestcase(yyruleno==334);
      /* (335) expr_list ::= expr */ yytestcase(yyruleno==335);
      /* (336) func_expr_list ::= func_expr_item */ yytestcase(yyruleno==336);
      /* (337) func_expr_item ::= named_expr */ yytestcase(yyruleno==337);
      /* (338) constant ::= string_constant */ yytestcase(yyruleno==338);
      /* (339) function_body ::= compound_statement */ yytestcase(yyruleno==339);
      /* (340) statement ::= selection_statement */ yytestcase(yyruleno==340);
      /* (341) statement ::= iteration_statement */ yytestcase(yyruleno==341);
      /* (342) statement ::= jump_statement */ yytestcase(yyruleno==342);
      /* (343) variable_list_with_init ::= var_init */ yytestcase(yyruleno==343);
       break;
/********** End reduce actions ************************************************/
  };
  assert( yyruleno<sizeof(yyRuleInfo)/sizeof(yyRuleInfo[0]) );
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact <= YY_MAX_SHIFTREDUCE ){
    if( yyact>YY_MAX_SHIFT ){
      yyact += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
    }
    yymsp -= yysize-1;
    yypParser->yytos = yymsp;
    yymsp->stateno = (YYACTIONTYPE)yyact;
    yymsp->major = (YYCODETYPE)yygoto;
    yyTraceShift(yypParser, yyact);
  }else{
    assert( yyact == YY_ACCEPT_ACTION );
    yypParser->yytos -= yysize;
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
#ifndef YYNOERRORRECOVERY
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  ZCCParseARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
    fflush(yyTraceFILE);
  }
#endif
  while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
/************ Begin %parse_failure code ***************************************/
#line 148 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
 /**failed = true;*/ 
#line 5493 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
/************ End %parse_failure code *****************************************/
  ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}
#endif /* YYNOERRORRECOVERY */

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  ZCCParseTOKENTYPE yyminor         /* The minor type of the error token */
){
  ZCCParseARG_FETCH;
#define TOKEN yyminor
/************ Begin %syntax_error code ****************************************/
#line 121 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"

	FString unexpected, expecting;

	int i;
	int stateno = yypParser->yytos->stateno;

	unexpected << "Unexpected " << ZCCTokenName(yymajor);

	// Determine all the terminals that the parser would have accepted at this point
	// (see yy_find_shift_action). This list can get quite long. Is it worthwhile to
	// print it when not debugging the grammar, or would that be too confusing to
	// the average user?
	if (stateno < YY_SHIFT_MAX && (i = yy_shift_ofst[stateno])!=YY_SHIFT_USE_DFLT)
	{
		for (int j = 1; j < YYERRORSYMBOL; ++j)
		{
			int k = i + j;
			if (k >= 0 && k < YY_ACTTAB_COUNT && yy_lookahead[k] == j)
			{
				expecting << (expecting.IsEmpty() ? "Expecting " : " or ") << ZCCTokenName(j);
			}
		}
	}
	stat->sc->ScriptMessage("%s\n%s\n", unexpected.GetChars(), expecting.GetChars());
	FScriptPosition::ErrorCounter++;
#line 5536 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
/************ End %syntax_error code ******************************************/
  ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  ZCCParseARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
    fflush(yyTraceFILE);
  }
#endif
#ifndef YYNOERRORRECOVERY
  yypParser->yyerrcnt = -1;
#endif
#if 0
  assert( yypParser->yytos==yypParser->yystack );
#else
  while (yypParser->yytos>yypParser->yystack) yy_pop_parser_stack(yypParser);
#endif
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
/*********** Begin %parse_accept code *****************************************/
#line 147 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/src/scripting/zscript/zcc-parse.lemon"
 DPrintf(DMSG_SPAMMY, "Input accepted\n"); 
#line 5567 "/home/iurt/rpmbuild/BUILD/gzdoom-g3.5.0/build/src/zcc-parse.c"
/*********** End %parse_accept code *******************************************/
  ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "ZCCParseAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void ZCCParse(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  ZCCParseTOKENTYPE yyminor       /* The value for the token */
  ZCCParseARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  unsigned int yyact;   /* The parser action. */
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  int yyendofinput;     /* True if we are at the end of input */
#endif
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  yypParser = (yyParser*)yyp;
  assert( yypParser->yytos!=0 );
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  yyendofinput = (yymajor==0);
#endif
  ZCCParseARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput '%s'\n",yyTracePrompt,yyTokenName[yymajor]);
    fflush(yyTraceFILE);
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact <= YY_MAX_SHIFTREDUCE ){
      yy_shift(yypParser,yyact,yymajor,yyminor);
#ifndef YYNOERRORRECOVERY
      yypParser->yyerrcnt--;
#endif
      yymajor = YYNOCODE;
    }else if( yyact <= YY_MAX_REDUCE ){
      yy_reduce(yypParser,yyact-YY_MIN_REDUCE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
      yyminorunion.yy0 = yyminor;
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
        fflush(yyTraceFILE);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminor);
      }
      yymx = yypParser->yytos->major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
          fflush(yyTraceFILE);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor, &yyminorunion);
        yymajor = YYNOCODE;
      }else{
        while( yypParser->yytos >= yypParser->yystack
            && yymx != YYERRORSYMBOL
            && (yyact = yy_find_reduce_action(
                        yypParser->yytos->stateno,
                        YYERRORSYMBOL)) >= YY_MIN_REDUCE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yytos < yypParser->yystack || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
          yypParser->yyerrcnt = -1;
#endif
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          yy_shift(yypParser,yyact,YYERRORSYMBOL,yyminor);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#elif defined(YYNOERRORRECOVERY)
      /* If the YYNOERRORRECOVERY macro is defined, then do not attempt to
      ** do any kind of error recovery.  Instead, simply invoke the syntax
      ** error routine and continue going as if nothing had happened.
      **
      ** Applications can set this macro (for example inside %include) if
      ** they intend to abandon the parse upon the first syntax error seen.
      */
      yy_syntax_error(yypParser,yymajor, yyminor);
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      yymajor = YYNOCODE;
      
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor, yyminor);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
        yypParser->yyerrcnt = -1;
#endif
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yytos>yypParser->yystack );
#ifndef NDEBUG
  if( yyTraceFILE ){
    yyStackEntry *i;
    char cDiv = '[';
    fprintf(yyTraceFILE,"%sReturn. Stack=",yyTracePrompt);
    for(i=&yypParser->yystack[1]; i<=yypParser->yytos; i++){
      fprintf(yyTraceFILE,"%c%s", cDiv, yyTokenName[i->major]);
      cDiv = ' ';
    }
    fprintf(yyTraceFILE,"]\n");
    fflush(yyTraceFILE);
  }
#endif
  return;
}
